//region Student
var db                                  = require('./SQLConnection'),
    logger                              = require('./logger'),
    eventLogger                         = require('../lib/eventLogger'),

    fs                                  = require('fs'),
    path                                = require('path'),

    Docxtemplater                       = require('docxtemplater'),

    Excel                               = require('exceljs'),
    XLSX                                = require('xlsx'),

    moment                              = require('moment'),
    momentDurationFormatSetup           = require("moment-duration-format")
;

moment.locale('hu');
momentDurationFormatSetup(moment);

module.exports.vallfaByDeviceIdBetweenTimestamps = async function (from, to, deviceId) {
    let generationResult = {eventType: eventLogger.eventType.Document, result: eventLogger.eventResult.Undefined, referenceIds: [], path: "UNDEFINED"};

    try {
        const [
            temperatures,
            humidity,
            pressure,
            weight,
            rfid,
            current,
            voltage
        ] = await Promise.all([
            db.getTemperatureOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getHumidityOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getPressureOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getScale_AvgWeightOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getrfidOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getcurrentOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getvoltageOfDeviceBetweenTimeStamps(from, to, deviceId)
        ]);

        let workbook = new Excel.Workbook();
        let worksheet_temperature = workbook.addWorksheet('Hőmérséklet');
        let worksheet_humidity = workbook.addWorksheet('Páratartalom');
        let worksheet_pressure = workbook.addWorksheet('Légnyomás');
        let worksheet_weight = workbook.addWorksheet('Súly');
        let worksheet_rfid = workbook.addWorksheet('RFID');
        let worksheet_current = workbook.addWorksheet('Áramfelvétel');
        let worksheet_voltage = workbook.addWorksheet('Feszültség');

        let columns_temperature = [];
        columns_temperature.push({ header: 'Dátum',             key: 'timeStamp',                width: 32});
        columns_temperature.push({ header: 'Hőmérséklet',       key: 'temperature',               width: 32});
        worksheet_temperature.columns = columns_temperature;
        temperatures.forEach((temperature) => {
            worksheet_temperature.addRow({
                timeStamp:moment(temperature.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature: temperature.temperature
            });
        });

        let columns_humidity = [];
        columns_humidity.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_humidity.push({ header: 'Páratartalom',         key: 'humidity',               width: 32});
        worksheet_humidity.columns = columns_humidity;
        humidity.forEach((humidity) => {
            worksheet_humidity.addRow({
                timeStamp:moment(humidity.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                humidity: humidity.humidity
            });
        });

        let columns_pressure = [];
        columns_pressure.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_pressure.push({ header: 'Légnyomás',         key: 'pressure',               width: 32});
        worksheet_pressure.columns = columns_pressure;
        pressure.forEach((pressure) => {
            worksheet_pressure.addRow({
                timeStamp:moment(pressure.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                pressure: pressure.pressure
            });
        });

        let columns_weight = [];
        columns_weight.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_weight.push({ header: 'Súly',                 key: 'weight',               width: 32});
        worksheet_weight.columns = columns_weight;
        weight.forEach((weight) => {
            worksheet_weight.addRow({
                timeStamp:moment(weight.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                weight: weight.scale_AvgWeight
            });
        });

        let columns_rfid = [];
        columns_rfid.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_rfid.push({ header: 'RFID',                 key: 'rfid',               width: 32});
        worksheet_rfid.columns = columns_rfid;
        rfid.forEach((rfid) => {
            worksheet_rfid.addRow({
                timeStamp:moment(rfid.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                rfid: rfid.rfid
            });
        });

        let columns_current = [];
        columns_current.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_current.push({ header: 'Áramfelvétel',                 key: 'current',               width: 32});
        worksheet_current.columns = columns_current;
        current.forEach((current) => {
            worksheet_current.addRow({
                timeStamp:moment(current.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                current: current.current
            });
        });

        let columns_voltage = [];
        columns_voltage.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_voltage.push({ header: 'Feszültség',                 key: 'voltage',               width: 32});
        worksheet_voltage.columns = columns_voltage;
        voltage.forEach((voltage) => {
            worksheet_voltage.addRow({
                timeStamp:moment(voltage.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                voltage: voltage.voltage
            });
        });

        let filePath = path.resolve('documents/generated/', 'vallfa-' + deviceId+"-"+from+"-"+ to + '.xlsx');

        generationResult.path = filePath;
        generationResult.result = eventLogger.eventResult.Success;

        await Promise.all([workbook.xlsx.writeFile(filePath)]);

        return generationResult;
    }
    catch (err) {
        logger.error('Error: ' + err.message + "\n\n"  + err.stack); generationResult.eventResult = eventLogger.eventResult.Failed;
        return generationResult;
    }
};

module.exports.vallfaByDeviceId = async function (deviceId) {
    let generationResult = {eventType: eventLogger.eventType.Document, result: eventLogger.eventResult.Undefined, referenceIds: [], path: "UNDEFINED"};

    try {
        const [
            temperatures,
            humidity,
            pressure,
            weight,
            rfid,
            current,
            voltage
        ] = await Promise.all([
            db.getTemperatureOfDevice(deviceId),
            db.getHumidityOfDevice(deviceId),
            db.getPressureOfDevice(deviceId),
            db.getScale_AvgWeightOfDevice(deviceId),
            db.getrfidOfDevice(deviceId),
            db.getcurrentOfDevice(deviceId),
            db.getvoltageOfDevice(deviceId)
        ]);

        let workbook = new Excel.Workbook();
        let worksheet_temperature = workbook.addWorksheet('Hőmérséklet');
        let worksheet_humidity = workbook.addWorksheet('Páratartalom');
        let worksheet_pressure = workbook.addWorksheet('Légnyomás');
        let worksheet_weight = workbook.addWorksheet('Súly');
        let worksheet_rfid = workbook.addWorksheet('RFID');
        let worksheet_current = workbook.addWorksheet('Áramfelvétel');
        let worksheet_voltage = workbook.addWorksheet('Feszültség');

        let columns_temperature = [];
        columns_temperature.push({ header: 'Dátum',             key: 'timeStamp',                width: 32});
        columns_temperature.push({ header: 'Hőmérséklet',       key: 'temperature',               width: 32});
        worksheet_temperature.columns = columns_temperature;
        temperatures.forEach((temperature) => {
            worksheet_temperature.addRow({
                timeStamp:moment(temperature.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature: temperature.temperature
            });
        });

        let columns_humidity = [];
        columns_humidity.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_humidity.push({ header: 'Páratartalom',         key: 'humidity',               width: 32});
        worksheet_humidity.columns = columns_humidity;
        humidity.forEach((humidity) => {
            worksheet_humidity.addRow({
                timeStamp:moment(humidity.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                humidity: humidity.humidity
            });
        });

        let columns_pressure = [];
        columns_pressure.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_pressure.push({ header: 'Légnyomás',         key: 'pressure',               width: 32});
        worksheet_pressure.columns = columns_pressure;
        pressure.forEach((pressure) => {
            worksheet_pressure.addRow({
                timeStamp:moment(pressure.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                pressure: pressure.pressure
            });
        });

        let columns_weight = [];
        columns_weight.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_weight.push({ header: 'Súly',                 key: 'weight',               width: 32});
        worksheet_weight.columns = columns_weight;
        weight.forEach((weight) => {
            worksheet_weight.addRow({
                timeStamp:moment(weight.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                weight: weight.scale_AvgWeight
            });
        });

        let columns_rfid = [];
        columns_rfid.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_rfid.push({ header: 'RFID',                 key: 'rfid',               width: 32});
        worksheet_rfid.columns = columns_rfid;
        rfid.forEach((rfid) => {
            worksheet_rfid.addRow({
                timeStamp:moment(rfid.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                rfid: rfid.rfid
            });
        });

        let columns_current = [];
        columns_current.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_current.push({ header: 'Áramfelvétel',         key: 'current',               width: 32});
        worksheet_current.columns = columns_current;
        current.forEach((current) => {
            worksheet_current.addRow({
                timeStamp:moment(current.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                current: current.current
            });
        });

        let columns_voltage = [];
        columns_voltage.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_voltage.push({ header: 'Feszültség',           key: 'voltage',               width: 32});
        worksheet_voltage.columns = columns_voltage;
        voltage.forEach((voltage) => {
            worksheet_voltage.addRow({
                timeStamp:moment(voltage.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                voltage: voltage.voltage
            });
        });

        let filePath = path.resolve('documents/generated/', 'vallfa-' + deviceId + '.xlsx');

        generationResult.path = filePath;
        generationResult.result = eventLogger.eventResult.Success;

        await Promise.all([workbook.xlsx.writeFile(filePath)]);

        return generationResult;
    }
    catch (err) {
        logger.error('Error: ' + err.message + "\n\n"  + err.stack); generationResult.eventResult = eventLogger.eventResult.Failed;
        return generationResult;
    }
};






module.exports.szekerByDeviceIdBetweenTimestamps = async function (from, to, deviceId) {
    let generationResult = {eventType: eventLogger.eventType.Document, result: eventLogger.eventResult.Undefined, referenceIds: [], path: "UNDEFINED"};

    try {
        const [
            temperatures,
            humidity,
            pressure,
            weight,

            temperature_Ambient,
            temperature_Ambient_B,
            temperature_Ambient_C,
            temperature_Thermocouple,
            temperature_Thermocouple_B,
            temperature_Thermocouple_C,

            rfid,
            current,
            voltage
        ] = await Promise.all([
            db.getTemperatureOfDeviceBetweenTimeStamps(from, to, deviceId),

            db.getHumidityOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getPressureOfDeviceBetweenTimeStamps(from, to, deviceId),

            db.getScale_AvgWeightOfDeviceBetweenTimeStamps(from, to, deviceId),

            db.gettemperatureAmbientOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.gettemperature_B_AmbientOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.gettemperature_C_AmbientOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.gettemperatureThermocoupleOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.gettemperature_B_ThermocoupleOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.gettemperature_C_ThermocoupleOfDeviceBetweenTimeStamps(from, to, deviceId),

            db.getrfidOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getcurrentOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getvoltageOfDeviceBetweenTimeStamps(from, to, deviceId)
        ]);

        let workbook = new Excel.Workbook();
        let worksheet_temperature = workbook.addWorksheet('Hőmérséklet');
        let worksheet_humidity = workbook.addWorksheet('Páratartalom');
        let worksheet_pressure = workbook.addWorksheet('Légnyomás');
        let worksheet_weight = workbook.addWorksheet('Súly');
        let worksheet_rfid = workbook.addWorksheet('RFID');
        let worksheet_current = workbook.addWorksheet('Áramfelvétel');
        let worksheet_voltage = workbook.addWorksheet('Feszültség');

        let worksheet_temperature_Ambient = workbook.addWorksheet('temperature_Ambient');
        let worksheet_temperature_Ambient_B = workbook.addWorksheet('temperature_Ambient_B');
        let worksheet_temperature_Ambient_C = workbook.addWorksheet('temperature_Ambient_C');
        let worksheet_temperature_Thermocouple = workbook.addWorksheet('temperature_Thermocouple');
        let worksheet_temperature_Thermocouple_B = workbook.addWorksheet('temperature_Thermocouple_B');
        let worksheet_temperature_Thermocouple_C = workbook.addWorksheet('temperature_Thermocouple_C');

        let columns_temperature = [];
        columns_temperature.push({ header: 'Dátum',             key: 'timeStamp',                width: 32});
        columns_temperature.push({ header: 'Hőmérséklet',       key: 'temperature',               width: 32});
        worksheet_temperature.columns = columns_temperature;
        temperatures.forEach((temperature) => {
            worksheet_temperature.addRow({
                timeStamp:moment(temperature.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature: temperature.temperature
            });
        });

        let columns_humidity = [];
        columns_humidity.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_humidity.push({ header: 'Páratartalom',         key: 'humidity',               width: 32});
        worksheet_humidity.columns = columns_humidity;
        humidity.forEach((humidity) => {
            worksheet_humidity.addRow({
                timeStamp:moment(humidity.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                humidity: humidity.humidity
            });
        });

        let columns_pressure = [];
        columns_pressure.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_pressure.push({ header: 'Légnyomás',         key: 'pressure',               width: 32});
        worksheet_pressure.columns = columns_pressure;
        pressure.forEach((pressure) => {
            worksheet_pressure.addRow({
                timeStamp:moment(pressure.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                pressure: pressure.pressure
            });
        });

        let columns_weight = [];
        columns_weight.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_weight.push({ header: 'Súly',                 key: 'weight',               width: 32});
        worksheet_weight.columns = columns_weight;
        weight.forEach((weight) => {
            worksheet_weight.addRow({
                timeStamp:moment(weight.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                weight: weight.scale_AvgWeight
            });
        });

        let columns_rfid = [];
        columns_rfid.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_rfid.push({ header: 'RFID',                 key: 'rfid',               width: 32});
        worksheet_rfid.columns = columns_rfid;
        rfid.forEach((rfid) => {
            worksheet_rfid.addRow({
                timeStamp:moment(rfid.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                rfid: rfid.rfid
            });
        });

        let columns_current = [];
        columns_current.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_current.push({ header: 'Áramfelvétel',                 key: 'current',               width: 32});
        worksheet_current.columns = columns_current;
        current.forEach((current) => {
            worksheet_current.addRow({
                timeStamp:moment(current.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                current: current.current
            });
        });

        let columns_voltage = [];
        columns_voltage.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_voltage.push({ header: 'Feszültség',                 key: 'voltage',               width: 32});
        worksheet_voltage.columns = columns_voltage;
        voltage.forEach((voltage) => {
            worksheet_voltage.addRow({
                timeStamp:moment(voltage.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                voltage: voltage.voltage
            });
        });







        let columns_temperature_Ambient = [];
        columns_temperature_Ambient.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_temperature_Ambient.push({ header: 'temperature_Ambient',                 key: 'temperature_Ambient',               width: 32});
        worksheet_temperature_Ambient.columns = columns_temperature_Ambient;
        temperature_Ambient.forEach((temperature_Ambient) => {
            worksheet_temperature_Ambient.addRow({
                timeStamp:moment(temperature_Ambient.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature_Ambient: temperature_Ambient.temperatureAmbient
            });
        });

        let columns_temperature_Ambient_B = [];
        columns_temperature_Ambient_B.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_temperature_Ambient_B.push({ header: 'temperature_Ambient_B',                 key: 'temperature_Ambient_B',               width: 32});
        worksheet_temperature_Ambient_B.columns = columns_temperature_Ambient_B;
        temperature_Ambient_B.forEach((temperature_Ambient_B) => {
            worksheet_temperature_Ambient_B.addRow({
                timeStamp:moment(temperature_Ambient_B.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature_Ambient_B: temperature_Ambient_B.temperatureAmbient
            });
        });

        let columns_temperature_Ambient_C = [];
        columns_temperature_Ambient_C.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_temperature_Ambient_C.push({ header: 'temperature_Ambient_C',                 key: 'temperature_Ambient_C',               width: 32});
        worksheet_temperature_Ambient_C.columns = columns_temperature_Ambient_C;
        temperature_Ambient_C.forEach((temperature_Ambient_C) => {
            worksheet_temperature_Ambient_C.addRow({
                timeStamp:moment(temperature_Ambient_C.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature_Ambient_C: temperature_Ambient_C.temperatureAmbient
            });
        });

        let columns_temperature_Thermocouple = [];
        columns_temperature_Thermocouple.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_temperature_Thermocouple.push({ header: 'temperature_Thermocouple',                 key: 'temperature_Thermocouple',               width: 32});
        worksheet_temperature_Thermocouple.columns = columns_temperature_Thermocouple;
        temperature_Thermocouple.forEach((temperature_Thermocouple) => {
            worksheet_temperature_Thermocouple.addRow({
                timeStamp:moment(temperature_Thermocouple.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature_Thermocouple: temperature_Thermocouple.temperatureThermocouple
            });
        });

        let columns_temperature_Thermocouple_B = [];
        columns_temperature_Thermocouple_B.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_temperature_Thermocouple_B.push({ header: 'temperature_Thermocouple_B',                 key: 'temperature_Thermocouple_B',               width: 32});
        worksheet_temperature_Thermocouple_B.columns = columns_temperature_Thermocouple_B;
        temperature_Thermocouple_B.forEach((temperature_Thermocouple_B) => {
            worksheet_temperature_Thermocouple_B.addRow({
                timeStamp:moment(temperature_Thermocouple_B.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature_Thermocouple_B: temperature_Thermocouple_B.temperatureThermocouple
            });
        });

        let columns_temperature_Thermocouple_C = [];
        columns_temperature_Thermocouple_C.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_temperature_Thermocouple_C.push({ header: 'temperature_Thermocouple_C',                 key: 'temperature_Thermocouple_C',               width: 32});
        worksheet_temperature_Thermocouple_C.columns = columns_temperature_Thermocouple_C;
        temperature_Thermocouple_C.forEach((temperature_Thermocouple_C) => {
            worksheet_temperature_Thermocouple_C.addRow({
                timeStamp:moment(temperature_Thermocouple_C.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature_Thermocouple_C: temperature_Thermocouple_C.temperatureThermocouple
            });
        });




        let filePath = path.resolve('documents/generated/', 'szeker-' + deviceId+"-"+from+"-"+ to + '.xlsx');

        generationResult.path = filePath;
        generationResult.result = eventLogger.eventResult.Success;

        await Promise.all([workbook.xlsx.writeFile(filePath)]);

        return generationResult;
    }
    catch (err) {
        logger.error('Error: ' + err.message + "\n\n"  + err.stack); generationResult.eventResult = eventLogger.eventResult.Failed;
        return generationResult;
    }
};

module.exports.szekerByDeviceId = async function (deviceId) {
    let generationResult = {eventType: eventLogger.eventType.Document, result: eventLogger.eventResult.Undefined, referenceIds: [], path: "UNDEFINED"};

    try {
        const [
            temperatures,
            humidity,
            pressure,
            weight,

            temperature_Ambient,
            temperature_Ambient_B,
            temperature_Ambient_C,
            temperature_Thermocouple,
            temperature_Thermocouple_B,
            temperature_Thermocouple_C,

            rfid,
            current,
            voltage
        ] = await Promise.all([
            db.getTemperatureOfDevice(deviceId),
            db.getHumidityOfDevice(deviceId),
            db.getPressureOfDevice(deviceId),
            db.getScale_AvgWeightOfDevice(deviceId),
            db.gettemperatureAmbientOfDevice(deviceId),
            db.gettemperature_B_AmbientOfDevice(deviceId),
            db.gettemperature_C_AmbientOfDevice(deviceId),
            db.gettemperatureThermocoupleOfDevice(deviceId),
            db.gettemperature_B_ThermocoupleOfDevice(deviceId),
            db.gettemperature_C_ThermocoupleOfDevice(deviceId),
            db.getrfidOfDevice(deviceId),
            db.getcurrentOfDevice(deviceId),
            db.getvoltageOfDevice(deviceId)
        ]);

        let workbook = new Excel.Workbook();
        let worksheet_temperature = workbook.addWorksheet('Hőmérséklet');
        let worksheet_humidity = workbook.addWorksheet('Páratartalom');
        let worksheet_pressure = workbook.addWorksheet('Légnyomás');
        let worksheet_weight = workbook.addWorksheet('Súly');
        let worksheet_rfid = workbook.addWorksheet('RFID');
        let worksheet_current = workbook.addWorksheet('Áramfelvétel');
        let worksheet_voltage = workbook.addWorksheet('Feszültség');

        let worksheet_temperature_Ambient = workbook.addWorksheet('temperature_Ambient');
        let worksheet_temperature_Ambient_B = workbook.addWorksheet('temperature_Ambient_B');
        let worksheet_temperature_Ambient_C = workbook.addWorksheet('temperature_Ambient_C');
        let worksheet_temperature_Thermocouple = workbook.addWorksheet('temperature_Thermocouple');
        let worksheet_temperature_Thermocouple_B = workbook.addWorksheet('temperature_Thermocouple_B');
        let worksheet_temperature_Thermocouple_C = workbook.addWorksheet('temperature_Thermocouple_C');

        let columns_temperature = [];
        columns_temperature.push({ header: 'Dátum',             key: 'timeStamp',                width: 32});
        columns_temperature.push({ header: 'Hőmérséklet',       key: 'temperature',               width: 32});
        worksheet_temperature.columns = columns_temperature;
        temperatures.forEach((temperature) => {
            worksheet_temperature.addRow({
                timeStamp:moment(temperature.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature: temperature.temperature
            });
        });

        let columns_humidity = [];
        columns_humidity.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_humidity.push({ header: 'Páratartalom',         key: 'humidity',               width: 32});
        worksheet_humidity.columns = columns_humidity;
        humidity.forEach((humidity) => {
            worksheet_humidity.addRow({
                timeStamp:moment(humidity.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                humidity: humidity.humidity
            });
        });

        let columns_pressure = [];
        columns_pressure.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_pressure.push({ header: 'Légnyomás',         key: 'pressure',               width: 32});
        worksheet_pressure.columns = columns_pressure;
        pressure.forEach((pressure) => {
            worksheet_pressure.addRow({
                timeStamp:moment(pressure.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                pressure: pressure.pressure
            });
        });

        let columns_weight = [];
        columns_weight.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_weight.push({ header: 'Súly',                 key: 'weight',               width: 32});
        worksheet_weight.columns = columns_weight;
        weight.forEach((weight) => {
            worksheet_weight.addRow({
                timeStamp:moment(weight.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                weight: weight.scale_AvgWeight
            });
        });

        let columns_rfid = [];
        columns_rfid.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_rfid.push({ header: 'RFID',                 key: 'rfid',               width: 32});
        worksheet_rfid.columns = columns_rfid;
        rfid.forEach((rfid) => {
            worksheet_rfid.addRow({
                timeStamp:moment(rfid.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                rfid: rfid.rfid
            });
        });

        let columns_current = [];
        columns_current.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_current.push({ header: 'Áramfelvétel',                 key: 'current',               width: 32});
        worksheet_current.columns = columns_current;
        current.forEach((current) => {
            worksheet_current.addRow({
                timeStamp:moment(current.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                current: current.current
            });
        });

        let columns_voltage = [];
        columns_voltage.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_voltage.push({ header: 'Feszültség',                 key: 'voltage',               width: 32});
        worksheet_voltage.columns = columns_voltage;
        voltage.forEach((voltage) => {
            worksheet_voltage.addRow({
                timeStamp:moment(voltage.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                voltage: voltage.voltage
            });
        });







        let columns_temperature_Ambient = [];
        columns_temperature_Ambient.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_temperature_Ambient.push({ header: 'temperature_Ambient',                 key: 'temperature_Ambient',               width: 32});
        worksheet_temperature_Ambient.columns = columns_temperature_Ambient;
        temperature_Ambient.forEach((temperature_Ambient) => {
            worksheet_temperature_Ambient.addRow({
                timeStamp:moment(temperature_Ambient.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature_Ambient: temperature_Ambient.temperatureAmbient
            });
        });

        let columns_temperature_Ambient_B = [];
        columns_temperature_Ambient_B.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_temperature_Ambient_B.push({ header: 'temperature_Ambient_B',                 key: 'temperature_Ambient_B',               width: 32});
        worksheet_temperature_Ambient_B.columns = columns_temperature_Ambient_B;
        temperature_Ambient_B.forEach((temperature_Ambient_B) => {
            worksheet_temperature_Ambient_B.addRow({
                timeStamp:moment(temperature_Ambient_B.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature_Ambient_B: temperature_Ambient_B.temperatureAmbient
            });
        });

        let columns_temperature_Ambient_C = [];
        columns_temperature_Ambient_C.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_temperature_Ambient_C.push({ header: 'temperature_Ambient_C',                 key: 'temperature_Ambient_C',               width: 32});
        worksheet_temperature_Ambient_C.columns = columns_temperature_Ambient_C;
        temperature_Ambient_C.forEach((temperature_Ambient_C) => {
            worksheet_temperature_Ambient_C.addRow({
                timeStamp:moment(temperature_Ambient_C.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature_Ambient_C: temperature_Ambient_C.temperatureAmbient
            });
        });

        let columns_temperature_Thermocouple = [];
        columns_temperature_Thermocouple.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_temperature_Thermocouple.push({ header: 'temperature_Thermocouple',                 key: 'temperature_Thermocouple',               width: 32});
        worksheet_temperature_Thermocouple.columns = columns_temperature_Thermocouple;
        temperature_Thermocouple.forEach((temperature_Thermocouple) => {
            worksheet_temperature_Thermocouple.addRow({
                timeStamp:moment(temperature_Thermocouple.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature_Thermocouple: temperature_Thermocouple.temperatureThermocouple
            });
        });

        let columns_temperature_Thermocouple_B = [];
        columns_temperature_Thermocouple_B.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_temperature_Thermocouple_B.push({ header: 'temperature_Thermocouple_B',                 key: 'temperature_Thermocouple_B',               width: 32});
        worksheet_temperature_Thermocouple_B.columns = columns_temperature_Thermocouple_B;
        temperature_Thermocouple_B.forEach((temperature_Thermocouple_B) => {
            worksheet_temperature_Thermocouple_B.addRow({
                timeStamp:moment(temperature_Thermocouple_B.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature_Thermocouple_B: temperature_Thermocouple_B.temperatureThermocouple
            });
        });

        let columns_temperature_Thermocouple_C = [];
        columns_temperature_Thermocouple_C.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_temperature_Thermocouple_C.push({ header: 'temperature_Thermocouple_C',                 key: 'temperature_Thermocouple_C',               width: 32});
        worksheet_temperature_Thermocouple_C.columns = columns_temperature_Thermocouple_C;
        temperature_Thermocouple_C.forEach((temperature_Thermocouple_C) => {
            worksheet_temperature_Thermocouple_C.addRow({
                timeStamp:moment(temperature_Thermocouple_C.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature_Thermocouple_C: temperature_Thermocouple_C.temperatureThermocouple
            });
        });

        let filePath = path.resolve('documents/generated/', 'szeker-' + deviceId + '.xlsx');

        generationResult.path = filePath;
        generationResult.result = eventLogger.eventResult.Success;

        await Promise.all([workbook.xlsx.writeFile(filePath)]);

        return generationResult;
    }
    catch (err) {
        logger.error('Error: ' + err.message + "\n\n"  + err.stack); generationResult.eventResult = eventLogger.eventResult.Failed;
        return generationResult;
    }
};


module.exports.szurkalogepByDeviceIdBetweenTimestamps = async function (from, to, deviceId) {
    let generationResult = {eventType: eventLogger.eventType.Document, result: eventLogger.eventResult.Undefined, referenceIds: [], path: "UNDEFINED"};

    try {
        const [
            temperature_Thermocouple,
            rfid,
            Spect_A,
            Spect_B,
            Spect_C,
            Spect_D,
            Spect_E,
            Spect_F,
            Spect_G,
            Spect_H,
            Spect_I,
            Spect_J,
            Spect_K,
            Spect_L,
            Spect_R,
            Spect_S,
            Spect_T,
            Spect_U,
            Spect_V,
            Spect_W

        ] = await Promise.all([
            db.gettemperatureThermocoupleOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getrfidOfDeviceBetweenTimeStamps(from, to, deviceId),

            db.getSpect_AOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_BOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_COfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_DOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_EOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_FOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_GOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_HOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_IOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_JOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_KOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_LOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_ROfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_SOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_TOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_UOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_VOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_WOfDeviceBetweenTimeStamps(from, to, deviceId),

        ]);

        let workbook = new Excel.Workbook();

        let worksheet_rfid = workbook.addWorksheet('RFID');
        let worksheet_temperature_Thermocouple = workbook.addWorksheet('temperature_Thermocouple');

        let worksheet_Spect_A = workbook.addWorksheet('Spect_A');
        let worksheet_Spect_B = workbook.addWorksheet('Spect_B');
        let worksheet_Spect_C = workbook.addWorksheet('Spect_C');
        let worksheet_Spect_D = workbook.addWorksheet('Spect_D');
        let worksheet_Spect_E = workbook.addWorksheet('Spect_E');
        let worksheet_Spect_F = workbook.addWorksheet('Spect_F');
        let worksheet_Spect_G = workbook.addWorksheet('Spect_G');
        let worksheet_Spect_H = workbook.addWorksheet('Spect_H');
        let worksheet_Spect_I = workbook.addWorksheet('Spect_I');
        let worksheet_Spect_J = workbook.addWorksheet('Spect_J');
        let worksheet_Spect_K = workbook.addWorksheet('Spect_K');
        let worksheet_Spect_L = workbook.addWorksheet('Spect_L');
        let worksheet_Spect_R = workbook.addWorksheet('Spect_R');
        let worksheet_Spect_S = workbook.addWorksheet('Spect_S');
        let worksheet_Spect_T = workbook.addWorksheet('Spect_T');
        let worksheet_Spect_U = workbook.addWorksheet('Spect_U');
        let worksheet_Spect_V = workbook.addWorksheet('Spect_V');
        let worksheet_Spect_W = workbook.addWorksheet('Spect_W');

        let columns_rfid = [];
        columns_rfid.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_rfid.push({ header: 'RFID',                 key: 'rfid',               width: 32});
        worksheet_rfid.columns = columns_rfid;
        rfid.forEach((rfid) => {
            worksheet_rfid.addRow({
                timeStamp:moment(rfid.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                rfid: rfid.rfid
            });
        });

        let columns_temperature_Thermocouple = [];
        columns_temperature_Thermocouple.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_temperature_Thermocouple.push({ header: 'temperature_Thermocouple',                 key: 'temperature_Thermocouple',               width: 32});
        worksheet_temperature_Thermocouple.columns = columns_temperature_Thermocouple;
        temperature_Thermocouple.forEach((temperature_Thermocouple) => {
            worksheet_temperature_Thermocouple.addRow({
                timeStamp:moment(temperature_Thermocouple.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature_Thermocouple: temperature_Thermocouple.temperatureThermocouple
            });
        });

        let columns_Spect_A = [];
        columns_Spect_A.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_A.push({ header: 'Spect_A',              key: 'value',               width: 32});
        worksheet_Spect_A.columns = columns_Spect_A;
        Spect_A.forEach((spect) => {worksheet_Spect_A.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_A});});

        let columns_Spect_B = [];
        columns_Spect_B.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_B.push({ header: 'Spect_B',              key: 'value',               width: 32});
        worksheet_Spect_B.columns = columns_Spect_B;
        Spect_B.forEach((spect) => {worksheet_Spect_B.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_B});});

        let columns_Spect_C = [];
        columns_Spect_C.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_C.push({ header: 'Spect_C',              key: 'value',               width: 32});
        worksheet_Spect_C.columns = columns_Spect_C;
        Spect_C.forEach((spect) => {worksheet_Spect_C.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_C});});

        let columns_Spect_D = [];
        columns_Spect_D.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_D.push({ header: 'Spect_D',              key: 'value',               width: 32});
        worksheet_Spect_D.columns = columns_Spect_D;
        Spect_D.forEach((spect) => {worksheet_Spect_D.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_D});});

        let columns_Spect_E = [];
        columns_Spect_E.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_E.push({ header: 'Spect_E',              key: 'value',               width: 32});
        worksheet_Spect_E.columns = columns_Spect_E;
        Spect_E.forEach((spect) => {worksheet_Spect_E.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_E});});

        let columns_Spect_F = [];
        columns_Spect_F.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_F.push({ header: 'Spect_F',              key: 'value',               width: 32});
        worksheet_Spect_F.columns = columns_Spect_F;
        Spect_F.forEach((spect) => {worksheet_Spect_F.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_F});});

        let columns_Spect_G = [];
        columns_Spect_G.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_G.push({ header: 'Spect_G',              key: 'value',               width: 32});
        worksheet_Spect_G.columns = columns_Spect_G;
        Spect_G.forEach((spect) => {worksheet_Spect_G.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_G});});

        let columns_Spect_H = [];
        columns_Spect_H.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_H.push({ header: 'Spect_H',              key: 'value',               width: 32});
        worksheet_Spect_H.columns = columns_Spect_H;
        Spect_H.forEach((spect) => {worksheet_Spect_H.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_H});});

        let columns_Spect_I = [];
        columns_Spect_I.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_I.push({ header: 'Spect_I',              key: 'value',               width: 32});
        worksheet_Spect_I.columns = columns_Spect_I;
        Spect_I.forEach((spect) => {worksheet_Spect_I.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_I});});

        let columns_Spect_J = [];
        columns_Spect_J.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_J.push({ header: 'Spect_J',              key: 'value',               width: 32});
        worksheet_Spect_J.columns = columns_Spect_J;
        Spect_J.forEach((spect) => {worksheet_Spect_J.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_J});});

        let columns_Spect_K = [];
        columns_Spect_K.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_K.push({ header: 'Spect_K',              key: 'value',               width: 32});
        worksheet_Spect_K.columns = columns_Spect_K;
        Spect_K.forEach((spect) => {worksheet_Spect_K.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_K});});

        let columns_Spect_L = [];
        columns_Spect_L.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_L.push({ header: 'Spect_L',              key: 'value',               width: 32});
        worksheet_Spect_L.columns = columns_Spect_L;
        Spect_L.forEach((spect) => {worksheet_Spect_L.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_L});});

        let columns_Spect_R = [];
        columns_Spect_R.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_R.push({ header: 'Spect_R',              key: 'value',               width: 32});
        worksheet_Spect_R.columns = columns_Spect_R;
        Spect_R.forEach((spect) => {worksheet_Spect_R.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_R});});

        let columns_Spect_S = [];
        columns_Spect_S.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_S.push({ header: 'Spect_S',              key: 'value',               width: 32});
        worksheet_Spect_S.columns = columns_Spect_S;
        Spect_S.forEach((spect) => {worksheet_Spect_S.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_S});});

        let columns_Spect_T = [];
        columns_Spect_T.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_T.push({ header: 'Spect_T',              key: 'value',               width: 32});
        worksheet_Spect_T.columns = columns_Spect_T;
        Spect_T.forEach((spect) => {worksheet_Spect_T.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_T});});

        let columns_Spect_U = [];
        columns_Spect_U.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_U.push({ header: 'Spect_U',              key: 'value',               width: 32});
        worksheet_Spect_U.columns = columns_Spect_U;
        Spect_U.forEach((spect) => {worksheet_Spect_U.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_U});});

        let columns_Spect_V = [];
        columns_Spect_V.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_V.push({ header: 'Spect_V',              key: 'value',               width: 32});
        worksheet_Spect_V.columns = columns_Spect_V;
        Spect_V.forEach((spect) => {worksheet_Spect_V.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_V});});

        let columns_Spect_W = [];
        columns_Spect_W.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_W.push({ header: 'Spect_W',              key: 'value',               width: 32});
        worksheet_Spect_W.columns = columns_Spect_W;
        Spect_W.forEach((spect) => {worksheet_Spect_W.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_W});});

        let filePath = path.resolve('documents/generated/', 'vallfa-' + deviceId+"-"+from+"-"+ to + '.xlsx');

        generationResult.path = filePath;
        generationResult.result = eventLogger.eventResult.Success;

        await Promise.all([workbook.xlsx.writeFile(filePath)]);

        return generationResult;
    }
    catch (err) {
        logger.error('Error: ' + err.message + "\n\n"  + err.stack); generationResult.eventResult = eventLogger.eventResult.Failed;
        return generationResult;
    }
};

module.exports.szurkalogepByDeviceId = async function (deviceId) {
    let generationResult = {eventType: eventLogger.eventType.Document, result: eventLogger.eventResult.Undefined, referenceIds: [], path: "UNDEFINED"};

    try {
        const [
            temperature_Thermocouple,
            rfid,
            Spect_A,
            Spect_B,
            Spect_C,
            Spect_D,
            Spect_E,
            Spect_F,
            Spect_G,
            Spect_H,
            Spect_I,
            Spect_J,
            Spect_K,
            Spect_L,
            Spect_R,
            Spect_S,
            Spect_T,
            Spect_U,
            Spect_V,
            Spect_W

        ] = await Promise.all([
            db.gettemperatureThermocoupleOfDevice(deviceId),
            db.getrfidOfDevice(deviceId),

            db.getSpect_AOfDevice(deviceId),
            db.getSpect_BOfDevice(deviceId),
            db.getSpect_COfDevice(deviceId),
            db.getSpect_DOfDevice(deviceId),
            db.getSpect_EOfDevice(deviceId),
            db.getSpect_FOfDevice(deviceId),
            db.getSpect_GOfDevice(deviceId),
            db.getSpect_HOfDevice(deviceId),
            db.getSpect_IOfDevice(deviceId),
            db.getSpect_JOfDevice(deviceId),
            db.getSpect_KOfDevice(deviceId),
            db.getSpect_LOfDevice(deviceId),
            db.getSpect_ROfDevice(deviceId),
            db.getSpect_SOfDevice(deviceId),
            db.getSpect_TOfDevice(deviceId),
            db.getSpect_UOfDevice(deviceId),
            db.getSpect_VOfDevice(deviceId),
            db.getSpect_WOfDevice(deviceId),

        ]);

        let workbook = new Excel.Workbook();

        let worksheet_rfid = workbook.addWorksheet('RFID');
        let worksheet_temperature_Thermocouple = workbook.addWorksheet('temperature_Thermocouple');

        let worksheet_Spect_A = workbook.addWorksheet('Spect_A');
        let worksheet_Spect_B = workbook.addWorksheet('Spect_B');
        let worksheet_Spect_C = workbook.addWorksheet('Spect_C');
        let worksheet_Spect_D = workbook.addWorksheet('Spect_D');
        let worksheet_Spect_E = workbook.addWorksheet('Spect_E');
        let worksheet_Spect_F = workbook.addWorksheet('Spect_F');
        let worksheet_Spect_G = workbook.addWorksheet('Spect_G');
        let worksheet_Spect_H = workbook.addWorksheet('Spect_H');
        let worksheet_Spect_I = workbook.addWorksheet('Spect_I');
        let worksheet_Spect_J = workbook.addWorksheet('Spect_J');
        let worksheet_Spect_K = workbook.addWorksheet('Spect_K');
        let worksheet_Spect_L = workbook.addWorksheet('Spect_L');
        let worksheet_Spect_R = workbook.addWorksheet('Spect_R');
        let worksheet_Spect_S = workbook.addWorksheet('Spect_S');
        let worksheet_Spect_T = workbook.addWorksheet('Spect_T');
        let worksheet_Spect_U = workbook.addWorksheet('Spect_U');
        let worksheet_Spect_V = workbook.addWorksheet('Spect_V');
        let worksheet_Spect_W = workbook.addWorksheet('Spect_W');

        let columns_rfid = [];
        columns_rfid.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_rfid.push({ header: 'RFID',                 key: 'rfid',               width: 32});
        worksheet_rfid.columns = columns_rfid;
        rfid.forEach((rfid) => {
            worksheet_rfid.addRow({
                timeStamp:moment(rfid.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                rfid: rfid.rfid
            });
        });

        let columns_temperature_Thermocouple = [];
        columns_temperature_Thermocouple.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_temperature_Thermocouple.push({ header: 'temperature_Thermocouple',                 key: 'temperature_Thermocouple',               width: 32});
        worksheet_temperature_Thermocouple.columns = columns_temperature_Thermocouple;
        temperature_Thermocouple.forEach((temperature_Thermocouple) => {
            worksheet_temperature_Thermocouple.addRow({
                timeStamp:moment(temperature_Thermocouple.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature_Thermocouple: temperature_Thermocouple.temperatureThermocouple
            });
        });

        let columns_Spect_A = [];
        columns_Spect_A.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_A.push({ header: 'Spect_A',              key: 'value',               width: 32});
        worksheet_Spect_A.columns = columns_Spect_A;
        Spect_A.forEach((spect) => {worksheet_Spect_A.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_A});});

        let columns_Spect_B = [];
        columns_Spect_B.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_B.push({ header: 'Spect_B',              key: 'value',               width: 32});
        worksheet_Spect_B.columns = columns_Spect_B;
        Spect_B.forEach((spect) => {worksheet_Spect_B.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_B});});

        let columns_Spect_C = [];
        columns_Spect_C.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_C.push({ header: 'Spect_C',              key: 'value',               width: 32});
        worksheet_Spect_C.columns = columns_Spect_C;
        Spect_C.forEach((spect) => {worksheet_Spect_C.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_C});});

        let columns_Spect_D = [];
        columns_Spect_D.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_D.push({ header: 'Spect_D',              key: 'value',               width: 32});
        worksheet_Spect_D.columns = columns_Spect_D;
        Spect_D.forEach((spect) => {worksheet_Spect_D.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_D});});

        let columns_Spect_E = [];
        columns_Spect_E.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_E.push({ header: 'Spect_E',              key: 'value',               width: 32});
        worksheet_Spect_E.columns = columns_Spect_E;
        Spect_E.forEach((spect) => {worksheet_Spect_E.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_E});});

        let columns_Spect_F = [];
        columns_Spect_F.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_F.push({ header: 'Spect_F',              key: 'value',               width: 32});
        worksheet_Spect_F.columns = columns_Spect_F;
        Spect_F.forEach((spect) => {worksheet_Spect_F.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_F});});

        let columns_Spect_G = [];
        columns_Spect_G.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_G.push({ header: 'Spect_G',              key: 'value',               width: 32});
        worksheet_Spect_G.columns = columns_Spect_G;
        Spect_G.forEach((spect) => {worksheet_Spect_G.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_G});});

        let columns_Spect_H = [];
        columns_Spect_H.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_H.push({ header: 'Spect_H',              key: 'value',               width: 32});
        worksheet_Spect_H.columns = columns_Spect_H;
        Spect_H.forEach((spect) => {worksheet_Spect_H.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_H});});

        let columns_Spect_I = [];
        columns_Spect_I.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_I.push({ header: 'Spect_I',              key: 'value',               width: 32});
        worksheet_Spect_I.columns = columns_Spect_I;
        Spect_I.forEach((spect) => {worksheet_Spect_I.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_I});});

        let columns_Spect_J = [];
        columns_Spect_J.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_J.push({ header: 'Spect_J',              key: 'value',               width: 32});
        worksheet_Spect_J.columns = columns_Spect_J;
        Spect_J.forEach((spect) => {worksheet_Spect_J.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_J});});

        let columns_Spect_K = [];
        columns_Spect_K.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_K.push({ header: 'Spect_K',              key: 'value',               width: 32});
        worksheet_Spect_K.columns = columns_Spect_K;
        Spect_K.forEach((spect) => {worksheet_Spect_K.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_K});});

        let columns_Spect_L = [];
        columns_Spect_L.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_L.push({ header: 'Spect_L',              key: 'value',               width: 32});
        worksheet_Spect_L.columns = columns_Spect_L;
        Spect_L.forEach((spect) => {worksheet_Spect_L.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_L});});

        let columns_Spect_R = [];
        columns_Spect_R.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_R.push({ header: 'Spect_R',              key: 'value',               width: 32});
        worksheet_Spect_R.columns = columns_Spect_R;
        Spect_R.forEach((spect) => {worksheet_Spect_R.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_R});});

        let columns_Spect_S = [];
        columns_Spect_S.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_S.push({ header: 'Spect_S',              key: 'value',               width: 32});
        worksheet_Spect_S.columns = columns_Spect_S;
        Spect_S.forEach((spect) => {worksheet_Spect_S.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_S});});

        let columns_Spect_T = [];
        columns_Spect_T.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_T.push({ header: 'Spect_T',              key: 'value',               width: 32});
        worksheet_Spect_T.columns = columns_Spect_T;
        Spect_T.forEach((spect) => {worksheet_Spect_T.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_T});});

        let columns_Spect_U = [];
        columns_Spect_U.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_U.push({ header: 'Spect_U',              key: 'value',               width: 32});
        worksheet_Spect_U.columns = columns_Spect_U;
        Spect_U.forEach((spect) => {worksheet_Spect_U.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_U});});

        let columns_Spect_V = [];
        columns_Spect_V.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_V.push({ header: 'Spect_V',              key: 'value',               width: 32});
        worksheet_Spect_V.columns = columns_Spect_V;
        Spect_V.forEach((spect) => {worksheet_Spect_V.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_V});});

        let columns_Spect_W = [];
        columns_Spect_W.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_Spect_W.push({ header: 'Spect_W',              key: 'value',               width: 32});
        worksheet_Spect_W.columns = columns_Spect_W;
        Spect_W.forEach((spect) => {worksheet_Spect_W.addRow({timeStamp:moment(spect.timeStamp).format("YYYY.MM.DD. HH:mm:ss"), value: spect.spect_W});});

        let filePath = path.resolve('documents/generated/', 'vallfa-' + deviceId + '.xlsx');

        generationResult.path = filePath;
        generationResult.result = eventLogger.eventResult.Success;

        await Promise.all([workbook.xlsx.writeFile(filePath)]);

        return generationResult;
    }
    catch (err) {
        logger.error('Error: ' + err.message + "\n\n"  + err.stack); generationResult.eventResult = eventLogger.eventResult.Failed;
        return generationResult;
    }
};




module.exports.sisakByDeviceIdBetweenTimestamps = async function (from, to, deviceId) {
    let generationResult = {eventType: eventLogger.eventType.Document, result: eventLogger.eventResult.Undefined, referenceIds: [], path: "UNDEFINED"};

    try {
        const [
            temperatures,
            humidity,
            heartRate,
            oxygen,
            current,
            voltage
        ] = await Promise.all([
            db.getTemperatureOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getHumidityOfDeviceBetweenTimeStamps(from, to, deviceId),

            db.getHR_heartRateOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getHR_oxygenOfDeviceBetweenTimeStamps(from, to, deviceId),

            db.getcurrentOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getvoltageOfDeviceBetweenTimeStamps(from, to, deviceId)
        ]);

        let workbook = new Excel.Workbook();
        let worksheet_temperature = workbook.addWorksheet('Hőmérséklet');
        let worksheet_humidity = workbook.addWorksheet('Páratartalom');

        let worksheet_heartRate = workbook.addWorksheet('Pulzus');
        let worksheet_oxygen = workbook.addWorksheet('Véroxigén szint');

        let worksheet_current = workbook.addWorksheet('Áramfelvétel');
        let worksheet_voltage = workbook.addWorksheet('Feszültség');

        let columns_temperature = [];
        columns_temperature.push({ header: 'Dátum',             key: 'timeStamp',                width: 32});
        columns_temperature.push({ header: 'Hőmérséklet',       key: 'temperature',               width: 32});
        worksheet_temperature.columns = columns_temperature;
        temperatures.forEach((temperature) => {
            worksheet_temperature.addRow({
                timeStamp:moment(temperature.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature: temperature.temperature
            });
        });

        let columns_humidity = [];
        columns_humidity.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_humidity.push({ header: 'Páratartalom',         key: 'humidity',               width: 32});
        worksheet_humidity.columns = columns_humidity;
        humidity.forEach((humidity) => {
            worksheet_humidity.addRow({
                timeStamp:moment(humidity.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                humidity: humidity.humidity
            });
        });

        let columns_heartRate = [];
        columns_heartRate.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_heartRate.push({ header: 'Pulzus',         key: 'heartRate',               width: 32});
        worksheet_heartRate.columns = columns_heartRate;
        heartRate.forEach((heartRate) => {
            worksheet_heartRate.addRow({
                timeStamp:moment(heartRate.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                heartRate: heartRate.hr_heartRate
            });
        });

        let columns_oxygen = [];
        columns_oxygen.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_oxygen.push({ header: 'Véroxigén szint',                 key: 'oxygen',               width: 32});
        worksheet_oxygen.columns = columns_oxygen;
        oxygen.forEach((oxygen) => {
            worksheet_oxygen.addRow({
                timeStamp:moment(oxygen.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                oxygen: oxygen.hr_oxygen
            });
        });
        
        let columns_current = [];
        columns_current.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_current.push({ header: 'Áramfelvétel',                 key: 'current',               width: 32});
        worksheet_current.columns = columns_current;
        current.forEach((current) => {
            worksheet_current.addRow({
                timeStamp:moment(current.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                current: current.current
            });
        });

        let columns_voltage = [];
        columns_voltage.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_voltage.push({ header: 'Feszültség',                 key: 'voltage',               width: 32});
        worksheet_voltage.columns = columns_voltage;
        voltage.forEach((voltage) => {
            worksheet_voltage.addRow({
                timeStamp:moment(voltage.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                voltage: voltage.voltage
            });
        });

        let filePath = path.resolve('documents/generated/', 'vallfa-' + deviceId+"-"+from+"-"+ to + '.xlsx');

        generationResult.path = filePath;
        generationResult.result = eventLogger.eventResult.Success;

        await Promise.all([workbook.xlsx.writeFile(filePath)]);

        return generationResult;
    }
    catch (err) {
        logger.error('Error: ' + err.message + "\n\n"  + err.stack); generationResult.eventResult = eventLogger.eventResult.Failed;
        return generationResult;
    }
};

module.exports.sisakByDeviceId = async function (deviceId) {
    let generationResult = {eventType: eventLogger.eventType.Document, result: eventLogger.eventResult.Undefined, referenceIds: [], path: "UNDEFINED"};

    try {
        const [
            temperatures,
            humidity,
            heartRate,
            oxygen,
            current,
            voltage
        ] = await Promise.all([
            db.getTemperatureOfDevice(deviceId),
            db.getHumidityOfDevice(deviceId),

            db.getHR_heartRateOfDevice(deviceId),
            db.getHR_oxygenOfDevice(deviceId),

            db.getcurrentOfDevice(deviceId),
            db.getvoltageOfDevice(deviceId)
        ]);

        let workbook = new Excel.Workbook();
        let worksheet_temperature = workbook.addWorksheet('Hőmérséklet');
        let worksheet_humidity = workbook.addWorksheet('Páratartalom');

        let worksheet_heartRate = workbook.addWorksheet('Pulzus');
        let worksheet_oxygen = workbook.addWorksheet('Véroxigén szint');

        let worksheet_current = workbook.addWorksheet('Áramfelvétel');
        let worksheet_voltage = workbook.addWorksheet('Feszültség');

        let columns_temperature = [];
        columns_temperature.push({ header: 'Dátum',             key: 'timeStamp',                width: 32});
        columns_temperature.push({ header: 'Hőmérséklet',       key: 'temperature',               width: 32});
        worksheet_temperature.columns = columns_temperature;
        temperatures.forEach((temperature) => {
            worksheet_temperature.addRow({
                timeStamp:moment(temperature.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                temperature: temperature.temperature
            });
        });

        let columns_humidity = [];
        columns_humidity.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_humidity.push({ header: 'Páratartalom',         key: 'humidity',               width: 32});
        worksheet_humidity.columns = columns_humidity;
        humidity.forEach((humidity) => {
            worksheet_humidity.addRow({
                timeStamp:moment(humidity.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                humidity: humidity.humidity
            });
        });

        let columns_heartRate = [];
        columns_heartRate.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_heartRate.push({ header: 'Pulzus',               key: 'heartRate',               width: 32});
        worksheet_heartRate.columns = columns_heartRate;
        heartRate.forEach((heartRate) => {
            worksheet_heartRate.addRow({
                timeStamp:moment(heartRate.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                heartRate: heartRate.hr_heartRate
            });
        });

        let columns_oxygen = [];
        columns_oxygen.push({ header: 'Dátum',                   key: 'timeStamp',                width: 32});
        columns_oxygen.push({ header: 'Véroxigén szint',         key: 'oxygen',               width: 32});
        worksheet_oxygen.columns = columns_oxygen;
        oxygen.forEach((oxygen) => {
            worksheet_oxygen.addRow({
                timeStamp:moment(oxygen.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                oxygen: oxygen.hr_oxygen
            });
        });

        let columns_current = [];
        columns_current.push({ header: 'Dátum',                 key: 'timeStamp',                width: 32});
        columns_current.push({ header: 'Áramfelvétel',          key: 'current',               width: 32});
        worksheet_current.columns = columns_current;
        current.forEach((current) => {
            worksheet_current.addRow({
                timeStamp:moment(current.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                current: current.current
            });
        });

        let columns_voltage = [];
        columns_voltage.push({ header: 'Dátum',                key: 'timeStamp',                width: 32});
        columns_voltage.push({ header: 'Feszültség',                 key: 'voltage',               width: 32});
        worksheet_voltage.columns = columns_voltage;
        voltage.forEach((voltage) => {
            worksheet_voltage.addRow({
                timeStamp:moment(voltage.timeStamp).format("YYYY.MM.DD. HH:mm:ss"),
                voltage: voltage.voltage
            });
        });

        let filePath = path.resolve('documents/generated/', 'vallfa-' + deviceId + '.xlsx');

        generationResult.path = filePath;
        generationResult.result = eventLogger.eventResult.Success;

        await Promise.all([workbook.xlsx.writeFile(filePath)]);

        return generationResult;
    }
    catch (err) {
        logger.error('Error: ' + err.message + "\n\n"  + err.stack); generationResult.eventResult = eventLogger.eventResult.Failed;
        return generationResult;
    }
};


