const { createLogger, format, transports } = require('winston');
require('winston-daily-rotate-file');
const fs = require('fs');
const path = require('path');

const env = process.env.NODE_ENV || 'development';
const logDir = 'log';
const importDataLogDir = 'importationLog';

// Create the log directory if it does not exist
if (!fs.existsSync(logDir)) {fs.mkdirSync(logDir);}

const dailyRotateFileTransport = new transports.DailyRotateFile({
    filename: `${logDir}/%DATE%-results.log`,
    datePattern: 'YYYY-MM-DD'
});

const logger = createLogger({
    // change level if in dev environment versus production
    level: env === 'development' ? 'verbose' : 'info',
    format: format.combine(
        format.timestamp({format: 'YYYY-MM-DD HH:mm:ss'}),
        format.printf(info => `${info.timestamp} ${info.level}: ${info.message}`)
    ),
    transports: [

        new transports.Console({
            level: 'error',
            format: format.combine(
                format.colorize(),
                format.printf(info => `${info.timestamp} ${info.level}: ${info.message}`)
            )
        }),

        dailyRotateFileTransport,

        //new transports.File({filename: `${importDataLogDir}/import.log`, level:'warn'})

    ]
});

logger.stream = {write: function(message, encoding) {logger.info(message);}};

module.exports = logger;
