'use strict';

let dataSet_TableUpdateTimes = [],

    dataSet_DecaWaveData = [],

    mapWidth_px = 950, mapHeight_px = 950,
    mapWidth_m = 3.8, mapHeight_m = 3.8,

    xscale,  yscale,  map,
    imagelayer,  heatmap,  vectorfield,  pathplot,  overlays,
    mapdata = {},

    dataSet_AtmosphericData = [],

    dataSet_temperature = [],
    dataSet_humidity = [],
    dataSet_pressure = [],

    dataSet_rfid = [],
    dataSet_current = [],
    dataSet_voltage = [],

    dataSet_button_Green = [],
    dataSet_button_Red = [],

    dataSet_hr_confidence = [],
    dataSet_hr_extStatus = [],
    dataSet_hr_heartRate = [],
    dataSet_hr_irLed = [],
    dataSet_hr_oxygen = [],
    dataSet_hr_redLed = [],
    dataSet_hr_rValue = [],
    dataSet_hr_status = [],

    dataSet_scale_AvgWeight = [],
    dataSet_scale_CalibrationDate = [],
    dataSet_scale_CalibrationFactor = [],
    dataSet_scale_Reading = [],
    dataSet_scale_Weight = [],
    dataSet_scale_ZeroOffset = [],

    dataSet_pwm = [],

    dataSet_voiceRecognition = [],

    chart_oxygen,
    chart_temperature,
    chart_humidity,
    chart_heartRate,

    colorOfOxygen = "#75B4FF",
    colorOfTemperature = "#60C173",
    colorOfHeartRate = "#FFB442",
    colorOfHumidity = "#FF6B72",

    selectedDataSource = "temperature",
    selectedDeviceId = null,

    dataDurationInMilliseconds = 10*1000,

    layoutType = "SISAK",

    timeToBakcAtStart = -10 // !! minute
;

$(document).ready(function() {
    enumerationRefreshCallbacks.push(refreshEnumerationUsersOnSisakLive);

    if(displayMode == "NORMAL") {
        $('#btn_Sisak').hide();
        $('#btn_Vallfa').show();
        $('#btn_Szeker').show();
        $('#btn_Szurka').show();
    } else {
        $('#btn_Sisak').show()
        $('#btn_Vallfa').hide();
        $('#btn_Szeker').hide();
        $('#btn_Szurka').hide();
    }

    kvpRefreshCallbacks.push(refreshKVPsOnSisakLive);

    var colorSchemes = Chart.colorschemes;

    $('#dataDuration_10s').on('click', function () {refreshChartDuration(10);});
    $('#dataDuration_01m').on('click', function () {refreshChartDuration(1*60);});
    $('#dataDuration_05m').on('click', function () {refreshChartDuration(5*60);});
    $('#dataDuration_10m').on('click', function () {refreshChartDuration(10*60);});



    $('#btnSaveSettings').on('click', function () {saveSettings();});
    $('#modalSettings').on('shown.bs.modal', function (e) {$('#modalSettings_Pos_1_x').focus();});

    //region Charts
    chart_temperature = new Chart(document.getElementById("chart-temperature").getContext('2d'), {
        type: 'line',
        responsive: true,
        data: {datasets: [{data: [], label: 'Dataset 1', type: 'line', fill: false},]},
        options: {
            barValueSpacing: 20,
            maintainAspectRatio: false,
            tooltips: {mode: 'nearest', intersect: false},
            legend: {display: false},
            hover: {mode: 'nearest', intersect: false},
            pan: {enabled: false, mode: 'x', rangeMax: {x: 4000}, rangeMin: {x: 0}},
            zoom: {enabled: false, mode: 'x', rangeMax: {x: 20000}, rangeMin: {x: 1000}},
            scales: {
                xAxes: [{
                    type: 'realtime',
                    time: {isoWeekday: true, tooltipFormat: 'YYYY.MM.DD. HH:mm:ss.SSS', displayFormats: {'millisecond': 'HH:mm:ss', 'second': 'HH:mm:ss', 'minute': 'HH:mm:ss', 'hour': 'MM.DD. HH:mm:ss', 'day': 'MM.DD. HH:mm', 'week': 'MM.DD.', 'month': 'YYYY.MM.DD.', 'quarter': 'YYYY.MM.DD.', 'year': 'YYYY.',}},
                    realtime: {
                        delay: 2000,
                        duration: dataDurationInMilliseconds,
                        refresh: 1000,
                        onRefresh: function(chart) {

                            /* chart.data.datasets.forEach(function(dataset) {
                                 dataset.data.push({
                                     x: Date.now(),
                                     y: Math.random()
                                 });
                             });*/

                        }
                    }
                }],
                yAxes: [{ticks : {min: 0, max: 40,}}]
            },
            plugins: {},
            annotation: {annotations: [
                    {type: 'box', id: 'limits', xScaleID: 'x-axis-0', yScaleID: 'y-axis-0', yMax: 0.0, yMin:  0.0, borderColor: '#60C173', borderWidth: 2, backgroundColor: '#60C17355',},
                    {type: 'line',id: 'min', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Min.: 0"},},
                    {type: 'line',id: 'max', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Max.: 0"},},
                    {type: 'line',id: 'avg', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Átl.: 0.00"},},
                ]}
        }
    });
    chart_humidity = new Chart(document.getElementById("chart-humidity").getContext('2d'), {
        type: 'line',
        responsive: true,
        data: {datasets: [{data: [], label: 'Dataset 1', type: 'line', fill: false,},]},
        options: {
            barValueSpacing: 20,
            maintainAspectRatio: false,
            tooltips: {mode: 'nearest', intersect: false},
            legend: {display: false},
            hover: {mode: 'nearest', intersect: false},
            pan: {enabled: false, mode: 'x', rangeMax: {x: 4000}, rangeMin: {x: 0}},
            zoom: {enabled: false, mode: 'x', rangeMax: {x: 20000}, rangeMin: {x: 1000}},
            scales: {
                xAxes: [{
                    type: 'realtime',
                    time: {isoWeekday: true, tooltipFormat: 'YYYY.MM.DD. HH:mm:ss.SSS', displayFormats: {'millisecond': 'HH:mm:ss', 'second': 'HH:mm:ss', 'minute': 'HH:mm:ss', 'hour': 'MM.DD. HH:mm:ss', 'day': 'MM.DD. HH:mm', 'week': 'MM.DD.', 'month': 'YYYY.MM.DD.', 'quarter': 'YYYY.MM.DD.', 'year': 'YYYY.',}},
                    realtime: {
                        delay: 2000,
                        duration: dataDurationInMilliseconds,
                        refresh: 1000,

                    }
                }],
                yAxes: [{ticks : {min: 0, max: 100,}}]
            },
            plugins: {colorschemes: {scheme: 'brewer.OrRd3'}},
            annotation: {annotations: [
                    {type: 'box', id: 'limits', xScaleID: 'x-axis-0', yScaleID: 'y-axis-0', yMax: 0.0, yMin:  0.0, borderColor: '#60C173', borderWidth: 2, backgroundColor: '#60C17355',},
                    {type: 'line',id: 'min', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Min.: 0"},},
                    {type: 'line',id: 'max', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Max.: 0"},},
                    {type: 'line',id: 'avg', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Átl.: 0.00"},},
                ]}
        }
    });
    chart_oxygen = new Chart(document.getElementById("chart-oxygen").getContext('2d'), {
        type: 'line',
        responsive: true,
        data: {datasets: [{data: [], label: 'Dataset 1', type: 'line', fill: false,},]},
        options: {
            barValueSpacing: 20,
            maintainAspectRatio: false,
            tooltips: {mode: 'nearest', intersect: false},
            legend: {display: false},
            hover: {mode: 'nearest', intersect: false},
            pan: {enabled: false, mode: 'x', rangeMax: {x: 4000}, rangeMin: {x: 0}},
            zoom: {enabled: false, mode: 'x', rangeMax: {x: 20000}, angeMin: {x: 1000}},
            scales: {
                xAxes: [{
                    type: 'realtime',
                    time: {
                        isoWeekday: true,
                        tooltipFormat: 'YYYY.MM.DD. HH:mm:ss',
                        displayFormats: {'millisecond': 'HH:mm:ss', 'second': 'HH:mm:ss', 'minute': 'HH:mm:ss', 'hour': 'MM.DD. HH:mm:ss', 'day': 'MM.DD. HH:mm', 'week': 'MM.DD.', 'month': 'YYYY.MM.DD.', 'quarter': 'YYYY.MM.DD.', 'year': 'YYYY.',}
                        },
                    realtime: {
                        delay: 2000,
                        duration: dataDurationInMilliseconds,
                        refresh: 1000,
                        onRefresh: function(chart) {}
                    }
                }],
                yAxes: [{ticks : {min: 0, max: 100,}}]
            },
            plugins: {colorschemes: {scheme: 'tableau.Tableau20'}},
            annotation: {annotations: [
                    {type: 'line',id: 'min', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Min.: 0"},},
                    {type: 'line',id: 'max', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Max.: 0"},},
                    {type: 'line',id: 'avg', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Átl.: 0.00"},},
                ]}
        }
    });
    chart_heartRate = new Chart(document.getElementById("chart-pulse").getContext('2d'), {
        type: 'line',
        responsive: true,
        data: {datasets: [{data: [], label: 'Dataset 1', type: 'line', fill: false,},]},
        options: {
            barValueSpacing: 20,
            maintainAspectRatio: false,
            tooltips: {mode: 'nearest', intersect: false},
            legend: {display: false},
            hover: {mode: 'nearest', intersect: false},
            pan: {enabled: false, mode: 'x', rangeMax: {x: 4000}, rangeMin: {x: 0}},
            zoom: {enabled: false, mode: 'x', rangeMax: {x: 20000}, rangeMin: {x: 1000}},
            scales: {
                xAxes: [{
                    type: 'realtime',
                    time: {isoWeekday: true, tooltipFormat: 'YYYY.MM.DD. HH:mm:ss.SSS', displayFormats: {'millisecond': 'HH:mm:ss', 'second': 'HH:mm:ss', 'minute': 'HH:mm:ss', 'hour': 'MM.DD. HH:mm:ss', 'day': 'MM.DD. HH:mm', 'week': 'MM.DD.', 'month': 'YYYY.MM.DD.', 'quarter': 'YYYY.MM.DD.', 'year': 'YYYY.',}},
                    realtime: {
                        delay: 2000,
                        duration: dataDurationInMilliseconds,
                        refresh: 1000,

                    }
                }],
                yAxes: [{ticks : {min: 0, max: 150,}}]
            },
            plugins: {colorschemes: {scheme: 'brewer.YlOrRd3'}},
            annotation: {annotations: [
                    {type: 'line',id: 'min', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Min.: 0"},},
                    {type: 'line',id: 'max', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Max.: 0"},},
                    {type: 'line',id: 'avg', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Átl.: 0.00"},},
                ]}
        }
    });
    //endregion Charts

    //region Map

    xscale = d3.scale.linear().domain([0,mapWidth_m]).range([0,mapWidth_px]);
    yscale = d3.scale.linear().domain([0,mapHeight_m]).range([0,mapHeight_px]);

    map = d3.floorplan().xScale(xscale).yScale(yscale).panZoom(false);


    //map.drawText(g, 'a');

    imagelayer = d3.floorplan.imagelayer();                 // map
    heatmap = d3.floorplan.heatmap();                       // ?
    vectorfield = d3.floorplan.vectorfield();               //
    pathplot = d3.floorplan.pathplot();                     // tag útvonal
    overlays = d3.floorplan.overlays().editMode(true);      // tag és horgony pozíciók

//    mapdata[imagelayer.id()] = [{url: '../images/isrv.jpg', x: 0, y: 0, height: mapHeight_m, width: mapWidth_m}];
    mapdata[imagelayer.id()] = [{url: '../images/gt.jpg', x: 0, y: 0, height: mapHeight_m, width: mapWidth_m}];


    map.addLayer(imagelayer)
        .addLayer(heatmap)
        .addLayer(vectorfield)
        .addLayer(pathplot)
        .addLayer(overlays);
    
    d3.select("#myMap")
        .append("svg")
        .attr("height", mapHeight_px)
        .attr("width",mapWidth_px)
        .attr("id","mapSVG")
        .datum(mapdata)
        .call(map);
        

    //endregion Map

    refreshTableUpdateTimes();

    setInterval(function(){ refreshTableUpdateTimes(); }, 1000);
    setInterval(function(){ageDekaWaveData();}, 1000);

    showData(selectedDeviceId);

    resizePanel();
    $(window).bind('resize', function(){resizePanel();});
});

function refreshKVPsOnSisakLive() {
    chart_temperature.annotation.elements['limits'].options.yMax = parseFloat(dataSet_KVPs["limit_temp_max"]);
    chart_temperature.annotation.elements['limits'].options.yMin = parseFloat(dataSet_KVPs["limit_temp_min"]);

    chart_humidity.annotation.elements['limits'].options.yMax = parseFloat(dataSet_KVPs["limit_Hum_max"]);
    chart_humidity.annotation.elements['limits'].options.yMin = parseFloat(dataSet_KVPs["limit_Hum_min"]);
}

function average(ctx) {
    const values = ctx.chart.data.datasets[0].data;
    return values.reduce((a, b) => a + b, 0) / values.length;
}

//region Download / Refresh data
function ageDekaWaveData() {
    let youngEnough = false;
    while (!youngEnough && dataSet_DecaWaveData.length > 0) {
        if ( (Date.now() - dataSet_DecaWaveData[0].timeStamp) < dataDurationInMilliseconds  )
            youngEnough = true;
        dataSet_DecaWaveData.shift();
    }
}

function refreshChartDuration(seconds) {

    dataDurationInMilliseconds = seconds*1000;

    $("#dataDuration_10s" ).removeClass('btn-outline-primary');
    $("#dataDuration_01m"   ).removeClass('btn-outline-primary');
    $("#dataDuration_05m"   ).removeClass('btn-outline-primary');
    $("#dataDuration_10m"  ).removeClass('btn-outline-primary');

    if(seconds == 10) {
        $("#dataDuration_10s").addClass('btn-primary');
        $("#dataDuration_01m").addClass('btn-outline-primary');
        $("#dataDuration_05m").addClass('btn-outline-primary');
        $("#dataDuration_10m").addClass('btn-outline-primary');

    }
    else if(seconds == 60) {
        $("#dataDuration_10s").addClass('btn-outline-primary');
        $("#dataDuration_01m").addClass('btn-primary');
        $("#dataDuration_05m").addClass('btn-outline-primary');
        $("#dataDuration_10m").addClass('btn-outline-primary');

    }
    else if(seconds == 5*60) {
        $("#dataDuration_10s").addClass('btn-outline-primary');
        $("#dataDuration_01m").addClass('btn-outline-primary');
        $("#dataDuration_05m").addClass('btn-primary');
        $("#dataDuration_10m").addClass('btn-outline-primary');
    }
    else if(seconds == 10*60) {
        $("#dataDuration_10s").addClass('btn-outline-primary');
        $("#dataDuration_01m").addClass('btn-outline-primary');
        $("#dataDuration_05m").addClass('btn-outline-primary');
        $("#dataDuration_10m").addClass('btn-primary');
    }

    chart_oxygen.options.scales.xAxes[0].realtime.duration = dataDurationInMilliseconds;
    chart_temperature.options.scales.xAxes[0].realtime.duration = dataDurationInMilliseconds;
    chart_humidity.options.scales.xAxes[0].realtime.duration = dataDurationInMilliseconds;
    chart_heartRate.options.scales.xAxes[0].realtime.duration = dataDurationInMilliseconds;
}

function refreshTableUpdateTimes() {
    $.ajax({
        url: "../generalCommunication/tableupdatetimes",
        method: 'GET',
        dataType: 'json',
        success: function (resp) {

            if(resp) {

                let tableUpdateTimes = resp.tableUpdateTimes;

                for (let key in tableUpdateTimes) {
                    if (!(key in dataSet_TableUpdateTimes) || tableUpdateTimes[key] > dataSet_TableUpdateTimes[key]) {
                        refreshItem(key);
                        dataSet_TableUpdateTimes[key] = tableUpdateTimes[key];
                    }
                }
            } else {
                dataSet_TableUpdateTimes = [];
            }
        }
    });
}

function refreshItem(key) {
    switch(key) {
        case "kvp":                 refreshKVPs(); break;
        case "decaWave":            refreshDecaWaveData(); break;

        case "temperature":         refreshData_temperature(selectedDeviceId); break;
        case "humidity":            refreshData_humidity(selectedDeviceId); break;
        case "hr_heartRate":        refreshData_hr_heartRate(selectedDeviceId); break;
        case "hr_oxygen":           refreshData_hr_oxygen(selectedDeviceId); break;

        case "current":             refreshData_current(selectedDeviceId); break;
        case "voltage":             refreshData_voltage(selectedDeviceId); break;
        case "rfid":                refreshData_rfid(selectedDeviceId); break;

        default:                    refreshEnumerationData(key); break;
    }
}

function refreshDecaWaveData() {

    let timeStamp = dataSet_TableUpdateTimes["decaWave"];
    if (dataSet_DecaWaveData.length == 0) timeStamp = moment(Date.now()).add(timeToBakcAtStart,'m').unix()*1000;


    $.ajax({
        url: "../data/decaWaveTagPositionsAfterTimeStamp",
        //data: { timeStamp: 0 },
        data: { timeStamp: timeStamp },
        method: 'GET',
        dataType: 'json',
        success: function(resp) {


            if(resp) { dataSet_DecaWaveData = dataSet_DecaWaveData.concat(resp);}
            //else { dataSet_DecaWaveData = [];}


            processAtmosphericAndScaleData(selectedDeviceId);

        }
    });
}


function displayData(deviceToDisplay) {
    selectedDeviceId = deviceToDisplay;
    $("#deviceIdLabel").text(deviceToDisplay);

    processAtmosphericAndScaleData(selectedDeviceId);
}

function showData(deviceToDisplay) {

    processAtmosphericAndScaleData(selectedDeviceId);

    if(deviceToDisplay != selectedDeviceId) {
        selectedDeviceId = deviceToDisplay;
        dataSet_rfid = [];
        let device = getDeviceById(deviceToDisplay);
        let icon_className = 'fab fa-bluetooth ';
        if(device.connectionStatus == "CONNECTED") icon_className += 'goodColor';
        else icon_className += 'badColor';
        let iconItem = "<i class='"+icon_className+"'></i>"
        $("#deviceIdLabel").html(iconItem + " " + device.deviceName);
    }
}


//region Download And Process Atmospheric And Scale Data


function processAtmosphericAndScaleData(selectedDeviceId) {
    
    let temperatureData_device1 = [], temperatureData_device2 = [], temperatureData_device3 = [], temperatureData_device4 = [],
        humidityData_device1 = [], humidityData_device2 = [], humidityData_device3 = [], humidityData_device4 = [],
        hr_heartRateData_device1 = [], hr_heartRateData_device2 = [], hr_heartRateData_device3 = [], hr_heartRateData_device4 = [],
        hr_oxygenData_device1 = [], hr_oxygenData_device2 = [], hr_oxygenData_device3 = [], hr_oxygenData_device4 = []
        ;

    let timeStampMin = Date.now()-dataDurationInMilliseconds, timeStampMax = Date.now(),
        sum_temperatureData_1 = 0, cnt_temperatureData_1 = 0, min_temperatureData_1 = Number.MAX_VALUE, max_temperatureData_1 = Number.MIN_VALUE, current_temperatureData_1 = 0,
        sum_temperatureData_2 = 0, cnt_temperatureData_2 = 0, min_temperatureData_2 = Number.MAX_VALUE, max_temperatureData_2 = Number.MIN_VALUE, current_temperatureData_2 = 0,
        sum_temperatureData_3 = 0, cnt_temperatureData_3 = 0, min_temperatureData_3 = Number.MAX_VALUE, max_temperatureData_3 = Number.MIN_VALUE, current_temperatureData_3 = 0,
        sum_temperatureData_4 = 0, cnt_temperatureData_4 = 0, min_temperatureData_4 = Number.MAX_VALUE, max_temperatureData_4 = Number.MIN_VALUE, current_temperatureData_4 = 0,
        sum_humidityData_1 = 0, cnt_humidityData_1 = 0, min_humidityData_1 = Number.MAX_VALUE, max_humidityData_1 = Number.MIN_VALUE, current_humidityData_1 = 0,
        sum_humidityData_2 = 0, cnt_humidityData_2 = 0, min_humidityData_2 = Number.MAX_VALUE, max_humidityData_2 = Number.MIN_VALUE, current_humidityData_2 = 0,
        sum_humidityData_3 = 0, cnt_humidityData_3 = 0, min_humidityData_3 = Number.MAX_VALUE, max_humidityData_3 = Number.MIN_VALUE, current_humidityData_3 = 0,
        sum_humidityData_4 = 0, cnt_humidityData_4 = 0, min_humidityData_4 = Number.MAX_VALUE, max_humidityData_4 = Number.MIN_VALUE, current_humidityData_4 = 0,
        sum_hr_oxygenData_1 = 0, cnt_hr_oxygenData_1 = 0, min_hr_oxygenData_1 = Number.MAX_VALUE, max_hr_oxygenData_1 = Number.MIN_VALUE, current_hr_oxygenData_1 = 0,
        sum_hr_oxygenData_2 = 0, cnt_hr_oxygenData_2 = 0, min_hr_oxygenData_2 = Number.MAX_VALUE, max_hr_oxygenData_2 = Number.MIN_VALUE, current_hr_oxygenData_2 = 0,
        sum_hr_oxygenData_3 = 0, cnt_hr_oxygenData_3 = 0, min_hr_oxygenData_3 = Number.MAX_VALUE, max_hr_oxygenData_3 = Number.MIN_VALUE, current_hr_oxygenData_3 = 0,
        sum_hr_oxygenData_4 = 0, cnt_hr_oxygenData_4 = 0, min_hr_oxygenData_4 = Number.MAX_VALUE, max_hr_oxygenData_4 = Number.MIN_VALUE, current_hr_oxygenData_4 = 0,
        sum_hr_heartRateData_1 = 0, cnt_hr_heartRateData_1 = 0, min_hr_heartRateData_1 = Number.MAX_VALUE, max_hr_heartRateData_1 = Number.MIN_VALUE, current_hr_heartRateData_1 = 0,
        sum_hr_heartRateData_2 = 0, cnt_hr_heartRateData_2 = 0, min_hr_heartRateData_2 = Number.MAX_VALUE, max_hr_heartRateData_2 = Number.MIN_VALUE, current_hr_heartRateData_2 = 0,
        sum_hr_heartRateData_3 = 0, cnt_hr_heartRateData_3 = 0, min_hr_heartRateData_3 = Number.MAX_VALUE, max_hr_heartRateData_3 = Number.MIN_VALUE, current_hr_heartRateData_3 = 0,
        sum_hr_heartRateData_4 = 0, cnt_hr_heartRateData_4 = 0, min_hr_heartRateData_4 = Number.MAX_VALUE, max_hr_heartRateData_4 = Number.MIN_VALUE, current_hr_heartRateData_4 = 0
    ;

    dataSet_temperature.forEach((tempData) => {
        switch(tempData.deviceId) {
            case selectedDeviceId:     temperatureData_device1.push({ x: tempData.timeStamp, y: tempData.temperature}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_temperatureData_1 = tempData.temperature; sum_temperatureData_1 += tempData.temperature; cnt_temperatureData_1++; if(tempData.temperature < min_temperatureData_1 ) min_temperatureData_1=tempData.temperature; if(tempData.temperature > max_temperatureData_1 ) max_temperatureData_1 =tempData.temperature;} break;
            //case "ketto":   temperatureData_device2.push({ x: tempData.timeStamp, y: tempData.temperature}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_temperatureData_2 = tempData.temperature; sum_temperatureData_2 += tempData.temperature; cnt_temperatureData_2++; if(tempData.temperature < min_temperatureData_2 ) min_temperatureData_2=tempData.temperature; if(tempData.temperature > max_temperatureData_2 ) max_temperatureData_2 =tempData.temperature;} break;
            //case "harom":   temperatureData_device3.push({ x: tempData.timeStamp, y: tempData.temperature}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_temperatureData_3 = tempData.temperature; sum_temperatureData_3 += tempData.temperature; cnt_temperatureData_3++; if(tempData.temperature < min_temperatureData_3 ) min_temperatureData_3=tempData.temperature; if(tempData.temperature > max_temperatureData_3 ) max_temperatureData_3 =tempData.temperature;} break;
            //case "negy":    temperatureData_device4.push({ x: tempData.timeStamp, y: tempData.temperature}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_temperatureData_4 = tempData.temperature; sum_temperatureData_4 += tempData.temperature; cnt_temperatureData_4++; if(tempData.temperature < min_temperatureData_4 ) min_temperatureData_4=tempData.temperature; if(tempData.temperature > max_temperatureData_4 ) max_temperatureData_4 =tempData.temperature;} break;
            default:       /* console.log("Unknown deviceId");*/ break;
        }
    });
    dataSet_humidity.forEach((tempData) => {
        switch(tempData.deviceId) {
            case selectedDeviceId:     humidityData_device1.push({ x: tempData.timeStamp, y: tempData.humidity}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_humidityData_1 = tempData.humidity; sum_humidityData_1 += tempData.humidity; cnt_humidityData_1++; if(tempData.humidity < min_humidityData_1 ) min_humidityData_1=tempData.humidity; if(tempData.humidity > max_humidityData_1 ) max_humidityData_1 =tempData.humidity;} break;
            //case "egy":     humidityData_device1.push({ x: tempData.timeStamp, y: tempData.humidity}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_humidityData_1 = tempData.humidity; sum_humidityData_1 += tempData.humidity; cnt_humidityData_1++; if(tempData.humidity < min_humidityData_1 ) min_humidityData_1=tempData.humidity; if(tempData.humidity > max_humidityData_1 ) max_humidityData_1 =tempData.humidity;} break;
            //case "ketto":   humidityData_device2.push({ x: tempData.timeStamp, y: tempData.humidity}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_humidityData_2 = tempData.humidity; sum_humidityData_2 += tempData.humidity; cnt_humidityData_2++; if(tempData.humidity < min_humidityData_2 ) min_humidityData_2=tempData.humidity; if(tempData.humidity > max_humidityData_2 ) max_humidityData_2 =tempData.humidity;} break;
            //case "harom":   humidityData_device3.push({ x: tempData.timeStamp, y: tempData.humidity}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_humidityData_3 = tempData.humidity; sum_humidityData_3 += tempData.humidity; cnt_humidityData_3++; if(tempData.humidity < min_humidityData_3 ) min_humidityData_3=tempData.humidity; if(tempData.humidity > max_humidityData_3 ) max_humidityData_3 =tempData.humidity;} break;
            //case "negy":    humidityData_device4.push({ x: tempData.timeStamp, y: tempData.humidity}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_humidityData_4 = tempData.humidity; sum_humidityData_4 += tempData.humidity; cnt_humidityData_4++; if(tempData.humidity < min_humidityData_4 ) min_humidityData_4=tempData.humidity; if(tempData.humidity > max_humidityData_4 ) max_humidityData_4 =tempData.humidity;} break;
            default:       /* console.log("Unknown deviceId");*/ break;
        }
    });
    dataSet_hr_heartRate.forEach((tempData) => {
        switch(tempData.deviceId) {
            case selectedDeviceId:     hr_heartRateData_device1.push({ x: tempData.timeStamp, y: tempData.hr_heartRate}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_heartRateData_1 = tempData.hr_heartRate; sum_hr_heartRateData_1 += tempData.hr_heartRate; cnt_hr_heartRateData_1++; if(tempData.hr_heartRate < min_hr_heartRateData_1 ) min_hr_heartRateData_1=tempData.hr_heartRate; if(tempData.hr_heartRate > max_hr_heartRateData_1 ) max_hr_heartRateData_1 =tempData.hr_heartRate;} break;
            //case "egy":     hr_heartRateData_device1.push({ x: tempData.timeStamp, y: tempData.hr_heartRate}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_heartRateData_1 = tempData.hr_heartRate; sum_hr_heartRateData_1 += tempData.hr_heartRate; cnt_hr_heartRateData_1++; if(tempData.hr_heartRate < min_hr_heartRateData_1 ) min_hr_heartRateData_1=tempData.hr_heartRate; if(tempData.hr_heartRate > max_hr_heartRateData_1 ) max_hr_heartRateData_1 =tempData.hr_heartRate;} break;
            //case "ketto":   hr_heartRateData_device2.push({ x: tempData.timeStamp, y: tempData.hr_heartRate}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_heartRateData_2 = tempData.hr_heartRate; sum_hr_heartRateData_2 += tempData.hr_heartRate; cnt_hr_heartRateData_2++; if(tempData.hr_heartRate < min_hr_heartRateData_2 ) min_hr_heartRateData_2=tempData.hr_heartRate; if(tempData.hr_heartRate > max_hr_heartRateData_2 ) max_hr_heartRateData_2 =tempData.hr_heartRate;} break;
            //case "harom":   hr_heartRateData_device3.push({ x: tempData.timeStamp, y: tempData.hr_heartRate}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_heartRateData_3 = tempData.hr_heartRate; sum_hr_heartRateData_3 += tempData.hr_heartRate; cnt_hr_heartRateData_3++; if(tempData.hr_heartRate < min_hr_heartRateData_3 ) min_hr_heartRateData_3=tempData.hr_heartRate; if(tempData.hr_heartRate > max_hr_heartRateData_3 ) max_hr_heartRateData_3 =tempData.hr_heartRate;} break;
            //case "negy":    hr_heartRateData_device4.push({ x: tempData.timeStamp, y: tempData.hr_heartRate}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_heartRateData_4 = tempData.hr_heartRate; sum_hr_heartRateData_4 += tempData.hr_heartRate; cnt_hr_heartRateData_4++; if(tempData.hr_heartRate < min_hr_heartRateData_4 ) min_hr_heartRateData_4=tempData.hr_heartRate; if(tempData.hr_heartRate > max_hr_heartRateData_4 ) max_hr_heartRateData_4 =tempData.hr_heartRate;} break;
            default:       /* console.log("Unknown deviceId");*/ break;
        }
    });
    dataSet_hr_oxygen.forEach((tempData) => {
        switch(tempData.deviceId) {
            case selectedDeviceId:     hr_oxygenData_device1.push({ x: tempData.timeStamp, y: tempData.hr_oxygen}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_oxygenData_1 = tempData.hr_oxygen; sum_hr_oxygenData_1 += tempData.hr_oxygen; cnt_hr_oxygenData_1++; if(tempData.hr_oxygen < min_hr_oxygenData_1 ) min_hr_oxygenData_1=tempData.hr_oxygen; if(tempData.hr_oxygen > max_hr_oxygenData_1 ) max_hr_oxygenData_1 =tempData.hr_oxygen;} break;
            //case "egy":     hr_oxygenData_device1.push({ x: tempData.timeStamp, y: tempData.hr_oxygen}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_oxygenData_1 = tempData.hr_oxygen; sum_hr_oxygenData_1 += tempData.hr_oxygen; cnt_hr_oxygenData_1++; if(tempData.hr_oxygen < min_hr_oxygenData_1 ) min_hr_oxygenData_1=tempData.hr_oxygen; if(tempData.hr_oxygen > max_hr_oxygenData_1 ) max_hr_oxygenData_1 =tempData.hr_oxygen;} break;
            //case "ketto":   hr_oxygenData_device2.push({ x: tempData.timeStamp, y: tempData.hr_oxygen}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_oxygenData_2 = tempData.hr_oxygen; sum_hr_oxygenData_2 += tempData.hr_oxygen; cnt_hr_oxygenData_2++; if(tempData.hr_oxygen < min_hr_oxygenData_2 ) min_hr_oxygenData_2=tempData.hr_oxygen; if(tempData.hr_oxygen > max_hr_oxygenData_2 ) max_hr_oxygenData_2 =tempData.hr_oxygen;} break;
            //case "harom":   hr_oxygenData_device3.push({ x: tempData.timeStamp, y: tempData.hr_oxygen}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_oxygenData_3 = tempData.hr_oxygen; sum_hr_oxygenData_3 += tempData.hr_oxygen; cnt_hr_oxygenData_3++; if(tempData.hr_oxygen < min_hr_oxygenData_3 ) min_hr_oxygenData_3=tempData.hr_oxygen; if(tempData.hr_oxygen > max_hr_oxygenData_3 ) max_hr_oxygenData_3 =tempData.hr_oxygen;} break;
            //case "negy":    hr_oxygenData_device4.push({ x: tempData.timeStamp, y: tempData.hr_oxygen}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_oxygenData_4 = tempData.hr_oxygen; sum_hr_oxygenData_4 += tempData.hr_oxygen; cnt_hr_oxygenData_4++; if(tempData.hr_oxygen < min_hr_oxygenData_4 ) min_hr_oxygenData_4=tempData.hr_oxygen; if(tempData.hr_oxygen > max_hr_oxygenData_4 ) max_hr_oxygenData_4 =tempData.hr_oxygen;} break;
            default:       /* console.log("Unknown deviceId");*/ break;
        }
    });


    let avgTemperatureData = 0, minTemperatureData = 0, maxTemperatureData = 0;
    let avgHumidityData = 0, minHumidityData = 0, maxHumidityData = 0;
    let avgOxygenData = 0, minOxygentData = 0, maxOxygentData = 0;
    let avgHeartRateData =0, minHeartRateData = 0, maxHeartRateData = 0;

    chart_oxygen.data        = {datasets: [
            { label: "Véroxigén",
                data: hr_oxygenData_device1,
                fill: false,
                borderColor: colorOfOxygen,
                pointBackgroundColor: colorOfOxygen,
                pointBorderColor: colorOfOxygen,
                pointHoverBackgroundColor: colorOfOxygen,
                pointHoverBorderColor: colorOfOxygen,
            },]};

    chart_temperature.data   = {datasets: [{
            label: "Hőmérséklet",
            data: temperatureData_device1,
            fill: false,
            borderColor: colorOfTemperature,
            pointBackgroundColor: colorOfTemperature,
            pointBorderColor: colorOfTemperature,
            pointHoverBackgroundColor: colorOfTemperature,
            pointHoverBorderColor: colorOfTemperature,},]};

    chart_humidity.data      = {datasets: [{ label: "Páratartalom",   data: humidityData_device1,     fill: false, borderColor: colorOfHumidity,pointBackgroundColor: colorOfHumidity, pointBorderColor: colorOfHumidity, pointHoverBackgroundColor: colorOfHumidity, pointHoverBorderColor: colorOfHumidity,},]};

    chart_heartRate.data     = {datasets: [{ label: "Pulzus",         data: hr_heartRateData_device1, fill: false, borderColor: colorOfHeartRate,pointBackgroundColor: colorOfHeartRate, pointBorderColor: colorOfHeartRate, pointHoverBackgroundColor: colorOfHeartRate, pointHoverBorderColor: colorOfHeartRate,},]};


    avgTemperatureData = sum_temperatureData_1 / cnt_temperatureData_1; minTemperatureData = min_temperatureData_1; maxTemperatureData = max_temperatureData_1;
    avgHumidityData = sum_humidityData_1 / cnt_humidityData_1; minHumidityData = min_humidityData_1; maxHumidityData = max_humidityData_1;
    avgOxygenData = sum_hr_oxygenData_1 / cnt_hr_oxygenData_1; minOxygentData = min_hr_oxygenData_1; maxOxygentData = max_hr_oxygenData_1;
    avgHeartRateData = sum_hr_heartRateData_1 / cnt_hr_oxygenData_1; minHeartRateData = min_hr_heartRateData_1; maxHeartRateData = max_hr_heartRateData_1;
    /*

    if(selectedDeviceId == "egy") {

        chart_oxygen.data        = {datasets: [
            { label: "Véroxigén",
                data: hr_oxygenData_device1,
                fill: false,
                borderColor: colorOfOxygen,
                pointBackgroundColor: colorOfOxygen,
                pointBorderColor: colorOfOxygen,
                pointHoverBackgroundColor: colorOfOxygen,
                pointHoverBorderColor: colorOfOxygen,
            },]};

        chart_temperature.data   = {datasets: [{
            label: "Hőmérséklet",
                data: temperatureData_device1,
                fill: false,
                borderColor: colorOfTemperature,
                pointBackgroundColor: colorOfTemperature,
                pointBorderColor: colorOfTemperature,
                pointHoverBackgroundColor: colorOfTemperature,
                pointHoverBorderColor: colorOfTemperature,},]};

        chart_humidity.data      = {datasets: [{ label: "Páratartalom",   data: humidityData_device1,     fill: false, borderColor: colorOfHumidity,pointBackgroundColor: colorOfHumidity, pointBorderColor: colorOfHumidity, pointHoverBackgroundColor: colorOfHumidity, pointHoverBorderColor: colorOfHumidity,},]};

        chart_heartRate.data     = {datasets: [{ label: "Pulzus",         data: hr_heartRateData_device1, fill: false, borderColor: colorOfHeartRate,pointBackgroundColor: colorOfHeartRate, pointBorderColor: colorOfHeartRate, pointHoverBackgroundColor: colorOfHeartRate, pointHoverBorderColor: colorOfHeartRate,},]};


        avgTemperatureData = sum_temperatureData_1 / cnt_temperatureData_1; minTemperatureData = min_temperatureData_1; maxTemperatureData = max_temperatureData_1;
        avgHumidityData = sum_humidityData_1 / cnt_humidityData_1; minHumidityData = min_humidityData_1; maxHumidityData = max_humidityData_1;
        avgOxygenData = sum_hr_oxygenData_1 / cnt_hr_oxygenData_1; minOxygentData = min_hr_oxygenData_1; maxOxygentData = max_hr_oxygenData_1;
        avgHeartRateData = sum_hr_heartRateData_1 / cnt_hr_oxygenData_1; minHeartRateData = min_hr_heartRateData_1; maxHeartRateData = max_hr_heartRateData_1;
    }
    else if(selectedDeviceId == "ketto") {
        chart_oxygen.data        = {datasets: [{ label: "Véroxigén",      data: hr_oxygenData_device2,    fill: false, borderColor: colorOfOxygen,pointBackgroundColor: colorOfOxygen, pointBorderColor: colorOfOxygen, pointHoverBackgroundColor: colorOfOxygen, pointHoverBorderColor: colorOfOxygen,},]};
        chart_temperature.data   = {datasets: [{ label: "Hőmérséklet",    data: temperatureData_device2,  fill: false, borderColor: colorOfTemperature,pointBackgroundColor: colorOfTemperature, pointBorderColor: colorOfTemperature, pointHoverBackgroundColor: colorOfTemperature, pointHoverBorderColor: colorOfTemperature,},]};
        chart_humidity.data      = {datasets: [{ label: "Páratartalom",   data: humidityData_device2,     fill: false, borderColor: colorOfHumidity,pointBackgroundColor: colorOfHumidity, pointBorderColor: colorOfHumidity, pointHoverBackgroundColor: colorOfHumidity, pointHoverBorderColor: colorOfHumidity,},]};
        chart_heartRate.data     = {datasets: [{ label: "Pulzus",         data: hr_heartRateData_device2, fill: false, borderColor: colorOfHeartRate,pointBackgroundColor: colorOfHeartRate, pointBorderColor: colorOfHeartRate, pointHoverBackgroundColor: colorOfHeartRate, pointHoverBorderColor: colorOfHeartRate,},]};

        avgTemperatureData = sum_temperatureData_2 / cnt_temperatureData_2; minTemperatureData = min_temperatureData_2; maxTemperatureData = max_temperatureData_2;
        avgHumidityData = sum_humidityData_2 / cnt_humidityData_2; minHumidityData = min_humidityData_2; maxHumidityData = max_humidityData_2;
        avgOxygenData = sum_hr_oxygenData_2 / cnt_hr_oxygenData_2; minOxygentData = min_hr_oxygenData_2; maxOxygentData = max_hr_oxygenData_2;
        avgHeartRateData = sum_hr_heartRateData_2 / cnt_hr_oxygenData_2; minHeartRateData = min_hr_heartRateData_2; maxHeartRateData = max_hr_heartRateData_2;
    }

    else if(selectedDeviceId == "harom") {
        chart_oxygen.data        = {datasets: [{ label: "Véroxigén",      data: hr_oxygenData_device3,    fill: false, borderColor: colorOfOxygen,pointBackgroundColor: colorOfOxygen, pointBorderColor: colorOfOxygen, pointHoverBackgroundColor: colorOfOxygen, pointHoverBorderColor: colorOfOxygen,},]};
        chart_temperature.data   = {datasets: [{ label: "Hőmérséklet",    data: temperatureData_device3,  fill: false, borderColor: colorOfTemperature,pointBackgroundColor: colorOfTemperature, pointBorderColor: colorOfTemperature, pointHoverBackgroundColor: colorOfTemperature, pointHoverBorderColor: colorOfTemperature,},]};
        chart_humidity.data      = {datasets: [{ label: "Páratartalom",   data: humidityData_device3,     fill: false, borderColor: colorOfHumidity,pointBackgroundColor: colorOfHumidity, pointBorderColor: colorOfHumidity, pointHoverBackgroundColor: colorOfHumidity, pointHoverBorderColor: colorOfHumidity,},]};
        chart_heartRate.data     = {datasets: [{ label: "Pulzus",         data: hr_heartRateData_device3, fill: false, borderColor: colorOfHeartRate,pointBackgroundColor: colorOfHeartRate, pointBorderColor: colorOfHeartRate, pointHoverBackgroundColor: colorOfHeartRate, pointHoverBorderColor: colorOfHeartRate,},]};

        avgTemperatureData = sum_temperatureData_3 / cnt_temperatureData_3; minTemperatureData = min_temperatureData_3; maxTemperatureData = max_temperatureData_3;
        avgHumidityData = sum_humidityData_3 / cnt_humidityData_3; minHumidityData = min_humidityData_3; maxHumidityData = max_humidityData_3;
        avgOxygenData = sum_hr_oxygenData_3 / cnt_hr_oxygenData_3; minOxygentData = min_hr_oxygenData_3; maxOxygentData = max_hr_oxygenData_3;
        avgHeartRateData = sum_hr_heartRateData_3 / cnt_hr_oxygenData_3; minHeartRateData = min_hr_heartRateData_3; maxHeartRateData = max_hr_heartRateData_3;
    }

    else if(selectedDeviceId == "negy") {
        chart_oxygen.data        = {datasets: [{ label: "Véroxigén",      data: hr_oxygenData_device4,    fill: false, borderColor: colorOfOxygen,pointBackgroundColor: colorOfOxygen, pointBorderColor: colorOfOxygen, pointHoverBackgroundColor: colorOfOxygen, pointHoverBorderColor: colorOfOxygen,},]};
        chart_temperature.data   = {datasets: [{ label: "Hőmérséklet",    data: temperatureData_device4,  fill: false, borderColor: colorOfTemperature,pointBackgroundColor: colorOfTemperature, pointBorderColor: colorOfTemperature, pointHoverBackgroundColor: colorOfTemperature, pointHoverBorderColor: colorOfTemperature,},]};
        chart_humidity.data      = {datasets: [{ label: "Páratartalom",   data: humidityData_device4,     fill: false, borderColor: colorOfHumidity,pointBackgroundColor: colorOfHumidity, pointBorderColor: colorOfHumidity, pointHoverBackgroundColor: colorOfHumidity, pointHoverBorderColor: colorOfHumidity,},]};
        chart_heartRate.data     = {datasets: [{ label: "Pulzus",         data: hr_heartRateData_device4, fill: false, borderColor: colorOfHeartRate,pointBackgroundColor: colorOfHeartRate, pointBorderColor: colorOfHeartRate, pointHoverBackgroundColor: colorOfHeartRate, pointHoverBorderColor: colorOfHeartRate,},]};

        avgTemperatureData = sum_temperatureData_4 / cnt_temperatureData_4; minTemperatureData = min_temperatureData_4; maxTemperatureData = max_temperatureData_4;
        avgHumidityData = sum_humidityData_4 / cnt_humidityData_4; minHumidityData = min_humidityData_4; maxHumidityData = max_humidityData_4;
        avgOxygenData = sum_hr_oxygenData_4 / cnt_hr_oxygenData_4; minOxygentData = min_hr_oxygenData_4; maxOxygentData = max_hr_oxygenData_4;
        avgHeartRateData = sum_hr_heartRateData_4 / cnt_hr_oxygenData_4; minHeartRateData = min_hr_heartRateData_4; maxHeartRateData = max_hr_heartRateData_4;
    }
*/

    //region Dekawave
    let mc_tag0 = {timeStamp:0,x:0, y:0, z:0},  mr_tag0 = {timeStamp:0,x:0, y:0, z:0}, mc_tag0_kalman_f = {timeStamp:0,x:0, y:0, z:0}, mc_tag0_kalman_c = {timeStamp:0,x:0, y:0, z:0},
        mc_tag1 = {timeStamp:0,x:0, y:0, z:0},  mr_tag1 = {timeStamp:0,x:0, y:0, z:0}, mc_tag1_kalman_f = {timeStamp:0,x:0, y:0, z:0}, mc_tag1_kalman_c = {timeStamp:0,x:0, y:0, z:0},
        mc_tag2 = {timeStamp:0,x:0, y:0, z:0},  mr_tag2 = {timeStamp:0,x:0, y:0, z:0}, mc_tag2_kalman_f = {timeStamp:0,x:0, y:0, z:0}, mc_tag2_kalman_c = {timeStamp:0,x:0, y:0, z:0},
        mc_tag3 = {timeStamp:0,x:0, y:0, z:0},  mr_tag3 = {timeStamp:0,x:0, y:0, z:0}, mc_tag3_kalman_f = {timeStamp:0,x:0, y:0, z:0}, mc_tag3_kalman_c = {timeStamp:0,x:0, y:0, z:0}
    ;

    let points_mc_tag0 = [], points_mc_tag1 = [], points_mc_tag2 = [], points_mc_tag3 = [],
        points_mr_tag0 = [], points_mr_tag1 = [], points_mr_tag2 = [], points_mr_tag3 = [],

        points_mc_tag0_kalman_c = [], points_mc_tag0_kalman_f = [],
        points_mc_tag1_kalman_c = [], points_mc_tag1_kalman_f = [],
        points_mc_tag2_kalman_c = [], points_mc_tag2_kalman_f = [],
        points_mc_tag3_kalman_c = [], points_mc_tag3_kalman_f = []
    ;

    dataSet_DecaWaveData.forEach((data) => {
        let pos = JSON.parse(data.pos);

        pos.x = parseFloat(pos.x);
        pos.y = parseFloat(pos.y);
        pos.z = parseFloat(pos.z);

        if(data.msgType == "b'mc'") {
            if(pos.x < 100 && pos.x > -100 && pos.y<100 && pos.x > -100) {
                switch (data.tag) {
                    case "0" :

                        if(data.timeStamp > mc_tag0.timeStamp) mc_tag0 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};

                        if(data.timeStamp > mc_tag0_kalman_f.timeStamp) mc_tag0_kalman_f = {timeStamp:data.timeStamp, x:(pos.position_kalman_calculated_x), y:(pos.position_kalman_calculated_y)};
                        if(data.timeStamp > mc_tag0_kalman_c.timeStamp) mc_tag0_kalman_c = {timeStamp:data.timeStamp, x:(pos.position_kalman_filtered_x), y:(pos.position_kalman_filtered_y)};

                        points_mc_tag0.push({"x": (pos.x), "y": (pos.y),});

                        points_mc_tag0_kalman_c.push({"x": (pos.position_kalman_calculated_x), "y": (pos.position_kalman_calculated_y),});
                        points_mc_tag0_kalman_f.push({"x": (pos.position_kalman_filtered_x), "y": (pos.position_kalman_filtered_y),});

                        break;
                    case "1" :
                        if(data.timeStamp > mc_tag1.timeStamp) mc_tag1 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};
                        points_mc_tag1.push({"x": (pos.x), "y": (pos.y),});
                        break;
                    case "2" :
                        if(data.timeStamp > mc_tag2.timeStamp) mc_tag2 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};
                        points_mc_tag2.push({"x": (pos.x), "y": (pos.y),});
                        break;
                    case "3" :
                        if(data.timeStamp > mc_tag3.timeStamp) mc_tag3 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};
                        points_mc_tag3.push({"x": (pos.x), "y": (pos.y),});
                        break;
                    default  : console.log("Unknown deviceId"); break;
                }
            }
        } else if(data.msgType == "b'mr'") {

            if(pos.x < 100 && pos.x > -100 && pos.y<100 && pos.x > -100) {
                switch (data.tag) {
                    case "0" :
                        if( data.timeStamp > mr_tag0.timeStamp) mr_tag0 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};
                        points_mr_tag0.push({"x": (pos.x), "y": (pos.y),});
                        break;
                    case "1" :
                        if( data.timeStamp > mr_tag1.timeStamp) mr_tag1 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};
                        points_mr_tag1.push({"x": (pos.x), "y": (pos.y),});
                        break;
                    case "2" :
                        if( data.timeStamp > mr_tag2.timeStamp) mr_tag2 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};
                        points_mr_tag2.push({"x": (pos.x), "y": (pos.y),});
                        break;
                    case "3" :
                        if( data.timeStamp > mr_tag3.timeStamp) mr_tag3 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};
                        points_mr_tag3.push({"x": (pos.x), "y": (pos.y),});
                        break;
                    default  :
                        console.log("Unknown deviceId");
                        break;
                }
            }
        }
    });


    let tempPathPlot = [];
    //{"id": "flt-11", "classes": "device_1_mc_k_c", "points": points_mc_tag0_kalman_c,},
    //{"id": "flt-12", "classes": "device_2_mc_k_f", "points": points_mc_tag0_kalman_f,},

    /*
    {"id": "flt-2", "classes": "device_1_mr", "points": points_mr_tag0,},
    {"id": "flt-4", "classes": "device_2_mr", "points": points_mr_tag1,},
    {"id": "flt-6", "classes": "device_3_mr", "points": points_mr_tag2,},
    {"id": "flt-8", "classes": "device_4_mr", "points": points_mr_tag3,},
     */


    if(selectedDeviceId == "sisak_1")       {tempPathPlot.push({"id": "flt-1", "classes": "device_1_mc", "points": points_mr_tag0,});} //sisak
    else if(selectedDeviceId == "vallfa_1") {tempPathPlot.push({"id": "flt-3", "classes": "device_2_mc", "points": points_mr_tag1,});} //vallfa
    else if(selectedDeviceId == "szeker_1") {tempPathPlot.push({"id": "flt-5", "classes": "device_3_mc", "points": points_mr_tag2,});} //szeker 1
    else if(selectedDeviceId == "szeker_2") {tempPathPlot.push({"id": "flt-7", "classes": "device_4_mc", "points": points_mc_tag3,});} //szeker 2


    mapdata[pathplot.id()] = tempPathPlot;

    let polygons = [
        {"id": "anchor_0", "class": "anchor_1_vertex", "points": [ {"x":dataSet_KVPs.pos_1_x,"y":dataSet_KVPs.pos_1_y}]},
        {"id": "anchor_1", "class": "anchor_2_vertex", "points": [ {"x":dataSet_KVPs.pos_2_x,"y":dataSet_KVPs.pos_2_y}]},
        {"id": "anchor_2", "class": "anchor_3_vertex", "points": [ {"x":dataSet_KVPs.pos_3_x,"y":dataSet_KVPs.pos_3_y}]},
        {"id": "anchor_3", "class": "anchor_4_vertex", "points": [ {"x":dataSet_KVPs.pos_4_x,"y":dataSet_KVPs.pos_4_y}]},


        //{"id": "mc_tag0_kalman_c", "class": "mc_tag0_kalman_c_vertex",  "points": [ {"x":mc_tag0_kalman_c.x,"y":mc_tag0_kalman_c.y}]},
        //{"id": "mc_tag0_kalman_f", "class": "mc_tag0_kalman_f_vertex",  "points": [ {"x":mc_tag0_kalman_f.x,"y":mc_tag0_kalman_f.y}]},

        /*
        {"id": "mr_tag0", "name": "mr_tag0", "points": [ {"x":mr_tag0.x,"y":mr_tag0.y}]},
        {"id": "mr_tag1", "name": "mr_tag1", "points": [ {"x":mr_tag1.x,"y":mr_tag1.y}]},
        {"id": "mr_tag2", "name": "mr_tag2", "points": [ {"x":mr_tag2.x,"y":mr_tag2.y}]},
        {"id": "mr_tag3", "name": "mr_tag3", "points": [ {"x":mr_tag3.x,"y":mr_tag3.y}]},
         */

    ];

    if(selectedDeviceId == "sisak_1")       {polygons.push({"id": "mc_tag0", "class": "device_1_vertex",  "points": [ {"x":mr_tag0.x,"y":mr_tag0.y}]});}
    else if(selectedDeviceId == "vallfa_1") {polygons.push({"id": "mc_tag1", "class": "device_2_vertex",  "points": [ {"x":mr_tag1.x,"y":mr_tag1.y}]});}
    else if(selectedDeviceId == "szeker_1") {polygons.push({"id": "mc_tag2", "class": "device_3_vertex",  "points": [ {"x":mr_tag2.x,"y":mr_tag2.y}]});}
    else if(selectedDeviceId == "szeker_2") {polygons.push({"id": "mc_tag3", "class": "device_4_vertex",  "points": [ {"x":mr_tag3.x,"y":mr_tag3.y}]});}


    mapdata[overlays.id()] = {"polygons" : polygons};

    //console.log("MC - " + "x: " + (mc_tag0.x).toFixed(2) + ", y: " + (mc_tag0.y).toFixed(2) +", z: " + (mc_tag0.z).toFixed(2));
    //console.log("KA - " + "x: " + parseFloat(mc_tag0_kalman_c.x).toFixed(2) + ", y: " + parseFloat(mc_tag0_kalman_c.y).toFixed(2));

    d3.select("#myMap").datum(mapdata).call(map);

    //endregion


    try{
        chart_heartRate.annotation.elements['avg'].options.value = avgHeartRateData;
        chart_heartRate.annotation.elements['avg'].options.label.content = "Átl.: "+avgHeartRateData.toFixed(2);
        chart_heartRate.annotation.elements['min'].options.value = minHeartRateData;
        chart_heartRate.annotation.elements['min'].options.label.content = "Min.: "+minHeartRateData.toFixed(2);
        chart_heartRate.annotation.elements['max'].options.value = maxHeartRateData;
        chart_heartRate.annotation.elements['max'].options.label.content = "Max.: "+maxHeartRateData.toFixed(2);

        chart_temperature.annotation.elements['avg'].options.value = avgTemperatureData;
        chart_temperature.annotation.elements['avg'].options.label.content = "Átl.: "+avgTemperatureData.toFixed(2);
        chart_temperature.annotation.elements['min'].options.value = minTemperatureData;
        chart_temperature.annotation.elements['min'].options.label.content = "Min.: "+minTemperatureData.toFixed(2);
        chart_temperature.annotation.elements['max'].options.value = maxTemperatureData;
        chart_temperature.annotation.elements['max'].options.label.content = "Max.: "+maxTemperatureData.toFixed(2);

        chart_humidity.annotation.elements['avg'].options.value = avgHumidityData;
        chart_humidity.annotation.elements['avg'].options.label.content = "Átl.: "+avgHumidityData.toFixed(2);
        chart_humidity.annotation.elements['min'].options.value = minHumidityData;
        chart_humidity.annotation.elements['min'].options.label.content = "Min.: "+minHumidityData.toFixed(2);
        chart_humidity.annotation.elements['max'].options.value = maxHumidityData;
        chart_humidity.annotation.elements['max'].options.label.content = "Max.: "+maxHumidityData.toFixed(2);

        chart_oxygen.annotation.elements['avg'].options.value = avgOxygenData;
        chart_oxygen.annotation.elements['avg'].options.label.content = "Átl.: "+avgOxygenData.toFixed(2);
        chart_oxygen.annotation.elements['min'].options.value = minOxygentData;
        chart_oxygen.annotation.elements['min'].options.label.content = "Min.: "+minOxygentData.toFixed(2);
        chart_oxygen.annotation.elements['max'].options.value = maxOxygentData;
        chart_oxygen.annotation.elements['max'].options.label.content = "Max.: "+maxOxygentData.toFixed(2);

        chart_temperature.update({preservation: true});
        chart_humidity.update({preservation: true});
        chart_heartRate.update({preservation: true});
        chart_oxygen.update({preservation: true});


    } catch (e) {
        console.log(e);
    }

}


function refreshData_temperature() {
    let timeStamp = dataSet_TableUpdateTimes["temperature"];
    if (dataSet_temperature.length == 0) timeStamp = moment(Date.now()).add(timeToBakcAtStart,'m').unix()*1000;
    $.ajax({url: "../data/temperatureAfterTimeStamp", data: { timeStamp: timeStamp }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_temperature = dataSet_temperature.concat(resp);showData(selectedDeviceId);}}});
}
function refreshData_humidity() {
    let timeStamp = dataSet_TableUpdateTimes["humidity"];
    if (dataSet_humidity.length == 0) timeStamp = moment(Date.now()).add(timeToBakcAtStart,'m').unix()*1000;
    $.ajax({url: "../data/humidityAfterTimeStamp", data: { timeStamp: timeStamp }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_humidity = dataSet_humidity.concat(resp);showData(selectedDeviceId);}}});
}
function refreshData_hr_heartRate() {
    let timeStamp = dataSet_TableUpdateTimes["hr_heartRate"];
    if (dataSet_hr_heartRate.length == 0) timeStamp = moment(Date.now()).add(timeToBakcAtStart,'m').unix()*1000;
    $.ajax({url: "../data/hr_heartRateAfterTimeStamp", data: { timeStamp: timeStamp }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_hr_heartRate = dataSet_hr_heartRate.concat(resp);showData(selectedDeviceId);}}});

}
function refreshData_hr_oxygen() {
    let timeStamp = dataSet_TableUpdateTimes["hr_oxygen"];
    if (dataSet_hr_oxygen.length == 0) timeStamp = moment(Date.now()).add(timeToBakcAtStart,'m').unix()*1000;
    $.ajax({url: "../data/hr_oxygenAfterTimeStamp", data: { timeStamp: timeStamp }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_hr_oxygen = dataSet_hr_oxygen.concat(resp);showData(selectedDeviceId);}}});

}

function refreshData_rfid() {
    let timeStamp = dataSet_TableUpdateTimes["rfid"];
    if (dataSet_rfid.length == 0) timeStamp = moment(Date.now()).add(timeToBakcAtStart,'m').unix()*1000;
    $.ajax({url: "../data/rfidAfterTimeStamp", data: { timeStamp: timeStamp }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_rfid = dataSet_rfid.concat(resp);showData(selectedDeviceId);}}});
}

function refreshData_current() {
    let timeStamp = dataSet_TableUpdateTimes["current"];
    if (dataSet_current.length == 0) timeStamp = moment(Date.now()).add(timeToBakcAtStart,'m').unix()*1000;
    $.ajax({url: "../data/currentAfterTimeStamp", data: { timeStamp: timeStamp }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_current = dataSet_current.concat(resp);showData(selectedDeviceId);}}});
}

function refreshData_voltage() {
    let timeStamp = dataSet_TableUpdateTimes["voltage"];
    if (dataSet_voltage.length == 0) timeStamp = moment(Date.now()).add(timeToBakcAtStart,'m').unix()*1000;
    $.ajax({url: "../data/voltageAfterTimeStamp", data: { timeStamp: timeStamp }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_voltage = dataSet_voltage.concat(resp);showData(selectedDeviceId);}}});
}

//endregion

//endregion

function refreshEnumerationUsersOnSisakLive(caller) {
    if(caller == "devices") {
        rebuildDeviceList();

        if(selectedDeviceId == null) {
            devices.forEach(item=> {
                if(item.deviceType == layoutType) {
                    if(selectedDeviceId == null) showData(item.deviceId);
                }
            });
        }
    }
}
function resizePanel() {
    let mapContainer = $("#mapContainer")[0];
    let myMap = $("#myMap")[0];

    //$('#myMap').css('height', mapContainer.clientHeight+'px');
    $('#mapSVG').attr('width', mapContainer.clientWidth-25+'px');
    $('.map-layers').attr('width', mapContainer.clientWidth-25+'px');
}