'use strict';

let dataSet_TableUpdateTimes = [],

    dataSet_DecaWaveData = [],

    mapWidth_px = 950, mapHeight_px = 950,
    mapWidth_m = 3.8, mapHeight_m = 3.8,

    dateFrom = 0, dateTo = 0,
    timeStampAtChartLoad = 0,

    xscale,  yscale,  map, imagelayer,  heatmap,  vectorfield,  pathplot,  overlays, mapdata = {},


    dataSet_temperature = [],
    dataSet_humidity = [],
    dataSet_pressure = [],

    dataSet_hr_heartRate = [],
    dataSet_hr_oxygen = [],

    dataSet_rfid = [],
    dataSet_current = [],
    dataSet_voltage = [],

    chart_temperature,
    chart_humidity,
    chart_heartRate,
    chart_oxygen,

    colorOfTemperature = "#60C173",
    colorOfHumidity = "#FFB442",
    colorOfOxygen = "#75B4FF",
    colorOfHeartRate = "#FF6B72",


    selectedDeviceId = null,
    layoutType = "SISAK",


    dataDurationInMilliseconds = 1*60*1000,

    timeToBakcAtStart = -10 // !! minute
;

$(document).ready(function() {

    kvpRefreshCallbacks.push(refreshKVPsOnSisakReplay);
    enumerationRefreshCallbacks.push(refreshEnumerationUsersOnSisakReplay);

    if(displayMode == "NORMAL") {$('#btn_Sisak').hide();$('#btn_Vallfa').show();$('#btn_Szeker').show();$('#btn_Szurka').show();}
    else {$('#btn_Sisak').show();$('#btn_Vallfa').hide();$('#btn_Szeker').hide();$('#btn_Szurka').hide();}

    dateTo      = moment().endOf('day').valueOf();
    dateFrom    = moment().endOf('day').subtract(1,'day').valueOf();

    //dateFrom = 1643204040000; //14:34
    //dateTo   = 1643204100000; //14:35

    $('#dateFrom').val(moment(dateFrom).format('YYYY-MM-DDTHH:mm'));
    $('#dateTo').val(  moment(dateTo)  .format('YYYY-MM-DDTHH:mm'));

    $('#refreshHistoricalData').on('click', function () {
        dateTo      = moment($('#dateTo').val()).valueOf();
        dateFrom    = moment($('#dateFrom').val()).valueOf();
        refreshItems();
    });

    $('#exportHistoricalData').on('click', function () {
        dateTo      = moment($('#dateTo').val()).valueOf();
        dateFrom    = moment($('#dateFrom').val()).valueOf();
        let win = window.open('/data/everythingBetweenTimeStamps?from='+dateFrom+'&to='+dateTo, '_blank');
        if (win) {win.focus();}
        else {alert('Please allow popups for this website');}
    });

    var colorSchemes = Chart.colorschemes;

    $('#btnSaveSettings').on('click', function () {saveSettings();});
    $('#modalSettings').on('shown.bs.modal', function (e) {$('#modalSettings_Pos_1_x').focus();});

    //region Charts
    chart_temperature = new Chart(document.getElementById("chart-line-temperature").getContext('2d'), {
        type: 'line',
        responsive: true,
        data: {datasets: [{data: [], label: 'Dataset 1', type: 'line', fill: false,}, {data: [], label: 'Dataset 2', type: 'line', fill: false,}]},
        options: {
            barValueSpacing: 20,
            maintainAspectRatio: false,
            tooltips: {mode: 'nearest', intersect: false},
            legend: {display: false},
            hover: {mode: 'nearest', intersect: false},
            pan: {enabled: true, mode: 'x', rangeMax: {x: 4000}, rangeMin: {x: 0}},
            scales: {
                xAxes: [{
                    type: 'time',
                    time: {
                        isoWeekday: true,
                        tooltipFormat: 'YYYY.MM.DD. HH:mm:ss',
                        displayFormats: {'millisecond': 'HH:mm:ss', 'second': 'HH:mm:ss', 'minute': 'HH:mm:ss', 'hour': 'MM.DD. HH:mm:ss', 'day': 'MM.DD. HH:mm', 'week': 'MM.DD.', 'month': 'YYYY.MM.DD.', 'quarter': 'YYYY.MM.DD.', 'year': 'YYYY.',}
                        },
                }]
            },
            plugins: {colorschemes: {scheme: 'tableau.Tableau20'}},
            annotation: {annotations: [
                    {type: 'box', id: 'limits', xScaleID: 'x-axis-0', yScaleID: 'y-axis-0', yMax: 0.0, yMin:  0.0, borderColor: '#60C173', borderWidth: 2, backgroundColor: '#60C17355',},
                    {type: 'line',id: 'min', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Min.: 0"},},
                    {type: 'line',id: 'max', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Max.: 0"},},
                    {type: 'line',id: 'avg', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Átl.: 0.00"},},
                ]}

        }
    });
    chart_humidity = new Chart(document.getElementById("chart-line-humidity").getContext('2d'), {
            type: 'line',
            responsive: true,
            data: {datasets: [
                    {data: [], label: 'Dataset 1', type: 'line', fill: false,},
                    {data: [], label: 'Dataset 2', type: 'line', fill: false,}
                ]},
            options: {
                barValueSpacing: 20,
                maintainAspectRatio: false,
                tooltips: {mode: 'nearest', intersect: false},
                legend: {display: false},
                hover: {mode: 'nearest', intersect: false},
                pan: {enabled: true, mode: 'x', rangeMax: {x: 4000}, rangeMin: {x: 0}},
                zoom: {enabled: false, mode: 'x', rangeMax: {x: 20000}, rangeMin: {x: 1000}},
                scales: {
                    xAxes: [{
                        type: 'time',
                        time: {isoWeekday: true, tooltipFormat: 'YYYY.MM.DD. HH:mm:ss.SSS', displayFormats: {'millisecond': 'HH:mm:ss', 'second': 'HH:mm:ss', 'minute': 'HH:mm:ss', 'hour': 'MM.DD. HH:mm:ss', 'day': 'MM.DD. HH:mm', 'week': 'MM.DD.', 'month': 'YYYY.MM.DD.', 'quarter': 'YYYY.MM.DD.', 'year': 'YYYY.',}},
                    }]
                },
                plugins: {colorschemes: {scheme: 'tableau.Tableau20'}},
                annotation: {annotations: [
                        {type: 'box', id: 'limits', xScaleID: 'x-axis-0', yScaleID: 'y-axis-0', yMax: 0.0, yMin:  0.0, borderColor: '#60C173', borderWidth: 2, backgroundColor: '#60C17355',},
                        {type: 'line',id: 'min', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Min.: 0"},},
                        {type: 'line',id: 'max', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Max.: 0"},},
                        {type: 'line',id: 'avg', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Átl.: 0.00"},},
                    ]}
            }
        });
    chart_heartRate = new Chart(document.getElementById("chart-line-heartrate").getContext('2d'), {
        type: 'line',
        responsive: true,
        data: {datasets: [
                {data: [], label: 'Dataset 1', type: 'line', fill: false,},
                {data: [], label: 'Dataset 2', type: 'line', fill: false,}
            ]},
        options: {
            barValueSpacing: 20,
            maintainAspectRatio: false,
            tooltips: {mode: 'nearest', intersect: false},
            legend: {display: false},
            hover: {mode: 'nearest', intersect: false},
            pan: {enabled: true, mode: 'x', rangeMax: {x: 4000}, rangeMin: {x: 0}},
            zoom: {enabled: false, mode: 'x', rangeMax: {x: 20000}, rangeMin: {x: 1000}},
            scales: {
                xAxes: [{
                    type: 'time',
                    time: {isoWeekday: true, tooltipFormat: 'YYYY.MM.DD. HH:mm:ss.SSS', displayFormats: {'millisecond': 'HH:mm:ss', 'second': 'HH:mm:ss', 'minute': 'HH:mm:ss', 'hour': 'MM.DD. HH:mm:ss', 'day': 'MM.DD. HH:mm', 'week': 'MM.DD.', 'month': 'YYYY.MM.DD.', 'quarter': 'YYYY.MM.DD.', 'year': 'YYYY.',}},
                }]
            },
            plugins: {colorschemes: {scheme: 'tableau.Tableau20'}},
            annotation: {annotations: [
                    {type: 'line',id: 'min', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Min.: 0"},},
                    {type: 'line',id: 'max', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Max.: 0"},},
                    {type: 'line',id: 'avg', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Átl.: 0.00"},},
                ]}
        }
    });
    chart_oxygen = new Chart(document.getElementById("chart-line-oxygen").getContext('2d'), {
        type: 'line',
        responsive: true,
        data: {datasets: [
                {data: [], label: 'Dataset 1', type: 'line', fill: false,},
                {data: [], label: 'Dataset 2', type: 'line', fill: false,}
            ]},
        options: {
            barValueSpacing: 20,
            maintainAspectRatio: false,
            tooltips: {mode: 'nearest', intersect: false},
            legend: {display: false},
            hover: {mode: 'nearest', intersect: false},
            pan: {enabled: true, mode: 'x', rangeMax: {x: 4000}, rangeMin: {x: 0}},
            zoom: {enabled: false, mode: 'x', rangeMax: {x: 20000}, rangeMin: {x: 1000}},
            scales: {
                xAxes: [{
                    type: 'time',
                    time: {isoWeekday: true, tooltipFormat: 'YYYY.MM.DD. HH:mm:ss.SSS', displayFormats: {'millisecond': 'HH:mm:ss', 'second': 'HH:mm:ss', 'minute': 'HH:mm:ss', 'hour': 'MM.DD. HH:mm:ss', 'day': 'MM.DD. HH:mm', 'week': 'MM.DD.', 'month': 'YYYY.MM.DD.', 'quarter': 'YYYY.MM.DD.', 'year': 'YYYY.',}},
                }]
            },
            plugins: {colorschemes: {scheme: 'tableau.Tableau20'}},
            annotation: {annotations: [
                    {type: 'line',id: 'min', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Min.: 0"},},
                    {type: 'line',id: 'max', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Max.: 0"},},
                    {type: 'line',id: 'avg', mode: 'horizontal', scaleID: 'y-axis-0', borderColor: 'gray',   borderDash: [6, 6], borderDashOffset: 5, borderWidth: 2, value: 0.0, drawTime: 'afterDraw', label: {backgroundColor: 'rgba(0,0,0,0.8)', fontFamily: "sans-serif", fontSize: 12, fontStyle: "bold", fontColor: "#fff", xPadding: 6, yPadding: 6, cornerRadius: 6, position: "left", xAdjust: 0, yAdjust: 0, enabled: true, content: "Átl.: 0.00"},},
                ]}
        }
    });

    timeStampAtChartLoad = moment().valueOf();

    //endregion Charts

    //region Map
    xscale = d3.scale.linear().domain([0,mapWidth_m]).range([0,mapWidth_px]);
    yscale = d3.scale.linear().domain([0,mapHeight_m]).range([0,mapHeight_px]);

    map = d3.floorplan().xScale(xscale).yScale(yscale).panZoom(false);

    //map.drawText(g, 'a');

    imagelayer = d3.floorplan.imagelayer();                 // map
    heatmap = d3.floorplan.heatmap();                       // ?
    vectorfield = d3.floorplan.vectorfield();               //
    pathplot = d3.floorplan.pathplot();                     // tag útvonal
    overlays = d3.floorplan.overlays().editMode(true);

    mapdata[imagelayer.id()] = [{url: '../images/gt.jpg', x: 0, y: 0, height: mapHeight_m, width: mapWidth_m}];

    map.addLayer(imagelayer)
        .addLayer(heatmap)
        .addLayer(vectorfield)
        .addLayer(pathplot)
        .addLayer(overlays);

    d3.select("#myMap").append("svg").attr("height", mapHeight_px).attr("width",mapWidth_px).attr("id","mapSVG").datum(mapdata).call(map);
    //endregion Map
    refreshKVPs();
    refreshEnumeration();
    resizePanel();
    $(window).bind('resize', function(){resizePanel();});
});
function refreshKVPsOnSisakReplay() {
    chart_temperature.annotation.elements['limits'].options.yMax = parseFloat(dataSet_KVPs["limit_temp_max"]);
    chart_temperature.annotation.elements['limits'].options.yMin = parseFloat(dataSet_KVPs["limit_temp_min"]);

    chart_humidity.annotation.elements['limits'].options.yMax = parseFloat(dataSet_KVPs["limit_Hum_max"]);
    chart_humidity.annotation.elements['limits'].options.yMin = parseFloat(dataSet_KVPs["limit_Hum_min"]);

    chart_temperature.update({preservation: true});
    chart_humidity.update({preservation: true});
}
//region Download
function refreshItems() {

    refreshKVPs();
    refreshDecaWaveData();

    refreshData_temperature();
    refreshData_humidity();
    //refreshData_pressure();
    //refreshData_scale_AvgWeight();

    refreshData_rfid();
    refreshData_current();
    refreshData_voltage();

    refreshData_hr_heartRate();
    refreshData_hr_oxygen();

    /*
    refreshData_spect_A();
    refreshData_spect_B();
    refreshData_spect_C();
    refreshData_spect_D();
    refreshData_spect_E();
    refreshData_spect_F();
    refreshData_spect_G();
    refreshData_spect_H();
    refreshData_spect_I();
    refreshData_spect_J();
    refreshData_spect_K();
    refreshData_spect_L();
    refreshData_spect_R();
    refreshData_spect_S();
    refreshData_spect_T();
    refreshData_spect_U();
    refreshData_spect_V();
    refreshData_spect_W();
    refreshData_ph_Value();
    refreshData_ph_Voltage();
    refreshData_button_Green();
    refreshData_button_Red();
    refreshData_hr_confidence();
    refreshData_hr_extStatus();
    refreshData_hr_heartRate();
    refreshData_hr_irLed();
    refreshData_hr_oxygen();
    refreshData_hr_redLed();
    refreshData_hr_rValue();
    refreshData_hr_status();
    refreshData_scale_AvgWeight();
    refreshData_scale_Weight();
    refreshData_scale_CalibrationDate();
    refreshData_scale_CalibrationFactor();
    refreshData_scale_Reading();
    refreshData_scale_ZeroOffset();
    refreshData_pwm();
    refreshData_voiceRecognition();
     */

    //refreshEnumeration();

}

function refreshDecaWaveData() {
    $.ajax({
        url: "../data/decaWaveTagPositionsBetweenTimeStamps",
        data: { from: dateFrom, to: dateTo },
        method: 'GET',
        dataType: 'json',
        success: function(resp) {
            if(resp) { dataSet_DecaWaveData = resp;}

            processData(selectedDeviceId);
        }
    });
}

function refreshData_temperature() {
    $.ajax({url: "../data/temperatureBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) {dataSet_temperature = resp;showData(selectedDeviceId);}}});
}
function refreshData_humidity() {
    $.ajax({url: "../data/humidityBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_humidity = resp;showData(selectedDeviceId);}}});
}
function refreshData_pressure() {
    $.ajax({url: "../data/pressureBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_pressure = dataSet_pressure.concat(resp);showData(selectedDeviceId);}}});
}
function refreshData_scale_AvgWeight() {
    $.ajax({url: "../data/scale_AvgWeightBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_scale_AvgWeight = (resp);showData(selectedDeviceId);}}});
}

function refreshData_rfid() {$.ajax({url: "../data/rfidBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_rfid = resp;showData(selectedDeviceId);}}});}
function refreshData_current() {$.ajax({url: "../data/currentBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_current = resp;showData(selectedDeviceId);}}});}
function refreshData_voltage() {$.ajax({url: "../data/voltageBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_voltage = resp;showData(selectedDeviceId);}}});}

function refreshData_hr_heartRate() {$.ajax({url: "../data/hr_heartRateBetweenTimeStamps", data: {  from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_hr_heartRate = (resp);showData(selectedDeviceId);}}});}
function refreshData_hr_oxygen() {$.ajax({url: "../data/hr_oxygenBetweenTimeStamps", data: {  from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_hr_oxygen = (resp);showData(selectedDeviceId);}}});}

//region Not used here
function refreshData_spect_A() {
    $.ajax({url: "../data/spect_ABetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_A = resp;showData(selectedDataSource);}}});
}
function refreshData_spect_B() {
    $.ajax({url: "../data/spect_BBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_B = resp;showData(selectedDataSource);}}});
}
function refreshData_spect_C() {
    $.ajax({url: "../data/spect_CBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_C = resp;showData(selectedDataSource);}}});
}
function refreshData_spect_D() {
    $.ajax({url: "../data/spect_DBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_D = (resp);showData(selectedDataSource);}}});
}
function refreshData_spect_E() {
    $.ajax({url: "../data/spect_EBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_E = (resp);showData(selectedDataSource);}}});
}
function refreshData_spect_F() {
    $.ajax({url: "../data/spect_FBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_F = (resp);showData(selectedDataSource);}}});
}
function refreshData_spect_G() {
    $.ajax({url: "../data/spect_GBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_G = (resp);showData(selectedDataSource);}}});
}
function refreshData_spect_H() {
    $.ajax({url: "../data/spect_HBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_H = (resp);showData(selectedDataSource);}}});
}
function refreshData_spect_I() {
    $.ajax({url: "../data/spect_IBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_I = (resp);showData(selectedDataSource);}}});
}
function refreshData_spect_J() {
    $.ajax({url: "../data/spect_JBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_J = (resp);showData(selectedDataSource);}}});
}
function refreshData_spect_K() {
    $.ajax({url: "../data/spect_KBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_K = (resp);showData(selectedDataSource);}}});
}
function refreshData_spect_L() {
    $.ajax({url: "../data/spect_LBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_L = (resp);showData(selectedDataSource);}}});
}
function refreshData_spect_R() {
    $.ajax({url: "../data/spect_RBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_R = (resp);showData(selectedDataSource);}}});
}
function refreshData_spect_S() {
    $.ajax({url: "../data/spect_SBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_S = (resp);showData(selectedDataSource);}}});
}
function refreshData_spect_T() {
    $.ajax({url: "../data/spect_TBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_T = (resp);showData(selectedDataSource);}}});
}
function refreshData_spect_U() {
    $.ajax({url: "../data/spect_UBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_U = (resp);showData(selectedDataSource);}}});
}
function refreshData_spect_V() {
    $.ajax({url: "../data/spect_VBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_V = (resp);showData(selectedDataSource);}}});
}
function refreshData_spect_W() {
    $.ajax({url: "../data/spect_WBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_spect_W = (resp);showData(selectedDataSource);}}});
}

function refreshData_ph_Value() {
    $.ajax({url: "../data/ph_ValueBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_ph_Value = (resp);showData(selectedDataSource);}}});
}
function refreshData_ph_Voltage() {
    $.ajax({url: "../data/ph_VoltageBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_ph_Voltage = (resp);showData(selectedDataSource);}}});
}

function refreshData_button_Green() {
    $.ajax({url: "../data/button_GreenBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_button_Green = (resp);showData(selectedDataSource);}}});
}
function refreshData_button_Red() {
    $.ajax({url: "../data/button_RedBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_button_Red = (resp);showData(selectedDataSource);}}});
}

function refreshData_hr_confidence() {
    $.ajax({url: "../data/hr_confidenceBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_hr_confidence = (resp);showData(selectedDataSource);}}});
}
function refreshData_hr_extStatus() {
    $.ajax({url: "../data/hr_extStatusBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_hr_extStatus = (resp);showData(selectedDataSource);}}});
}
function refreshData_hr_irLed() {
    $.ajax({url: "../data/hr_irLedBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_hr_irLed = (resp);showData(selectedDataSource);}}});
}
function refreshData_hr_redLed() {
    $.ajax({url: "../data/hr_redLedBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_hr_redLed = (resp);showData(selectedDataSource);}}});
}
function refreshData_hr_rValue() {
    $.ajax({url: "../data/hr_rValueBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_hr_rValue = (resp);showData(selectedDataSource);}}});
}
function refreshData_hr_status() {
    $.ajax({url: "../data/hr_statusBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_hr_status = (resp);showData(selectedDataSource);}}});
}


function refreshData_scale_CalibrationDate() {
    $.ajax({url: "../data/scale_CalibrationDateBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_scale_CalibrationDate = (resp);showData(selectedDataSource);}}});
}
function refreshData_scale_CalibrationFactor() {
    $.ajax({url: "../data/scale_CalibrationFactorBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_scale_CalibrationFactor = (resp);showData(selectedDataSource);}}});
}
function refreshData_scale_Reading() {
    $.ajax({url: "../data/scale_ReadingBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_scale_Reading = (resp);showData(selectedDataSource);}}});
}
function refreshData_scale_Weight() {
    $.ajax({url: "../data/scale_WeightBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_scale_Weight = (resp);showData(selectedDataSource);}}});
}
function refreshData_scale_ZeroOffset() {
    $.ajax({url: "../data/scale_ZeroOffsetBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_scale_ZeroOffset = (resp);showData(selectedDataSource);}}});
}

function refreshData_voiceRecognition() {
    let timeStamp = dataSet_TableUpdateTimes["voiceRecognition"];
    if (dataSet_voiceRecognition.length == 0) timeStamp = moment(Date.now()).add(timeToBakcAtStart,'m').unix()*1000;
    $.ajax({url: "../data/voiceRecognitionBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_voiceRecognition = dataSet_voiceRecognition.concat(resp);showData(selectedDataSource);}}});

}
function refreshData_pwm() {
    let timeStamp = dataSet_TableUpdateTimes["pwm"];
    if (dataSet_pwm.length == 0) timeStamp = moment(Date.now()).add(timeToBakcAtStart,'m').unix()*1000;
    $.ajax({url: "../data/pwmBetweenTimeStamps", data: { from: dateFrom, to: dateTo }, method: 'GET', dataType: 'json', success: function(resp) {if(resp) { dataSet_pwm = dataSet_pwm.concat(resp);showData(selectedDataSource);}}});

}
//endregion
//endregion

//region Process

let earliestTimeStamp = Number.MAX_SAFE_INTEGER, latestTimeStamp = Number.MIN_SAFE_INTEGER;
function processData() {

    let temperatureData_device1 = [], temperatureData_device2 = [], temperatureData_device3 = [], temperatureData_device4 = [],
        humidityData_device1 = [], humidityData_device2 = [], humidityData_device3 = [], humidityData_device4 = [],
        hr_heartRateData_device1 = [], hr_heartRateData_device2 = [], hr_heartRateData_device3 = [], hr_heartRateData_device4 = [],
        hr_oxygenData_device1 = [], hr_oxygenData_device2 = [], hr_oxygenData_device3 = [], hr_oxygenData_device4 = []
    ;

    let timeStampMin = dateFrom, timeStampMax = dateTo,
        sum_temperatureData_1 = 0, cnt_temperatureData_1 = 0, min_temperatureData_1 = Number.MAX_VALUE, max_temperatureData_1 = Number.MIN_VALUE, current_temperatureData_1 = 0,
        sum_temperatureData_2 = 0, cnt_temperatureData_2 = 0, min_temperatureData_2 = Number.MAX_VALUE, max_temperatureData_2 = Number.MIN_VALUE, current_temperatureData_2 = 0,
        sum_temperatureData_3 = 0, cnt_temperatureData_3 = 0, min_temperatureData_3 = Number.MAX_VALUE, max_temperatureData_3 = Number.MIN_VALUE, current_temperatureData_3 = 0,
        sum_temperatureData_4 = 0, cnt_temperatureData_4 = 0, min_temperatureData_4 = Number.MAX_VALUE, max_temperatureData_4 = Number.MIN_VALUE, current_temperatureData_4 = 0,
        sum_humidityData_1 = 0, cnt_humidityData_1 = 0, min_humidityData_1 = Number.MAX_VALUE, max_humidityData_1 = Number.MIN_VALUE, current_humidityData_1 = 0,
        sum_humidityData_2 = 0, cnt_humidityData_2 = 0, min_humidityData_2 = Number.MAX_VALUE, max_humidityData_2 = Number.MIN_VALUE, current_humidityData_2 = 0,
        sum_humidityData_3 = 0, cnt_humidityData_3 = 0, min_humidityData_3 = Number.MAX_VALUE, max_humidityData_3 = Number.MIN_VALUE, current_humidityData_3 = 0,
        sum_humidityData_4 = 0, cnt_humidityData_4 = 0, min_humidityData_4 = Number.MAX_VALUE, max_humidityData_4 = Number.MIN_VALUE, current_humidityData_4 = 0,
        sum_hr_oxygenData_1 = 0, cnt_hr_oxygenData_1 = 0, min_hr_oxygenData_1 = Number.MAX_VALUE, max_hr_oxygenData_1 = Number.MIN_VALUE, current_hr_oxygenData_1 = 0,
        sum_hr_oxygenData_2 = 0, cnt_hr_oxygenData_2 = 0, min_hr_oxygenData_2 = Number.MAX_VALUE, max_hr_oxygenData_2 = Number.MIN_VALUE, current_hr_oxygenData_2 = 0,
        sum_hr_oxygenData_3 = 0, cnt_hr_oxygenData_3 = 0, min_hr_oxygenData_3 = Number.MAX_VALUE, max_hr_oxygenData_3 = Number.MIN_VALUE, current_hr_oxygenData_3 = 0,
        sum_hr_oxygenData_4 = 0, cnt_hr_oxygenData_4 = 0, min_hr_oxygenData_4 = Number.MAX_VALUE, max_hr_oxygenData_4 = Number.MIN_VALUE, current_hr_oxygenData_4 = 0,
        sum_hr_heartRateData_1 = 0, cnt_hr_heartRateData_1 = 0, min_hr_heartRateData_1 = Number.MAX_VALUE, max_hr_heartRateData_1 = Number.MIN_VALUE, current_hr_heartRateData_1 = 0,
        sum_hr_heartRateData_2 = 0, cnt_hr_heartRateData_2 = 0, min_hr_heartRateData_2 = Number.MAX_VALUE, max_hr_heartRateData_2 = Number.MIN_VALUE, current_hr_heartRateData_2 = 0,
        sum_hr_heartRateData_3 = 0, cnt_hr_heartRateData_3 = 0, min_hr_heartRateData_3 = Number.MAX_VALUE, max_hr_heartRateData_3 = Number.MIN_VALUE, current_hr_heartRateData_3 = 0,
        sum_hr_heartRateData_4 = 0, cnt_hr_heartRateData_4 = 0, min_hr_heartRateData_4 = Number.MAX_VALUE, max_hr_heartRateData_4 = Number.MIN_VALUE, current_hr_heartRateData_4 = 0
    ;

    dataSet_temperature.forEach((tempData) => {
        if(tempData.timeStamp < earliestTimeStamp) earliestTimeStamp = tempData.timeStamp;
        if(tempData.timeStamp > latestTimeStamp) latestTimeStamp = tempData.timeStamp;

        switch(tempData.deviceId) {
            case selectedDeviceId:     temperatureData_device1.push({ x: tempData.timeStamp, y: tempData.temperature}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_temperatureData_1 = tempData.temperature; sum_temperatureData_1 += tempData.temperature; cnt_temperatureData_1++; if(tempData.temperature < min_temperatureData_1 ) min_temperatureData_1=tempData.temperature; if(tempData.temperature > max_temperatureData_1 ) max_temperatureData_1 =tempData.temperature;} break;
            case "egy":     temperatureData_device1.push({ x: tempData.timeStamp, y: tempData.temperature}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_temperatureData_1 = tempData.temperature; sum_temperatureData_1 += tempData.temperature; cnt_temperatureData_1++; if(tempData.temperature < min_temperatureData_1 ) min_temperatureData_1=tempData.temperature; if(tempData.temperature > max_temperatureData_1 ) max_temperatureData_1 =tempData.temperature;} break;
            case "ketto":   temperatureData_device2.push({ x: tempData.timeStamp, y: tempData.temperature}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_temperatureData_2 = tempData.temperature; sum_temperatureData_2 += tempData.temperature; cnt_temperatureData_2++; if(tempData.temperature < min_temperatureData_2 ) min_temperatureData_2=tempData.temperature; if(tempData.temperature > max_temperatureData_2 ) max_temperatureData_2 =tempData.temperature;} break;
            case "harom":   temperatureData_device3.push({ x: tempData.timeStamp, y: tempData.temperature}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_temperatureData_3 = tempData.temperature; sum_temperatureData_3 += tempData.temperature; cnt_temperatureData_3++; if(tempData.temperature < min_temperatureData_3 ) min_temperatureData_3=tempData.temperature; if(tempData.temperature > max_temperatureData_3 ) max_temperatureData_3 =tempData.temperature;} break;
            case "negy":    temperatureData_device4.push({ x: tempData.timeStamp, y: tempData.temperature}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_temperatureData_4 = tempData.temperature; sum_temperatureData_4 += tempData.temperature; cnt_temperatureData_4++; if(tempData.temperature < min_temperatureData_4 ) min_temperatureData_4=tempData.temperature; if(tempData.temperature > max_temperatureData_4 ) max_temperatureData_4 =tempData.temperature;} break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_humidity.forEach((tempData) => {
        if(tempData.timeStamp < earliestTimeStamp) earliestTimeStamp = tempData.timeStamp;
        if(tempData.timeStamp > latestTimeStamp) latestTimeStamp = tempData.timeStamp;
        switch(tempData.deviceId) {
            case selectedDeviceId:     humidityData_device1.push({ x: tempData.timeStamp, y: tempData.humidity}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_humidityData_1 = tempData.humidity; sum_humidityData_1 += tempData.humidity; cnt_humidityData_1++; if(tempData.humidity < min_humidityData_1 ) min_humidityData_1=tempData.humidity; if(tempData.humidity > max_humidityData_1 ) max_humidityData_1 =tempData.humidity;} break;
            case "egy":     humidityData_device1.push({ x: tempData.timeStamp, y: tempData.humidity}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_humidityData_1 = tempData.humidity; sum_humidityData_1 += tempData.humidity; cnt_humidityData_1++; if(tempData.humidity < min_humidityData_1 ) min_humidityData_1=tempData.humidity; if(tempData.humidity > max_humidityData_1 ) max_humidityData_1 =tempData.humidity;} break;
            case "ketto":   humidityData_device2.push({ x: tempData.timeStamp, y: tempData.humidity}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_humidityData_2 = tempData.humidity; sum_humidityData_2 += tempData.humidity; cnt_humidityData_2++; if(tempData.humidity < min_humidityData_2 ) min_humidityData_2=tempData.humidity; if(tempData.humidity > max_humidityData_2 ) max_humidityData_2 =tempData.humidity;} break;
            case "harom":   humidityData_device3.push({ x: tempData.timeStamp, y: tempData.humidity}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_humidityData_3 = tempData.humidity; sum_humidityData_3 += tempData.humidity; cnt_humidityData_3++; if(tempData.humidity < min_humidityData_3 ) min_humidityData_3=tempData.humidity; if(tempData.humidity > max_humidityData_3 ) max_humidityData_3 =tempData.humidity;} break;
            case "negy":    humidityData_device4.push({ x: tempData.timeStamp, y: tempData.humidity}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_humidityData_4 = tempData.humidity; sum_humidityData_4 += tempData.humidity; cnt_humidityData_4++; if(tempData.humidity < min_humidityData_4 ) min_humidityData_4=tempData.humidity; if(tempData.humidity > max_humidityData_4 ) max_humidityData_4 =tempData.humidity;} break;
            default:        console.log("Unknown deviceId"); break;
        }
    });

    dataSet_hr_heartRate.forEach((tempData) => {
        if(tempData.timeStamp < earliestTimeStamp) earliestTimeStamp = tempData.timeStamp;
        if(tempData.timeStamp > latestTimeStamp) latestTimeStamp = tempData.timeStamp;
        switch(tempData.deviceId) {
            case selectedDeviceId:     hr_heartRateData_device1.push({ x: tempData.timeStamp, y: tempData.hr_heartRate}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_heartRateData_1 = tempData.hr_heartRate; sum_hr_heartRateData_1 += tempData.hr_heartRate; cnt_hr_heartRateData_1++; if(tempData.hr_heartRate < min_hr_heartRateData_1 ) min_hr_heartRateData_1=tempData.hr_heartRate; if(tempData.hr_heartRate > max_hr_heartRateData_1 ) max_hr_heartRateData_1 =tempData.hr_heartRate;} break;
            case "egy":     hr_heartRateData_device1.push({ x: tempData.timeStamp, y: tempData.hr_heartRate}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_heartRateData_1 = tempData.hr_heartRate; sum_hr_heartRateData_1 += tempData.hr_heartRate; cnt_hr_heartRateData_1++; if(tempData.hr_heartRate < min_hr_heartRateData_1 ) min_hr_heartRateData_1=tempData.hr_heartRate; if(tempData.hr_heartRate > max_hr_heartRateData_1 ) max_hr_heartRateData_1 =tempData.hr_heartRate;} break;
            case "ketto":   hr_heartRateData_device2.push({ x: tempData.timeStamp, y: tempData.hr_heartRate}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_heartRateData_2 = tempData.hr_heartRate; sum_hr_heartRateData_2 += tempData.hr_heartRate; cnt_hr_heartRateData_2++; if(tempData.hr_heartRate < min_hr_heartRateData_2 ) min_hr_heartRateData_2=tempData.hr_heartRate; if(tempData.hr_heartRate > max_hr_heartRateData_2 ) max_hr_heartRateData_2 =tempData.hr_heartRate;} break;
            case "harom":   hr_heartRateData_device3.push({ x: tempData.timeStamp, y: tempData.hr_heartRate}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_heartRateData_3 = tempData.hr_heartRate; sum_hr_heartRateData_3 += tempData.hr_heartRate; cnt_hr_heartRateData_3++; if(tempData.hr_heartRate < min_hr_heartRateData_3 ) min_hr_heartRateData_3=tempData.hr_heartRate; if(tempData.hr_heartRate > max_hr_heartRateData_3 ) max_hr_heartRateData_3 =tempData.hr_heartRate;} break;
            case "negy":    hr_heartRateData_device4.push({ x: tempData.timeStamp, y: tempData.hr_heartRate}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_heartRateData_4 = tempData.hr_heartRate; sum_hr_heartRateData_4 += tempData.hr_heartRate; cnt_hr_heartRateData_4++; if(tempData.hr_heartRate < min_hr_heartRateData_4 ) min_hr_heartRateData_4=tempData.hr_heartRate; if(tempData.hr_heartRate > max_hr_heartRateData_4 ) max_hr_heartRateData_4 =tempData.hr_heartRate;} break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_hr_oxygen.forEach((tempData) => {
        if(tempData.timeStamp < earliestTimeStamp) earliestTimeStamp = tempData.timeStamp;
        if(tempData.timeStamp > latestTimeStamp) latestTimeStamp = tempData.timeStamp;
        switch(tempData.deviceId) {
            case selectedDeviceId:     hr_oxygenData_device1.push({ x: tempData.timeStamp, y: tempData.hr_oxygen}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_oxygenData_1 = tempData.hr_oxygen; sum_hr_oxygenData_1 += tempData.hr_oxygen; cnt_hr_oxygenData_1++; if(tempData.hr_oxygen < min_hr_oxygenData_1 ) min_hr_oxygenData_1=tempData.hr_oxygen; if(tempData.hr_oxygen > max_hr_oxygenData_1 ) max_hr_oxygenData_1 =tempData.hr_oxygen;} break;
            case "egy":     hr_oxygenData_device1.push({ x: tempData.timeStamp, y: tempData.hr_oxygen}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_oxygenData_1 = tempData.hr_oxygen; sum_hr_oxygenData_1 += tempData.hr_oxygen; cnt_hr_oxygenData_1++; if(tempData.hr_oxygen < min_hr_oxygenData_1 ) min_hr_oxygenData_1=tempData.hr_oxygen; if(tempData.hr_oxygen > max_hr_oxygenData_1 ) max_hr_oxygenData_1 =tempData.hr_oxygen;} break;
            case "ketto":   hr_oxygenData_device2.push({ x: tempData.timeStamp, y: tempData.hr_oxygen}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_oxygenData_2 = tempData.hr_oxygen; sum_hr_oxygenData_2 += tempData.hr_oxygen; cnt_hr_oxygenData_2++; if(tempData.hr_oxygen < min_hr_oxygenData_2 ) min_hr_oxygenData_2=tempData.hr_oxygen; if(tempData.hr_oxygen > max_hr_oxygenData_2 ) max_hr_oxygenData_2 =tempData.hr_oxygen;} break;
            case "harom":   hr_oxygenData_device3.push({ x: tempData.timeStamp, y: tempData.hr_oxygen}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_oxygenData_3 = tempData.hr_oxygen; sum_hr_oxygenData_3 += tempData.hr_oxygen; cnt_hr_oxygenData_3++; if(tempData.hr_oxygen < min_hr_oxygenData_3 ) min_hr_oxygenData_3=tempData.hr_oxygen; if(tempData.hr_oxygen > max_hr_oxygenData_3 ) max_hr_oxygenData_3 =tempData.hr_oxygen;} break;
            case "negy":    hr_oxygenData_device4.push({ x: tempData.timeStamp, y: tempData.hr_oxygen}); if(tempData.timeStamp >= timeStampMin && tempData.timeStamp <= timeStampMax) { current_hr_oxygenData_4 = tempData.hr_oxygen; sum_hr_oxygenData_4 += tempData.hr_oxygen; cnt_hr_oxygenData_4++; if(tempData.hr_oxygen < min_hr_oxygenData_4 ) min_hr_oxygenData_4=tempData.hr_oxygen; if(tempData.hr_oxygen > max_hr_oxygenData_4 ) max_hr_oxygenData_4 =tempData.hr_oxygen;} break;
            default:        console.log("Unknown deviceId"); break;
        }
    });


    let avgTemperatureData = 0, minTemperatureData = 0, maxTemperatureData = 0;
    let avgHumidityData = 0, minHumidityData = 0, maxHumidityData = 0;
    let avgOxygenData = 0, minOxygentData = 0, maxOxygentData = 0;
    let avgHeartRateData =0, minHeartRateData = 0, maxHeartRateData = 0;

    chart_oxygen.data        = {datasets: [{ label: "Véroxigén",      data: hr_oxygenData_device1,    fill: false, borderColor: colorOfOxygen,pointBackgroundColor: colorOfOxygen, pointBorderColor: colorOfOxygen, pointHoverBackgroundColor: colorOfOxygen, pointHoverBorderColor: colorOfOxygen,},]};
    chart_temperature.data   = {datasets: [{ label: "Hőmérséklet",    data: temperatureData_device1,  fill: false, borderColor: colorOfTemperature,pointBackgroundColor: colorOfTemperature, pointBorderColor: colorOfTemperature, pointHoverBackgroundColor: colorOfTemperature, pointHoverBorderColor: colorOfTemperature,},]};
    chart_humidity.data      = {datasets: [{ label: "Páratartalom",   data: humidityData_device1,     fill: false, borderColor: colorOfHumidity,pointBackgroundColor: colorOfHumidity, pointBorderColor: colorOfHumidity, pointHoverBackgroundColor: colorOfHumidity, pointHoverBorderColor: colorOfHumidity,},]};
    chart_heartRate.data     = {datasets: [{ label: "Pulzus",         data: hr_heartRateData_device1, fill: false, borderColor: colorOfHeartRate,pointBackgroundColor: colorOfHeartRate, pointBorderColor: colorOfHeartRate, pointHoverBackgroundColor: colorOfHeartRate, pointHoverBorderColor: colorOfHeartRate,},]};

    avgTemperatureData = sum_temperatureData_1 / cnt_temperatureData_1; minTemperatureData = min_temperatureData_1; maxTemperatureData = max_temperatureData_1;
    avgHumidityData = sum_humidityData_1 / cnt_humidityData_1; minHumidityData = min_humidityData_1; maxHumidityData = max_humidityData_1;
    avgOxygenData = sum_hr_oxygenData_1 / cnt_hr_oxygenData_1; minOxygentData = min_hr_oxygenData_1; maxOxygentData = max_hr_oxygenData_1;
    avgHeartRateData = sum_hr_heartRateData_1 / cnt_hr_oxygenData_1; minHeartRateData = min_hr_heartRateData_1; maxHeartRateData = max_hr_heartRateData_1;
    /*
    if(selectedDeviceId == "egy") {
        chart_oxygen.data        = {datasets: [{ label: "Véroxigén",      data: hr_oxygenData_device1,    fill: false, borderColor: colorOfOxygen,pointBackgroundColor: colorOfOxygen, pointBorderColor: colorOfOxygen, pointHoverBackgroundColor: colorOfOxygen, pointHoverBorderColor: colorOfOxygen,},]};
        chart_temperature.data   = {datasets: [{ label: "Hőmérséklet",    data: temperatureData_device1,  fill: false, borderColor: colorOfTemperature,pointBackgroundColor: colorOfTemperature, pointBorderColor: colorOfTemperature, pointHoverBackgroundColor: colorOfTemperature, pointHoverBorderColor: colorOfTemperature,},]};
        chart_humidity.data      = {datasets: [{ label: "Páratartalom",   data: humidityData_device1,     fill: false, borderColor: colorOfHumidity,pointBackgroundColor: colorOfHumidity, pointBorderColor: colorOfHumidity, pointHoverBackgroundColor: colorOfHumidity, pointHoverBorderColor: colorOfHumidity,},]};
        chart_heartRate.data     = {datasets: [{ label: "Pulzus",         data: hr_heartRateData_device1, fill: false, borderColor: colorOfHeartRate,pointBackgroundColor: colorOfHeartRate, pointBorderColor: colorOfHeartRate, pointHoverBackgroundColor: colorOfHeartRate, pointHoverBorderColor: colorOfHeartRate,},]};

        avgTemperatureData = sum_temperatureData_1 / cnt_temperatureData_1; minTemperatureData = min_temperatureData_1; maxTemperatureData = max_temperatureData_1;
        avgHumidityData = sum_humidityData_1 / cnt_humidityData_1; minHumidityData = min_humidityData_1; maxHumidityData = max_humidityData_1;
        avgOxygenData = sum_hr_oxygenData_1 / cnt_hr_oxygenData_1; minOxygentData = min_hr_oxygenData_1; maxOxygentData = max_hr_oxygenData_1;
        avgHeartRateData = sum_hr_heartRateData_1 / cnt_hr_oxygenData_1; minHeartRateData = min_hr_heartRateData_1; maxHeartRateData = max_hr_heartRateData_1;
    }
    else if(selectedDeviceId == "ketto") {
        chart_oxygen.data        = {datasets: [{ label: "Véroxigén",      data: hr_oxygenData_device2,    fill: false, borderColor: colorOfOxygen,pointBackgroundColor: colorOfOxygen, pointBorderColor: colorOfOxygen, pointHoverBackgroundColor: colorOfOxygen, pointHoverBorderColor: colorOfOxygen,},]};
        chart_temperature.data   = {datasets: [{ label: "Hőmérséklet",    data: temperatureData_device2,  fill: false, borderColor: colorOfTemperature,pointBackgroundColor: colorOfTemperature, pointBorderColor: colorOfTemperature, pointHoverBackgroundColor: colorOfTemperature, pointHoverBorderColor: colorOfTemperature,},]};
        chart_humidity.data      = {datasets: [{ label: "Páratartalom",   data: humidityData_device2,     fill: false, borderColor: colorOfHumidity,pointBackgroundColor: colorOfHumidity, pointBorderColor: colorOfHumidity, pointHoverBackgroundColor: colorOfHumidity, pointHoverBorderColor: colorOfHumidity,},]};
        chart_heartRate.data     = {datasets: [{ label: "Pulzus",         data: hr_heartRateData_device2, fill: false, borderColor: colorOfHeartRate,pointBackgroundColor: colorOfHeartRate, pointBorderColor: colorOfHeartRate, pointHoverBackgroundColor: colorOfHeartRate, pointHoverBorderColor: colorOfHeartRate,},]};
        avgTemperatureData = sum_temperatureData_2 / cnt_temperatureData_2; minTemperatureData = min_temperatureData_2; maxTemperatureData = max_temperatureData_2;
        avgHumidityData = sum_humidityData_2 / cnt_humidityData_2; minHumidityData = min_humidityData_2; maxHumidityData = max_humidityData_2;
        avgOxygenData = sum_hr_oxygenData_2 / cnt_hr_oxygenData_2; minOxygentData = min_hr_oxygenData_2; maxOxygentData = max_hr_oxygenData_2;
        avgHeartRateData = sum_hr_heartRateData_2 / cnt_hr_oxygenData_2; minHeartRateData = min_hr_heartRateData_2; maxHeartRateData = max_hr_heartRateData_2;
    }
    else if(selectedDeviceId == "harom") {
        chart_oxygen.data        = {datasets: [{ label: "Véroxigén",      data: hr_oxygenData_device3,    fill: false, borderColor: colorOfOxygen,pointBackgroundColor: colorOfOxygen, pointBorderColor: colorOfOxygen, pointHoverBackgroundColor: colorOfOxygen, pointHoverBorderColor: colorOfOxygen,},]};
        chart_temperature.data   = {datasets: [{ label: "Hőmérséklet",    data: temperatureData_device3,  fill: false, borderColor: colorOfTemperature,pointBackgroundColor: colorOfTemperature, pointBorderColor: colorOfTemperature, pointHoverBackgroundColor: colorOfTemperature, pointHoverBorderColor: colorOfTemperature,},]};
        chart_humidity.data      = {datasets: [{ label: "Páratartalom",   data: humidityData_device3,     fill: false, borderColor: colorOfHumidity,pointBackgroundColor: colorOfHumidity, pointBorderColor: colorOfHumidity, pointHoverBackgroundColor: colorOfHumidity, pointHoverBorderColor: colorOfHumidity,},]};
        chart_heartRate.data     = {datasets: [{ label: "Pulzus",         data: hr_heartRateData_device3, fill: false, borderColor: colorOfHeartRate,pointBackgroundColor: colorOfHeartRate, pointBorderColor: colorOfHeartRate, pointHoverBackgroundColor: colorOfHeartRate, pointHoverBorderColor: colorOfHeartRate,},]};
        avgTemperatureData = sum_temperatureData_3 / cnt_temperatureData_3; minTemperatureData = min_temperatureData_3; maxTemperatureData = max_temperatureData_3;
        avgHumidityData = sum_humidityData_3 / cnt_humidityData_3; minHumidityData = min_humidityData_3; maxHumidityData = max_humidityData_3;
        avgOxygenData = sum_hr_oxygenData_3 / cnt_hr_oxygenData_3; minOxygentData = min_hr_oxygenData_3; maxOxygentData = max_hr_oxygenData_3;
        avgHeartRateData = sum_hr_heartRateData_3 / cnt_hr_oxygenData_3; minHeartRateData = min_hr_heartRateData_3; maxHeartRateData = max_hr_heartRateData_3;
    }
    else if(selectedDeviceId == "negy") {
        chart_oxygen.data        = {datasets: [{ label: "Véroxigén",      data: hr_oxygenData_device4,    fill: false, borderColor: colorOfOxygen,pointBackgroundColor: colorOfOxygen, pointBorderColor: colorOfOxygen, pointHoverBackgroundColor: colorOfOxygen, pointHoverBorderColor: colorOfOxygen,},]};
        chart_temperature.data   = {datasets: [{ label: "Hőmérséklet",    data: temperatureData_device4,  fill: false, borderColor: colorOfTemperature,pointBackgroundColor: colorOfTemperature, pointBorderColor: colorOfTemperature, pointHoverBackgroundColor: colorOfTemperature, pointHoverBorderColor: colorOfTemperature,},]};
        chart_humidity.data      = {datasets: [{ label: "Páratartalom",   data: humidityData_device4,     fill: false, borderColor: colorOfHumidity,pointBackgroundColor: colorOfHumidity, pointBorderColor: colorOfHumidity, pointHoverBackgroundColor: colorOfHumidity, pointHoverBorderColor: colorOfHumidity,},]};
        chart_heartRate.data     = {datasets: [{ label: "Pulzus",         data: hr_heartRateData_device4, fill: false, borderColor: colorOfHeartRate,pointBackgroundColor: colorOfHeartRate, pointBorderColor: colorOfHeartRate, pointHoverBackgroundColor: colorOfHeartRate, pointHoverBorderColor: colorOfHeartRate,},]};
        avgTemperatureData = sum_temperatureData_4 / cnt_temperatureData_4; minTemperatureData = min_temperatureData_4; maxTemperatureData = max_temperatureData_4;
        avgHumidityData = sum_humidityData_4 / cnt_humidityData_4; minHumidityData = min_humidityData_4; maxHumidityData = max_humidityData_4;
        avgOxygenData = sum_hr_oxygenData_4 / cnt_hr_oxygenData_4; minOxygentData = min_hr_oxygenData_4; maxOxygentData = max_hr_oxygenData_4;
        avgHeartRateData = sum_hr_heartRateData_4 / cnt_hr_oxygenData_4; minHeartRateData = min_hr_heartRateData_4; maxHeartRateData = max_hr_heartRateData_4;
    }
     */

    //region Dekawave
    let mc_tag0 = {timeStamp:0,x:0, y:0, z:0},  mr_tag0 = {timeStamp:0,x:0, y:0, z:0}, mc_tag0_kalman_f = {timeStamp:0,x:0, y:0, z:0}, mc_tag0_kalman_c = {timeStamp:0,x:0, y:0, z:0},
        mc_tag1 = {timeStamp:0,x:0, y:0, z:0},  mr_tag1 = {timeStamp:0,x:0, y:0, z:0}, mc_tag1_kalman_f = {timeStamp:0,x:0, y:0, z:0}, mc_tag1_kalman_c = {timeStamp:0,x:0, y:0, z:0},
        mc_tag2 = {timeStamp:0,x:0, y:0, z:0},  mr_tag2 = {timeStamp:0,x:0, y:0, z:0}, mc_tag2_kalman_f = {timeStamp:0,x:0, y:0, z:0}, mc_tag2_kalman_c = {timeStamp:0,x:0, y:0, z:0},
        mc_tag3 = {timeStamp:0,x:0, y:0, z:0},  mr_tag3 = {timeStamp:0,x:0, y:0, z:0}, mc_tag3_kalman_f = {timeStamp:0,x:0, y:0, z:0}, mc_tag3_kalman_c = {timeStamp:0,x:0, y:0, z:0}
    ;

    let points_mc_tag0 = [], points_mc_tag1 = [], points_mc_tag2 = [], points_mc_tag3 = [],
        points_mr_tag0 = [], points_mr_tag1 = [], points_mr_tag2 = [], points_mr_tag3 = [],

        points_mc_tag0_kalman_c = [], points_mc_tag0_kalman_f = [],
        points_mc_tag1_kalman_c = [], points_mc_tag1_kalman_f = [],
        points_mc_tag2_kalman_c = [], points_mc_tag2_kalman_f = [],
        points_mc_tag3_kalman_c = [], points_mc_tag3_kalman_f = []
    ;

    dataSet_DecaWaveData.forEach((data) => {
        let pos = JSON.parse(data.pos);

        pos.x = parseFloat(pos.x);
        pos.y = parseFloat(pos.y);
        pos.z = parseFloat(pos.z);

        if(data.msgType == "b'mc'") {
            if(pos.x < 100 && pos.x > -100 && pos.y<100 && pos.x > -100) {
                switch (data.tag) {
                    case "0" :

                        if(data.timeStamp > mc_tag0.timeStamp) mc_tag0 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};

                        if(data.timeStamp > mc_tag0_kalman_f.timeStamp) mc_tag0_kalman_f = {timeStamp:data.timeStamp, x:(pos.position_kalman_calculated_x), y:(pos.position_kalman_calculated_y)};
                        if(data.timeStamp > mc_tag0_kalman_c.timeStamp) mc_tag0_kalman_c = {timeStamp:data.timeStamp, x:(pos.position_kalman_filtered_x), y:(pos.position_kalman_filtered_y)};

                        points_mc_tag0.push({"x": (pos.x), "y": (pos.y),});

                        points_mc_tag0_kalman_c.push({"x": (pos.position_kalman_calculated_x), "y": (pos.position_kalman_calculated_y),});
                        points_mc_tag0_kalman_f.push({"x": (pos.position_kalman_filtered_x), "y": (pos.position_kalman_filtered_y),});

                        break;
                    case "1" :
                        if(data.timeStamp > mc_tag1.timeStamp) mc_tag1 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};
                        points_mc_tag1.push({"x": (pos.x), "y": (pos.y),});
                        break;
                    case "2" :
                        if(data.timeStamp > mc_tag2.timeStamp) mc_tag2 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};
                        points_mc_tag2.push({"x": (pos.x), "y": (pos.y),});
                        break;
                    case "3" :
                        if(data.timeStamp > mc_tag3.timeStamp) mc_tag3 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};
                        points_mc_tag3.push({"x": (pos.x), "y": (pos.y),});
                        break;
                    default  : console.log("Unknown deviceId"); break;
                }
            }
        } else if(data.msgType == "b'mr'") {

            if(pos.x < 100 && pos.x > -100 && pos.y<100 && pos.x > -100) {
                switch (data.tag) {
                    case "0" :
                        if( data.timeStamp > mr_tag0.timeStamp) mr_tag0 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};
                        points_mr_tag0.push({"x": (pos.x), "y": (pos.y),});
                        break;
                    case "1" :
                        if( data.timeStamp > mr_tag1.timeStamp) mr_tag1 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};
                        points_mr_tag1.push({"x": (pos.x), "y": (pos.y),});
                        break;
                    case "2" :
                        if( data.timeStamp > mr_tag2.timeStamp) mr_tag2 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};
                        points_mr_tag2.push({"x": (pos.x), "y": (pos.y),});
                        break;
                    case "3" :
                        if( data.timeStamp > mr_tag3.timeStamp) mr_tag3 = {timeStamp:data.timeStamp, x:(pos.x), y:(pos.y), z:(pos.z)};
                        points_mr_tag3.push({"x": (pos.x), "y": (pos.y),});
                        break;
                    default  :
                        console.log("Unknown deviceId");
                        break;
                }
            }
        }
    });


    let tempPathPlot = [];
    //{"id": "flt-11", "classes": "device_1_mc_k_c", "points": points_mc_tag0_kalman_c,},
    //{"id": "flt-12", "classes": "device_2_mc_k_f", "points": points_mc_tag0_kalman_f,},

    /*
    {"id": "flt-2", "classes": "device_1_mr", "points": points_mr_tag0,},
    {"id": "flt-4", "classes": "device_2_mr", "points": points_mr_tag1,},
    {"id": "flt-6", "classes": "device_3_mr", "points": points_mr_tag2,},
    {"id": "flt-8", "classes": "device_4_mr", "points": points_mr_tag3,},
     */


    if(selectedDeviceId == "sisak_1")       {tempPathPlot.push({"id": "flt-1", "classes": "device_1_mc", "points": points_mr_tag0,});} //sisak
    else if(selectedDeviceId == "vallfa_1") {tempPathPlot.push({"id": "flt-3", "classes": "device_2_mc", "points": points_mr_tag1,});} //vallfa
    else if(selectedDeviceId == "szeker_1") {tempPathPlot.push({"id": "flt-5", "classes": "device_3_mc", "points": points_mr_tag2,});} //szeker 1
    else if(selectedDeviceId == "szeker_2") {tempPathPlot.push({"id": "flt-7", "classes": "device_4_mc", "points": points_mc_tag3,});} //szeker 2


    mapdata[pathplot.id()] = tempPathPlot;

    let polygons = [
        {"id": "anchor_0", "class": "anchor_1_vertex", "points": [ {"x":dataSet_KVPs.pos_1_x,"y":dataSet_KVPs.pos_1_y}]},
        {"id": "anchor_1", "class": "anchor_2_vertex", "points": [ {"x":dataSet_KVPs.pos_2_x,"y":dataSet_KVPs.pos_2_y}]},
        {"id": "anchor_2", "class": "anchor_3_vertex", "points": [ {"x":dataSet_KVPs.pos_3_x,"y":dataSet_KVPs.pos_3_y}]},
        {"id": "anchor_3", "class": "anchor_4_vertex", "points": [ {"x":dataSet_KVPs.pos_4_x,"y":dataSet_KVPs.pos_4_y}]},


        //{"id": "mc_tag0_kalman_c", "class": "mc_tag0_kalman_c_vertex",  "points": [ {"x":mc_tag0_kalman_c.x,"y":mc_tag0_kalman_c.y}]},
        //{"id": "mc_tag0_kalman_f", "class": "mc_tag0_kalman_f_vertex",  "points": [ {"x":mc_tag0_kalman_f.x,"y":mc_tag0_kalman_f.y}]},

        /*
        {"id": "mr_tag0", "name": "mr_tag0", "points": [ {"x":mr_tag0.x,"y":mr_tag0.y}]},
        {"id": "mr_tag1", "name": "mr_tag1", "points": [ {"x":mr_tag1.x,"y":mr_tag1.y}]},
        {"id": "mr_tag2", "name": "mr_tag2", "points": [ {"x":mr_tag2.x,"y":mr_tag2.y}]},
        {"id": "mr_tag3", "name": "mr_tag3", "points": [ {"x":mr_tag3.x,"y":mr_tag3.y}]},
         */

    ];

    if(selectedDeviceId == "sisak_1")       {polygons.push({"id": "mc_tag0", "class": "device_1_vertex",  "points": [ {"x":mr_tag0.x,"y":mr_tag0.y}]});}
    else if(selectedDeviceId == "vallfa_1") {polygons.push({"id": "mc_tag1", "class": "device_2_vertex",  "points": [ {"x":mr_tag1.x,"y":mr_tag1.y}]});}
    else if(selectedDeviceId == "szeker_1") {polygons.push({"id": "mc_tag2", "class": "device_3_vertex",  "points": [ {"x":mr_tag2.x,"y":mr_tag2.y}]});}
    else if(selectedDeviceId == "szeker_2") {polygons.push({"id": "mc_tag3", "class": "device_4_vertex",  "points": [ {"x":mr_tag3.x,"y":mr_tag3.y}]});}


    mapdata[overlays.id()] = {"polygons" : polygons};

    //console.log("MC - " + "x: " + (mc_tag0.x).toFixed(2) + ", y: " + (mc_tag0.y).toFixed(2) +", z: " + (mc_tag0.z).toFixed(2));
    //console.log("KA - " + "x: " + parseFloat(mc_tag0_kalman_c.x).toFixed(2) + ", y: " + parseFloat(mc_tag0_kalman_c.y).toFixed(2));

    d3.select("#myMap").datum(mapdata).call(map);

    //endregion

    try
    {
        chart_heartRate.annotation.elements['avg'].options.value = avgHeartRateData;
        chart_heartRate.annotation.elements['avg'].options.label.content = "Átl.: "+avgHeartRateData.toFixed(2);
        chart_heartRate.annotation.elements['min'].options.value = minHeartRateData;
        chart_heartRate.annotation.elements['min'].options.label.content = "Min.: "+minHeartRateData.toFixed(2);
        chart_heartRate.annotation.elements['max'].options.value = maxHeartRateData;
        chart_heartRate.annotation.elements['max'].options.label.content = "Max.: "+maxHeartRateData.toFixed(2);

        chart_temperature.annotation.elements['avg'].options.value = avgTemperatureData;
        chart_temperature.annotation.elements['avg'].options.label.content = "Átl.: "+avgTemperatureData.toFixed(2);
        chart_temperature.annotation.elements['min'].options.value = minTemperatureData;
        chart_temperature.annotation.elements['min'].options.label.content = "Min.: "+minTemperatureData.toFixed(2);
        chart_temperature.annotation.elements['max'].options.value = maxTemperatureData;
        chart_temperature.annotation.elements['max'].options.label.content = "Max.: "+maxTemperatureData.toFixed(2);

        chart_humidity.annotation.elements['avg'].options.value = avgHumidityData;
        chart_humidity.annotation.elements['avg'].options.label.content = "Átl.: "+avgHumidityData.toFixed(2);
        chart_humidity.annotation.elements['min'].options.value = minHumidityData;
        chart_humidity.annotation.elements['min'].options.label.content = "Min.: "+minHumidityData.toFixed(2);
        chart_humidity.annotation.elements['max'].options.value = maxHumidityData;
        chart_humidity.annotation.elements['max'].options.label.content = "Max.: "+maxHumidityData.toFixed(2);

        chart_oxygen.annotation.elements['avg'].options.value = avgOxygenData;
        chart_oxygen.annotation.elements['avg'].options.label.content = "Átl.: "+avgOxygenData.toFixed(2);
        chart_oxygen.annotation.elements['min'].options.value = minOxygentData;
        chart_oxygen.annotation.elements['min'].options.label.content = "Min.: "+minOxygentData.toFixed(2);
        chart_oxygen.annotation.elements['max'].options.value = maxOxygentData;
        chart_oxygen.annotation.elements['max'].options.label.content = "Max.: "+maxOxygentData.toFixed(2);


        chart_temperature.update({preservation: true});
        chart_humidity.update({preservation: true});
        chart_heartRate.update({preservation: true});
        chart_oxygen.update({preservation: true});

    } catch (e) {console.log(e);}

}

function processScaleData() {

    let scale_AvgWeightData_device1 = [], scale_AvgWeightData_device2 = [], scale_AvgWeightData_device3 = [], scale_AvgWeightData_device4 = [],
        scale_WeightData_device1 = [], scale_WeightData_device2 = [], scale_WeightData_device3 = [], scale_WeightData_device4 = [],
        scale_ReadingData_device1 = [], scale_ReadingData_device2 = [], scale_ReadingData_device3 = [], scale_ReadingData_device4 = [],
        scale_ZeroOffsetData_device1 = [], scale_ZeroOffsetData_device2 = [], scale_ZeroOffsetData_device3 = [], scale_ZeroOffsetData_device4 = [],
        scale_CalibrationFactorData_device1 = [], scale_CalibrationFactorData_device2 = [], scale_CalibrationFactorData_device3 = [], scale_CalibrationFactorData_device4 = []
    ;

    dataSet_scale_AvgWeight.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     scale_AvgWeightData_device1.push({ x: tempData.timeStamp, y: tempData.scale_AvgWeight}); break;
            case "ketto":   scale_AvgWeightData_device2.push({ x: tempData.timeStamp, y: tempData.scale_AvgWeight}); break;
            case "harom":   scale_AvgWeightData_device3.push({ x: tempData.timeStamp, y: tempData.scale_AvgWeight}); break;
            case "negy":    scale_AvgWeightData_device4.push({ x: tempData.timeStamp, y: tempData.scale_AvgWeight}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_scale_Reading.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     scale_ReadingData_device1.push({ x: tempData.timeStamp, y: tempData.scale_Reading}); break;
            case "ketto":   scale_ReadingData_device2.push({ x: tempData.timeStamp, y: tempData.scale_Reading}); break;
            case "harom":   scale_ReadingData_device3.push({ x: tempData.timeStamp, y: tempData.scale_Reading}); break;
            case "negy":    scale_ReadingData_device4.push({ x: tempData.timeStamp, y: tempData.scale_Reading}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_scale_Weight.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     scale_WeightData_device1.push({ x: tempData.timeStamp, y: tempData.scale_Weight}); break;
            case "ketto":   scale_WeightData_device2.push({ x: tempData.timeStamp, y: tempData.scale_Weight}); break;
            case "harom":   scale_WeightData_device3.push({ x: tempData.timeStamp, y: tempData.scale_Weight}); break;
            case "negy":    scale_WeightData_device4.push({ x: tempData.timeStamp, y: tempData.scale_Weight}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_scale_ZeroOffset.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     scale_ZeroOffsetData_device1.push({ x: tempData.timeStamp, y: tempData.scale_ZeroOffset}); break;
            case "ketto":   scale_ZeroOffsetData_device2.push({ x: tempData.timeStamp, y: tempData.scale_ZeroOffset}); break;
            case "harom":   scale_ZeroOffsetData_device3.push({ x: tempData.timeStamp, y: tempData.scale_ZeroOffset}); break;
            case "negy":    scale_ZeroOffsetData_device4.push({ x: tempData.timeStamp, y: tempData.scale_ZeroOffset}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_scale_CalibrationFactor.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     scale_CalibrationFactorData_device1.push({ x: tempData.timeStamp, y: tempData.scale_CalibrationFactor}); break;
            case "ketto":   scale_CalibrationFactorData_device2.push({ x: tempData.timeStamp, y: tempData.scale_CalibrationFactor}); break;
            case "harom":   scale_CalibrationFactorData_device3.push({ x: tempData.timeStamp, y: tempData.scale_CalibrationFactor}); break;
            case "negy":    scale_CalibrationFactorData_device4.push({ x: tempData.timeStamp, y: tempData.scale_CalibrationFactor}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });

    if(selectedDataSource == "scale") {
        chart_temperature.data = {
            datasets: [
                { label: "Súly átlag", data: scale_AvgWeightData_device1,  fill: false},
                { label: "Súly",      data: scale_WeightData_device1,     fill: false},
                //{ label: "Mérés",data: scale_ReadingData_device1,     fill: false},
                //{ label: "Zero Offset", data: scale_ZeroOffsetData_device1,  fill: false},
                //{ label: "Calibration Factor",      data: scale_CalibrationFactorData_device1,     fill: false}
            ]
        };
        chart_humidity.data = {
            datasets: [
                { label: "Súly átlag", data: scale_AvgWeightData_device2,  fill: false},
                { label: "Súly",      data: scale_WeightData_device2,     fill: false},
                //{ label: "Mérés",data: scale_ReadingData_device2,     fill: false},
                //{ label: "Zero Offset", data: scale_ZeroOffsetData_device2,  fill: false},
                //{ label: "Calibration Factor",      data: scale_CalibrationFactorData_device2,     fill: false}
            ]
        };
        chart_heartRate.data = {
            datasets: [
                { label: "Súly átlag", data: scale_AvgWeightData_device3,  fill: false},
                { label: "Súly",      data: scale_WeightData_device3,     fill: false},
                //{ label: "Mérés",data: scale_ReadingData_device3,     fill: false},
                //{ label: "Zero Offset", data: scale_ZeroOffsetData_device3,  fill: false},
                //{ label: "Calibration Factor",      data: scale_CalibrationFactorData_device3,     fill: false}
            ]
        };
        chart_oxygen.data = {
            datasets: [
                { label: "Súly átlag", data: scale_AvgWeightData_device4,  fill: false},
                { label: "Súly",      data: scale_WeightData_device4,     fill: false},
                //{ label: "Mérés",data: scale_ReadingData_device4,     fill: false},
                //{ label: "Zero Offset", data: scale_ZeroOffsetData_device4,  fill: false},
                //{ label: "Calibration Factor",      data: scale_CalibrationFactorData_device4,     fill: false},
            ]
        };

        chart_temperature.update(0);
        chart_humidity.update(0);
        chart_heartRate.update(0);
        chart_oxygen.update(0);
    }
}

function processLightData() {

    let spect_A_device1 = [], spect_A_device2 = [], spect_A_device3 = [], spect_A_device4 = [],
        spect_B_device1 = [], spect_B_device2 = [], spect_B_device3 = [], spect_B_device4 = [],
        spect_C_device1 = [], spect_C_device2 = [], spect_C_device3 = [], spect_C_device4 = [],
        spect_D_device1 = [], spect_D_device2 = [], spect_D_device3 = [], spect_D_device4 = [],
        spect_E_device1 = [], spect_E_device2 = [], spect_E_device3 = [], spect_E_device4 = [],
        spect_F_device1 = [], spect_F_device2 = [], spect_F_device3 = [], spect_F_device4 = [],
        spect_G_device1 = [], spect_G_device2 = [], spect_G_device3 = [], spect_G_device4 = [],
        spect_H_device1 = [], spect_H_device2 = [], spect_H_device3 = [], spect_H_device4 = [],
        spect_I_device1 = [], spect_I_device2 = [], spect_I_device3 = [], spect_I_device4 = [],
        spect_J_device1 = [], spect_J_device2 = [], spect_J_device3 = [], spect_J_device4 = [],
        spect_K_device1 = [], spect_K_device2 = [], spect_K_device3 = [], spect_K_device4 = [],
        spect_L_device1 = [], spect_L_device2 = [], spect_L_device3 = [], spect_L_device4 = [],
        spect_R_device1 = [], spect_R_device2 = [], spect_R_device3 = [], spect_R_device4 = [],
        spect_S_device1 = [], spect_S_device2 = [], spect_S_device3 = [], spect_S_device4 = [],
        spect_T_device1 = [], spect_T_device2 = [], spect_T_device3 = [], spect_T_device4 = [],
        spect_U_device1 = [], spect_U_device2 = [], spect_U_device3 = [], spect_U_device4 = [],
        spect_V_device1 = [], spect_V_device2 = [], spect_V_device3 = [], spect_V_device4 = [],
        spect_W_device1 = [], spect_W_device2 = [], spect_W_device3 = [], spect_W_device4 = []
    ;

    dataSet_spect_A.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_A_device1.push({ x: tempData.timeStamp, y: tempData.spect_A}); break;
            case "ketto":   spect_A_device2.push({ x: tempData.timeStamp, y: tempData.spect_A}); break;
            case "harom":   spect_A_device3.push({ x: tempData.timeStamp, y: tempData.spect_A}); break;
            case "negy":    spect_A_device4.push({ x: tempData.timeStamp, y: tempData.spect_A}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_B.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_B_device1.push({ x: tempData.timeStamp, y: tempData.spect_B}); break;
            case "ketto":   spect_B_device2.push({ x: tempData.timeStamp, y: tempData.spect_B}); break;
            case "harom":   spect_B_device3.push({ x: tempData.timeStamp, y: tempData.spect_B}); break;
            case "negy":    spect_B_device4.push({ x: tempData.timeStamp, y: tempData.spect_B}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_C.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_C_device1.push({ x: tempData.timeStamp, y: tempData.spect_C}); break;
            case "ketto":   spect_C_device2.push({ x: tempData.timeStamp, y: tempData.spect_C}); break;
            case "harom":   spect_C_device3.push({ x: tempData.timeStamp, y: tempData.spect_C}); break;
            case "negy":    spect_C_device4.push({ x: tempData.timeStamp, y: tempData.spect_C}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_D.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_D_device1.push({ x: tempData.timeStamp, y: tempData.spect_D}); break;
            case "ketto":   spect_D_device2.push({ x: tempData.timeStamp, y: tempData.spect_D}); break;
            case "harom":   spect_D_device3.push({ x: tempData.timeStamp, y: tempData.spect_D}); break;
            case "negy":    spect_D_device4.push({ x: tempData.timeStamp, y: tempData.spect_D}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_E.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_E_device1.push({ x: tempData.timeStamp, y: tempData.spect_E}); break;
            case "ketto":   spect_E_device2.push({ x: tempData.timeStamp, y: tempData.spect_E}); break;
            case "harom":   spect_E_device3.push({ x: tempData.timeStamp, y: tempData.spect_E}); break;
            case "negy":    spect_E_device4.push({ x: tempData.timeStamp, y: tempData.spect_E}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_F.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_F_device1.push({ x: tempData.timeStamp, y: tempData.spect_F}); break;
            case "ketto":   spect_F_device2.push({ x: tempData.timeStamp, y: tempData.spect_F}); break;
            case "harom":   spect_F_device3.push({ x: tempData.timeStamp, y: tempData.spect_F}); break;
            case "negy":    spect_F_device4.push({ x: tempData.timeStamp, y: tempData.spect_F}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_G.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_G_device1.push({ x: tempData.timeStamp, y: tempData.spect_G}); break;
            case "ketto":   spect_G_device2.push({ x: tempData.timeStamp, y: tempData.spect_G}); break;
            case "harom":   spect_G_device3.push({ x: tempData.timeStamp, y: tempData.spect_G}); break;
            case "negy":    spect_G_device4.push({ x: tempData.timeStamp, y: tempData.spect_G}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_H.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_H_device1.push({ x: tempData.timeStamp, y: tempData.spect_H}); break;
            case "ketto":   spect_H_device2.push({ x: tempData.timeStamp, y: tempData.spect_H}); break;
            case "harom":   spect_H_device3.push({ x: tempData.timeStamp, y: tempData.spect_H}); break;
            case "negy":    spect_H_device4.push({ x: tempData.timeStamp, y: tempData.spect_H}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_I.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_I_device1.push({ x: tempData.timeStamp, y: tempData.spect_I}); break;
            case "ketto":   spect_I_device2.push({ x: tempData.timeStamp, y: tempData.spect_I}); break;
            case "harom":   spect_I_device3.push({ x: tempData.timeStamp, y: tempData.spect_I}); break;
            case "negy":    spect_I_device4.push({ x: tempData.timeStamp, y: tempData.spect_I}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_J.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_J_device1.push({ x: tempData.timeStamp, y: tempData.spect_J}); break;
            case "ketto":   spect_J_device2.push({ x: tempData.timeStamp, y: tempData.spect_J}); break;
            case "harom":   spect_J_device3.push({ x: tempData.timeStamp, y: tempData.spect_J}); break;
            case "negy":    spect_J_device4.push({ x: tempData.timeStamp, y: tempData.spect_J}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_K.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_K_device1.push({ x: tempData.timeStamp, y: tempData.spect_K}); break;
            case "ketto":   spect_K_device2.push({ x: tempData.timeStamp, y: tempData.spect_K}); break;
            case "harom":   spect_K_device3.push({ x: tempData.timeStamp, y: tempData.spect_K}); break;
            case "negy":    spect_K_device4.push({ x: tempData.timeStamp, y: tempData.spect_K}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_L.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_L_device1.push({ x: tempData.timeStamp, y: tempData.spect_L}); break;
            case "ketto":   spect_L_device2.push({ x: tempData.timeStamp, y: tempData.spect_L}); break;
            case "harom":   spect_L_device3.push({ x: tempData.timeStamp, y: tempData.spect_L}); break;
            case "negy":    spect_L_device4.push({ x: tempData.timeStamp, y: tempData.spect_L}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_R.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_R_device1.push({ x: tempData.timeStamp, y: tempData.spect_R}); break;
            case "ketto":   spect_R_device2.push({ x: tempData.timeStamp, y: tempData.spect_R}); break;
            case "harom":   spect_R_device3.push({ x: tempData.timeStamp, y: tempData.spect_R}); break;
            case "negy":    spect_R_device4.push({ x: tempData.timeStamp, y: tempData.spect_R}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_S.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_S_device1.push({ x: tempData.timeStamp, y: tempData.spect_S}); break;
            case "ketto":   spect_S_device2.push({ x: tempData.timeStamp, y: tempData.spect_S}); break;
            case "harom":   spect_S_device3.push({ x: tempData.timeStamp, y: tempData.spect_S}); break;
            case "negy":    spect_S_device4.push({ x: tempData.timeStamp, y: tempData.spect_S}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_T.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_T_device1.push({ x: tempData.timeStamp, y: tempData.spect_T}); break;
            case "ketto":   spect_T_device2.push({ x: tempData.timeStamp, y: tempData.spect_T}); break;
            case "harom":   spect_T_device3.push({ x: tempData.timeStamp, y: tempData.spect_T}); break;
            case "negy":    spect_T_device4.push({ x: tempData.timeStamp, y: tempData.spect_T}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_U.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_U_device1.push({ x: tempData.timeStamp, y: tempData.spect_U}); break;
            case "ketto":   spect_U_device2.push({ x: tempData.timeStamp, y: tempData.spect_U}); break;
            case "harom":   spect_U_device3.push({ x: tempData.timeStamp, y: tempData.spect_U}); break;
            case "negy":    spect_U_device4.push({ x: tempData.timeStamp, y: tempData.spect_U}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_V.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_V_device1.push({ x: tempData.timeStamp, y: tempData.spect_V}); break;
            case "ketto":   spect_V_device2.push({ x: tempData.timeStamp, y: tempData.spect_V}); break;
            case "harom":   spect_V_device3.push({ x: tempData.timeStamp, y: tempData.spect_V}); break;
            case "negy":    spect_V_device4.push({ x: tempData.timeStamp, y: tempData.spect_V}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_spect_W.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     spect_W_device1.push({ x: tempData.timeStamp, y: tempData.spect_W}); break;
            case "ketto":   spect_W_device2.push({ x: tempData.timeStamp, y: tempData.spect_W}); break;
            case "harom":   spect_W_device3.push({ x: tempData.timeStamp, y: tempData.spect_W}); break;
            case "negy":    spect_W_device4.push({ x: tempData.timeStamp, y: tempData.spect_W}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });

    if(selectedDataSource == "light") {
        chart_temperature.data = {
            datasets: [
                { label: "A", data: spect_A_device1,  fill: false},
                { label: "B", data: spect_B_device1,  fill: false},
                { label: "C", data: spect_C_device1,  fill: false},
                { label: "D", data: spect_D_device1,  fill: false},
                { label: "E", data: spect_E_device1,  fill: false},
                { label: "F", data: spect_F_device1,  fill: false},
                { label: "G", data: spect_G_device1,  fill: false},
                { label: "H", data: spect_H_device1,  fill: false},
                { label: "I", data: spect_I_device1,  fill: false},
                { label: "J", data: spect_J_device1,  fill: false},
                { label: "K", data: spect_K_device1,  fill: false},
                { label: "L", data: spect_L_device1,  fill: false},
                { label: "R", data: spect_R_device1,  fill: false},
                { label: "S", data: spect_S_device1,  fill: false},
                { label: "T", data: spect_T_device1,  fill: false},
                { label: "U", data: spect_U_device1,  fill: false},
                { label: "V", data: spect_V_device1,  fill: false},
                { label: "W", data: spect_W_device1,  fill: false}
            ]
        };
        chart_humidity.data = {
            datasets: [
                { label: "A", data: spect_A_device2,  fill: false},
                { label: "B", data: spect_B_device2,  fill: false},
                { label: "C", data: spect_C_device2,  fill: false},
                { label: "D", data: spect_D_device2,  fill: false},
                { label: "E", data: spect_E_device2,  fill: false},
                { label: "F", data: spect_F_device2,  fill: false},
                { label: "G", data: spect_G_device2,  fill: false},
                { label: "H", data: spect_H_device2,  fill: false},
                { label: "I", data: spect_I_device2,  fill: false},
                { label: "J", data: spect_J_device2,  fill: false},
                { label: "K", data: spect_K_device2,  fill: false},
                { label: "L", data: spect_L_device2,  fill: false},
                { label: "R", data: spect_R_device2,  fill: false},
                { label: "S", data: spect_S_device2,  fill: false},
                { label: "T", data: spect_T_device2,  fill: false},
                { label: "U", data: spect_U_device2,  fill: false},
                { label: "V", data: spect_V_device2,  fill: false},
                { label: "W", data: spect_W_device2,  fill: false}
            ]
        };
        chart_heartRate.data = {
            datasets: [
                { label: "A", data: spect_A_device3,  fill: false},
                { label: "B", data: spect_B_device3,  fill: false},
                { label: "C", data: spect_C_device3,  fill: false},
                { label: "D", data: spect_D_device3,  fill: false},
                { label: "E", data: spect_E_device3,  fill: false},
                { label: "F", data: spect_F_device3,  fill: false},
                { label: "G", data: spect_G_device3,  fill: false},
                { label: "H", data: spect_H_device3,  fill: false},
                { label: "I", data: spect_I_device3,  fill: false},
                { label: "J", data: spect_J_device3,  fill: false},
                { label: "K", data: spect_K_device3,  fill: false},
                { label: "L", data: spect_L_device3,  fill: false},
                { label: "R", data: spect_R_device3,  fill: false},
                { label: "S", data: spect_S_device3,  fill: false},
                { label: "T", data: spect_T_device3,  fill: false},
                { label: "U", data: spect_U_device3,  fill: false},
                { label: "V", data: spect_V_device3,  fill: false},
                { label: "W", data: spect_W_device3,  fill: false}
            ]
        };
        chart_oxygen.data = {
            datasets: [
                { label: "A", data: spect_A_device4,  fill: false},
                { label: "B", data: spect_B_device4,  fill: false},
                { label: "C", data: spect_C_device4,  fill: false},
                { label: "D", data: spect_D_device4,  fill: false},
                { label: "E", data: spect_E_device4,  fill: false},
                { label: "F", data: spect_F_device4,  fill: false},
                { label: "G", data: spect_G_device4,  fill: false},
                { label: "H", data: spect_H_device4,  fill: false},
                { label: "I", data: spect_I_device4,  fill: false},
                { label: "J", data: spect_J_device4,  fill: false},
                { label: "K", data: spect_K_device4,  fill: false},
                { label: "L", data: spect_L_device4,  fill: false},
                { label: "R", data: spect_R_device4,  fill: false},
                { label: "S", data: spect_S_device4,  fill: false},
                { label: "T", data: spect_T_device4,  fill: false},
                { label: "U", data: spect_U_device4,  fill: false},
                { label: "V", data: spect_V_device4,  fill: false},
                { label: "W", data: spect_W_device4,  fill: false}
            ]
        };

        chart_temperature.update(0);
        chart_humidity.update(0);
        chart_heartRate.update(0);
        chart_oxygen.update(0);
    }
}

function processPHData() {

    let PHValueData_device1 = [],
        PHValueData_device2 = [],
        PHValueData_device3 = [],
        PHValueData_device4 = []

        /*
        PHVoltageData_device1 = [],
        PHVoltageData_device2 = [],
        PHVoltageData_device3 = [],
        PHVoltageData_device4 = []
         */
    ;

    dataSet_ph_Value.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     PHValueData_device1.push({ x: tempData.timeStamp, y: tempData.ph_Value}); break;
            case "ketto":   PHValueData_device2.push({ x: tempData.timeStamp, y: tempData.ph_Value}); break;
            case "harom":   PHValueData_device3.push({ x: tempData.timeStamp, y: tempData.ph_Value}); break;
            case "negy":    PHValueData_device4.push({ x: tempData.timeStamp, y: tempData.ph_Value}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_ph_Voltage.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     PHVoltageData_device1.push({ x: tempData.timeStamp, y: tempData.ph_Voltage}); break;
            case "ketto":   PHVoltageData_device2.push({ x: tempData.timeStamp, y: tempData.ph_Voltage}); break;
            case "harom":   PHVoltageData_device3.push({ x: tempData.timeStamp, y: tempData.ph_Voltage}); break;
            case "negy":    PHVoltageData_device4.push({ x: tempData.timeStamp, y: tempData.ph_Voltage}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });

    if(selectedDataSource == "ph") {
        chart_temperature.data = {
            datasets: [
                { label: "PH Érték",    data: PHValueData_device1,       fill: false},
                //{ label: "Feszültség",  data: PHVoltageData_device1,     fill: false}
            ]
        };
        chart_humidity.data = {
            datasets: [
                { label: "PH Érték",    data: PHValueData_device2,       fill: false},
                //{ label: "Feszültség",  data: PHVoltageData_device2,     fill: false}
            ]
        };
        chart_heartRate.data = {
            datasets: [
                { label: "PH Érték",    data: PHValueData_device3,       fill: false},
                //{ label: "Feszültség",  data: PHVoltageData_device3,     fill: false}
            ]
        };
        chart_oxygen.data = {
            datasets: [
                { label: "PH Érték",    data: PHValueData_device4,       fill: false},
                //{ label: "Feszültség",  data: PHVoltageData_device4,     fill: false}
            ]
        };

        chart_temperature.update(0);
        chart_humidity.update(0);
        chart_heartRate.update(0);
        chart_oxygen.update(0);
    }
}

function processButtonData() {

    let greenButtonData_device1 = [],
        greenButtonData_device2 = [],
        greenButtonData_device3 = [],
        greenButtonData_device4 = [],
        redButtonData_device1 = [],
        redButtonData_device2 = [],
        redButtonData_device3 = [],
        redButtonData_device4 = []
    ;

    dataSet_button_Green.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     greenButtonData_device1.push({ x: tempData.timeStamp, y: tempData.button_Green}); break;
            case "ketto":   greenButtonData_device2.push({ x: tempData.timeStamp, y: tempData.button_Green}); break;
            case "harom":   greenButtonData_device3.push({ x: tempData.timeStamp, y: tempData.button_Green}); break;
            case "negy":    greenButtonData_device4.push({ x: tempData.timeStamp, y: tempData.button_Green}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_button_Red.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     redButtonData_device1.push({ x: tempData.timeStamp, y: tempData.button_Red}); break;
            case "ketto":   redButtonData_device2.push({ x: tempData.timeStamp, y: tempData.button_Red}); break;
            case "harom":   redButtonData_device3.push({ x: tempData.timeStamp, y: tempData.button_Red}); break;
            case "negy":    redButtonData_device4.push({ x: tempData.timeStamp, y: tempData.button_Red}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });

    if(selectedDataSource == "button") {
        chart_temperature.data = {
            datasets: [
                { label: "Zöld",   data: greenButtonData_device1,  fill: false},
                { label: "Piros",  data: redButtonData_device1,     fill: false}
            ]
        };
        chart_humidity.data = {
            datasets: [
                { label: "Zöld",   data: greenButtonData_device2,  fill: false},
                { label: "Piros",  data: redButtonData_device2,     fill: false}
            ]
        };
        chart_heartRate.data = {
            datasets: [
                { label: "Zöld",   data: greenButtonData_device3,  fill: false},
                { label: "Piros",  data: redButtonData_device3,     fill: false}
            ]
        };
        chart_oxygen.data = {
            datasets: [
                { label: "Zöld",   data: greenButtonData_device4,  fill: false},
                { label: "Piros",  data: redButtonData_device4,     fill: false}
            ]
        };

        chart_temperature.update(0);
        chart_humidity.update(0);
        chart_heartRate.update(0);
        chart_oxygen.update(0);
    }
}

function processHeartRateData() {

    let hr_confidenceData_device1 = [], hr_confidenceData_device2 = [], hr_confidenceData_device3 = [], hr_confidenceData_device4 = [],
        hr_extStatusData_device1 = [], hr_extStatusData_device2 = [], hr_extStatusData_device3 = [], hr_extStatusData_device4 = [],
        hr_statusData_device1 = [], hr_statusData_device2 = [], hr_statusData_device3 = [], hr_statusData_device4 = [],
        hr_heartRateData_device1 = [], hr_heartRateData_device2 = [], hr_heartRateData_device3 = [], hr_heartRateData_device4 = [],
        hr_irLedData_device1 = [], hr_irLedData_device2 = [], hr_irLedData_device3 = [], hr_irLedData_device4 = [],
        hr_redLedData_device1 = [], hr_redLedData_device2 = [], hr_redLedData_device3 = [], hr_redLedData_device4 = [],
        hr_oxygenData_device1 = [], hr_oxygenData_device2 = [], hr_oxygenData_device3 = [], hr_oxygenData_device4 = [],
        hr_rValueData_device1 = [], hr_rValueData_device2 = [], hr_rValueData_device3 = [], hr_rValueData_device4 = []
    ;

    dataSet_hr_confidence.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     hr_confidenceData_device1.push({ x: tempData.timeStamp, y: tempData.hr_confidence}); break;
            case "ketto":   hr_confidenceData_device2.push({ x: tempData.timeStamp, y: tempData.hr_confidence}); break;
            case "harom":   hr_confidenceData_device3.push({ x: tempData.timeStamp, y: tempData.hr_confidence}); break;
            case "negy":    hr_confidenceData_device4.push({ x: tempData.timeStamp, y: tempData.hr_confidence}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_hr_status.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     hr_statusData_device1.push({ x: tempData.timeStamp, y: tempData.hr_status}); break;
            case "ketto":   hr_statusData_device2.push({ x: tempData.timeStamp, y: tempData.hr_status}); break;
            case "harom":   hr_statusData_device3.push({ x: tempData.timeStamp, y: tempData.hr_status}); break;
            case "negy":    hr_statusData_device4.push({ x: tempData.timeStamp, y: tempData.hr_status}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_hr_extStatus.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     hr_extStatusData_device1.push({ x: tempData.timeStamp, y: tempData.hr_extStatus}); break;
            case "ketto":   hr_extStatusData_device2.push({ x: tempData.timeStamp, y: tempData.hr_extStatus}); break;
            case "harom":   hr_extStatusData_device3.push({ x: tempData.timeStamp, y: tempData.hr_extStatus}); break;
            case "negy":    hr_extStatusData_device4.push({ x: tempData.timeStamp, y: tempData.hr_extStatus}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_hr_heartRate.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     hr_heartRateData_device1.push({ x: tempData.timeStamp, y: tempData.hr_heartRate}); break;
            case "ketto":   hr_heartRateData_device2.push({ x: tempData.timeStamp, y: tempData.hr_heartRate}); break;
            case "harom":   hr_heartRateData_device3.push({ x: tempData.timeStamp, y: tempData.hr_heartRate}); break;
            case "negy":    hr_heartRateData_device4.push({ x: tempData.timeStamp, y: tempData.hr_heartRate}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_hr_redLed.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     hr_redLedData_device1.push({ x: tempData.timeStamp, y: tempData.hr_redLed}); break;
            case "ketto":   hr_redLedData_device2.push({ x: tempData.timeStamp, y: tempData.hr_redLed}); break;
            case "harom":   hr_redLedData_device3.push({ x: tempData.timeStamp, y: tempData.hr_redLed}); break;
            case "negy":    hr_redLedData_device4.push({ x: tempData.timeStamp, y: tempData.hr_redLed}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_hr_irLed.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     hr_irLedData_device1.push({ x: tempData.timeStamp, y: tempData.hr_irLed}); break;
            case "ketto":   hr_irLedData_device2.push({ x: tempData.timeStamp, y: tempData.hr_irLed}); break;
            case "harom":   hr_irLedData_device3.push({ x: tempData.timeStamp, y: tempData.hr_irLed}); break;
            case "negy":    hr_irLedData_device4.push({ x: tempData.timeStamp, y: tempData.hr_irLed}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_hr_oxygen.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     hr_oxygenData_device1.push({ x: tempData.timeStamp, y: tempData.hr_oxygen}); break;
            case "ketto":   hr_oxygenData_device2.push({ x: tempData.timeStamp, y: tempData.hr_oxygen}); break;
            case "harom":   hr_oxygenData_device3.push({ x: tempData.timeStamp, y: tempData.hr_oxygen}); break;
            case "negy":    hr_oxygenData_device4.push({ x: tempData.timeStamp, y: tempData.hr_oxygen}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });
    dataSet_hr_rValue.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     hr_rValueData_device1.push({ x: tempData.timeStamp, y: tempData.hr_rValue}); break;
            case "ketto":   hr_rValueData_device2.push({ x: tempData.timeStamp, y: tempData.hr_rValue}); break;
            case "harom":   hr_rValueData_device3.push({ x: tempData.timeStamp, y: tempData.hr_rValue}); break;
            case "negy":    hr_rValueData_device4.push({ x: tempData.timeStamp, y: tempData.hr_rValue}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });

    if(selectedDataSource == "heartRate") {
        chart_temperature.data = {
            datasets: [
                { label: "Pulzus",      data: hr_heartRateData_device1,  fill: false},
                { label: "Oxigén",      data: hr_oxygenData_device1,  fill: false},

                { label: "Konfidenca",  data: hr_confidenceData_device1,  fill: false},

                { label: "Státusz+",    data: hr_extStatusData_device1,     fill: false},
                { label: "Státusz",     data: hr_statusData_device1,     fill: false},

                { label: "R érték",     data: hr_rValueData_device1,     fill: false},

                { label: "Infra LED",   data: hr_irLedData_device1,     fill: false},
                { label: "Piros LED",   data: hr_redLedData_device1,     fill: false}
            ]
        };
        chart_humidity.data = {
            datasets: [
                { label: "Pulzus",      data: hr_heartRateData_device2,  fill: false},
                { label: "Oxigén",      data: hr_oxygenData_device2,  fill: false},

                { label: "Konfidenca",  data: hr_confidenceData_device2,  fill: false},

                { label: "Státusz+",    data: hr_extStatusData_device2,     fill: false},
                { label: "Státusz",     data: hr_statusData_device2,     fill: false},

                { label: "R érték",     data: hr_rValueData_device2,     fill: false},

                { label: "Infra LED",   data: hr_irLedData_device2,     fill: false},
                { label: "Piros LED",   data: hr_redLedData_device2,     fill: false}
            ]
        };
        chart_heartRate.data = {
            datasets: [
                { label: "Pulzus",      data: hr_heartRateData_device3,  fill: false},
                { label: "Oxigén",      data: hr_oxygenData_device3,  fill: false},

                { label: "Konfidenca",  data: hr_confidenceData_device3,  fill: false},

                { label: "Státusz+",    data: hr_extStatusData_device3,     fill: false},
                { label: "Státusz",     data: hr_statusData_device3,     fill: false},
                { label: "R érték",     data: hr_rValueData_device3,     fill: false},

                { label: "Infra LED+",  data: hr_irLedData_device3,     fill: false},
                { label: "Piros LED",   data: hr_redLedData_device3,     fill: false}
            ]
        };
        chart_oxygen.data = {
            datasets: [
                { label: "Pulzus",      data: hr_heartRateData_device4,  fill: false},
                { label: "Oxigén",      data: hr_oxygenData_device4,  fill: false},
                { label: "Konfidenca",  data: hr_confidenceData_device4,  fill: false},

                { label: "Státusz+",    data: hr_extStatusData_device4,     fill: false},
                { label: "Státusz",     data: hr_statusData_device4,     fill: false},

                { label: "R érték",     data: hr_rValueData_device4,     fill: false},

                { label: "Infra LED+",  data: hr_irLedData_device4,     fill: false},
                { label: "Piros LED",   data: hr_redLedData_device4,     fill: false}
            ]
        };

        chart_temperature.update(0);
        chart_humidity.update(0);
        chart_heartRate.update(0);
        chart_oxygen.update(0);
    }
}

function processPWMData() {

    let pwmData_device1 = [],
        pwmData_device2 = [],
        pwmData_device3 = [],
        pwmData_device4 = []
    ;

    dataSet_pwm.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     pwmData_device1.push({ x: tempData.timeStamp, y: tempData.pwm}); break;
            case "ketto":   pwmData_device2.push({ x: tempData.timeStamp, y: tempData.pwm}); break;
            case "harom":   pwmData_device3.push({ x: tempData.timeStamp, y: tempData.pwm}); break;
            case "negy":    pwmData_device4.push({ x: tempData.timeStamp, y: tempData.pwm}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });

    if(selectedDataSource == "pwm") {
        chart_temperature.data = {datasets: [{ label: "PWM", data: pwmData_device1,  fill: false}]};
        chart_humidity.data = {datasets: [{ label: "PWM", data: pwmData_device2,  fill: false}]};
        chart_heartRate.data = {datasets: [{ label: "PWM", data: pwmData_device3,  fill: false}]};
        chart_oxygen.data = {datasets: [{ label: "PWM", data: pwmData_device4,  fill: false}]};

        chart_temperature.update(0);
        chart_humidity.update(0);
        chart_heartRate.update(0);
        chart_oxygen.update(0);
    }
}

function processVoiceData() {

    let voiceRecognitionData_device1 = [],
        voiceRecognitionData_device2 = [],
        voiceRecognitionData_device3 = [],
        voiceRecognitionData_device4 = []
    ;

    dataSet_voiceRecognition.forEach((tempData) => {
        switch(tempData.deviceId) {
            case "egy":     voiceRecognitionData_device1.push({ x: tempData.timeStamp, y: tempData.voiceRecognition}); break;
            case "ketto":   voiceRecognitionData_device2.push({ x: tempData.timeStamp, y: tempData.voiceRecognition}); break;
            case "harom":   voiceRecognitionData_device3.push({ x: tempData.timeStamp, y: tempData.voiceRecognition}); break;
            case "negy":    voiceRecognitionData_device4.push({ x: tempData.timeStamp, y: tempData.voiceRecognition}); break;
            default:        console.log("Unknown deviceId"); break;
        }
    });

    if(selectedDataSource == "voice") {
        chart_temperature.data = {datasets: [{ label: "voice", data: voiceRecognitionData_device1,  fill: false}]};
        chart_humidity.data = {datasets: [{ label: "voice", data: voiceRecognitionData_device2,  fill: false}]};
        chart_heartRate.data = {datasets: [{ label: "voice", data: voiceRecognitionData_device3,  fill: false}]};
        chart_oxygen.data = {datasets: [{ label: "voice", data: voiceRecognitionData_device4,  fill: false}]};

        chart_temperature.update(0);
        chart_humidity.update(0);
        chart_heartRate.update(0);
        chart_oxygen.update(0);
    }
}

//endregion

//region Display
function displayData(deviceToDisplay) {
    selectedDeviceId = deviceToDisplay;$("#deviceIdLabel").text(deviceToDisplay);processData(selectedDeviceId);
}

function showData(deviceToDisplay) {

    if(deviceToDisplay != selectedDeviceId) {
        selectedDeviceId = deviceToDisplay;
        dataSet_rfid = [];
        let device = getDeviceById(deviceToDisplay);
        let icon_className = 'fab fa-bluetooth ';
        if(device.connectionStatus == "CONNECTED") icon_className += 'goodColor';
        else icon_className += 'badColor';
        let iconItem = "<i class='"+icon_className+"'></i>"
        $("#deviceIdLabel").html(iconItem + " " + device.deviceName);
    }

    processData();
}
//endregion

//region Export
function exportSelectedDeviceBetweenTimeStamps() {
    dateTo      = moment($('#dateTo').val()).valueOf();
    dateFrom    = moment($('#dateFrom').val()).valueOf();
    window.open('../generator/sisakByDeviceIdBetweenTimestamps?deviceId='+selectedDeviceId+"&dateFrom="+dateFrom+"&dateTo="+dateTo);
}

function exportSelectedDevice() {
    window.open('../generator/sisakByDeviceId?deviceId='+selectedDeviceId);
}

function exportSelectedDeviceBetweenTimeStamps_json() {
    dateTo      = moment($('#dateTo').val()).valueOf();
    dateFrom    = moment($('#dateFrom').val()).valueOf();
    window.open('../generator/sisakByDeviceIdBetweenTimestamps-json?deviceId='+selectedDeviceId+"&dateFrom="+dateFrom+"&dateTo="+dateTo);
}

function exportSelectedDevice_json() {
    window.open('../generator/sisakByDeviceId-json?deviceId='+selectedDeviceId);
}
//endregion

function refreshEnumerationUsersOnSisakReplay(caller) {
    if(caller == "devices") {
        rebuildDeviceList();
        if(selectedDeviceId == null) {
            devices.forEach(item=> {
                if(item.deviceType == layoutType) {
                    if(selectedDeviceId == null) showData(item.deviceId);
                }
            });
        }
    }
}

function resizePanel() {
    let mapContainer = $("#mapContainer")[0];
    let myMap = $("#myMap")[0];

    //$('#myMap').css('height', mapContainer.clientHeight+'px');
    $('#mapSVG').attr('width', mapContainer.clientWidth-25+'px');
    $('.map-layers').attr('width', mapContainer.clientWidth-25+'px');
}