var express = require('express'),
    router = express.Router(),
    fs = require('fs'),
    path = require('path'),
    middleware = require('../middleware/index'),
    db = require('../lib//SQLConnection'),
    documentManager = require('../lib/documentManager'),
    eventLogger = require('../lib/eventLogger')
;

router.get('/vallfaByDeviceIdBetweenTimestamps', middleware.isLoggedIn, async function(req, res, next) {
    try {
        let from = req.query.dateFrom,
            to = req.query.dateTo,
            deviceId = req.query.deviceId
        ;
        let generationResult = await documentManager.vallfaByDeviceIdBetweenTimestamps(from, to, deviceId);
        if(generationResult.result === eventLogger.eventResult.Success) {documentManager.sendFileInRes(generationResult.path, 'vallfa-'+ deviceId +"-"+from+"-"+to+'.xlsx', res);}
        else {res.status(500).json({ status: "ERROR", message: "Hiba történt a dokumentum generálása során" });}
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});
router.get('/vallfaByDeviceId', middleware.isLoggedIn, async function(req, res, next) {
    try {
        let deviceId = req.query.deviceId
        ;
        let generationResult = await documentManager.vallfaByDeviceId(deviceId);
        if(generationResult.result === eventLogger.eventResult.Success) {documentManager.sendFileInRes(generationResult.path, 'vallfa-'+ deviceId +'.xlsx', res);}
        else {res.status(500).json({ status: "ERROR", message: "Hiba történt a dokumentum generálása során" });}
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});
router.get('/vallfaByDeviceIdBetweenTimestamps-json', middleware.isLoggedIn, async function(req, res, next) {
    //http://localhost:3000/generator/vallfaByDeviceIdBetweenTimestamps-json?dateFrom=1657692000000&dateTo=1657692060000&deviceId=egy
    try {
        let from = req.query.dateFrom,
            to = req.query.dateTo,
            deviceId = req.query.deviceId
        ;

        const [
            temperatures,
            humidity,
            pressure,
            weight,
            rfid,
            current,
            voltage
        ] = await Promise.all([
            db.getTemperatureOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getHumidityOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getPressureOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getScale_AvgWeightOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getrfidOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getcurrentOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getvoltageOfDeviceBetweenTimeStamps(from, to, deviceId)
        ]);

        res.status(200).json(
            {
                temperatures:temperatures,
                humidity:humidity,
                pressure:pressure,
                weight:weight,
                rfid:rfid,
                current:current,
                voltage:voltage
            }
        );
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});
router.get('/vallfaByDeviceId-json', middleware.isLoggedIn, async function(req, res, next) {
    //http://localhost:3000/generator/vallfaByDeviceIdBetweenTimestamps-json?dateFrom=1657692000000&dateTo=1657692060000&deviceId=egy
    try {
        let deviceId = req.query.deviceId;

        const [
            temperatures,
            humidity,
            pressure,
            weight,
            rfid,
            current,
            voltage
        ] = await Promise.all([
            db.getTemperatureOfDevice(deviceId),
            db.getHumidityOfDevice(deviceId),
            db.getPressureOfDevice(deviceId),
            db.getScale_AvgWeightOfDevice(deviceId),
            db.getrfidOfDevice(deviceId),
            db.getcurrentOfDevice(deviceId),
            db.getvoltageOfDevice(deviceId)
        ]);

        res.status(200).json(
            {
                temperatures:temperatures,
                humidity:humidity,
                pressure:pressure,
                weight:weight,
                rfid:rfid,
                current:current,
                voltage:voltage
            }
        );
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});

router.get('/szekerByDeviceIdBetweenTimestamps', middleware.isLoggedIn, async function(req, res, next) {
    try {
        let from = req.query.dateFrom,
            to = req.query.dateTo,
            deviceId = req.query.deviceId
        ;
        let generationResult = await documentManager.szekerByDeviceIdBetweenTimestamps(from, to, deviceId);
        if(generationResult.result === eventLogger.eventResult.Success) {documentManager.sendFileInRes(generationResult.path, 'szeker-'+ deviceId +"-"+from+"-"+to+'.xlsx', res);}
        else {res.status(500).json({ status: "ERROR", message: "Hiba történt a dokumentum generálása során" });}
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});
router.get('/szekerByDeviceId', middleware.isLoggedIn, async function(req, res, next) {
    try {
        let deviceId = req.query.deviceId
        ;
        let generationResult = await documentManager.szekerByDeviceId(deviceId);
        if(generationResult.result === eventLogger.eventResult.Success) {documentManager.sendFileInRes(generationResult.path, 'szeker-'+ deviceId +'.xlsx', res);}
        else {res.status(500).json({ status: "ERROR", message: "Hiba történt a dokumentum generálása során" });}
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});
router.get('/szekerByDeviceIdBetweenTimestamps-json', middleware.isLoggedIn, async function(req, res, next) {
    //http://localhost:3000/generator/vallfaByDeviceIdBetweenTimestamps-json?dateFrom=1657692000000&dateTo=1657692060000&deviceId=egy
    try {
        let from = req.query.dateFrom,
            to = req.query.dateTo,
            deviceId = req.query.deviceId
        ;
        const [
            temperatures,
            humidity,
            pressure,
            weight,

            temperature_Ambient,
            temperature_Ambient_B,
            temperature_Ambient_C,
            temperature_Thermocouple,
            temperature_Thermocouple_B,
            temperature_Thermocouple_C,

            rfid,
            current,
            voltage
        ] = await Promise.all([
            db.getTemperatureOfDeviceBetweenTimeStamps(from, to, deviceId),

            db.getHumidityOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getPressureOfDeviceBetweenTimeStamps(from, to, deviceId),

            db.getScale_AvgWeightOfDeviceBetweenTimeStamps(from, to, deviceId),

            db.gettemperatureAmbientOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.gettemperature_B_AmbientOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.gettemperature_C_AmbientOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.gettemperatureThermocoupleOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.gettemperature_B_ThermocoupleOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.gettemperature_C_ThermocoupleOfDeviceBetweenTimeStamps(from, to, deviceId),

            db.getrfidOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getcurrentOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getvoltageOfDeviceBetweenTimeStamps(from, to, deviceId)
        ]);

        res.status(200).json(
            {
                temperatures:temperatures,
                humidity:humidity,
                pressure:pressure,
                weight:weight,

                temperature_Ambient:temperature_Ambient,
                temperature_Ambient_B:temperature_Ambient_B,
                temperature_Ambient_C:temperature_Ambient_C,
                temperature_Thermocouple:temperature_Thermocouple,
                temperature_Thermocouple_B:temperature_Thermocouple_B,
                temperature_Thermocouple_C:temperature_Thermocouple_C,

                rfid:rfid,
                current:current,
                voltage:voltage
            }
        );
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});
router.get('/szekerByDeviceId-json', middleware.isLoggedIn, async function(req, res, next) {
    //http://localhost:3000/generator/vallfaByDeviceIdBetweenTimestamps-json?dateFrom=1657692000000&dateTo=1657692060000&deviceId=egy
    try {
        let deviceId = req.query.deviceId;

        const [
            temperatures,
            humidity,
            pressure,
            weight,

            temperature_Ambient,
            temperature_Ambient_B,
            temperature_Ambient_C,
            temperature_Thermocouple,
            temperature_Thermocouple_B,
            temperature_Thermocouple_C,

            rfid,
            current,
            voltage
        ] = await Promise.all([
            db.getTemperatureOfDevice(deviceId),
            db.getHumidityOfDevice(deviceId),
            db.getPressureOfDevice(deviceId),
            db.getScale_AvgWeightOfDevice(deviceId),
            db.gettemperatureAmbientOfDevice(deviceId),
            db.gettemperature_B_AmbientOfDevice(deviceId),
            db.gettemperature_C_AmbientOfDevice(deviceId),
            db.gettemperatureThermocoupleOfDevice(deviceId),
            db.gettemperature_B_ThermocoupleOfDevice(deviceId),
            db.gettemperature_C_ThermocoupleOfDevice(deviceId),
            db.getrfidOfDevice(deviceId),
            db.getcurrentOfDevice(deviceId),
            db.getvoltageOfDevice(deviceId)
        ]);

        res.status(200).json(
            {
                temperatures:temperatures,
                humidity:humidity,
                pressure:pressure,
                weight:weight,

                temperature_Ambient:temperature_Ambient,
                temperature_Ambient_B:temperature_Ambient_B,
                temperature_Ambient_C:temperature_Ambient_C,
                temperature_Thermocouple:temperature_Thermocouple,
                temperature_Thermocouple_B:temperature_Thermocouple_B,
                temperature_Thermocouple_C:temperature_Thermocouple_C,

                rfid:rfid,
                current:current,
                voltage:voltage
            }
        );
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});

router.get('/szurkalogepByDeviceIdBetweenTimestamps', middleware.isLoggedIn, async function(req, res, next) {
    try {
        let from = req.query.dateFrom,
            to = req.query.dateTo,
            deviceId = req.query.deviceId
        ;
        let generationResult = await documentManager.szurkalogepByDeviceIdBetweenTimestamps(from, to, deviceId);
        if(generationResult.result === eventLogger.eventResult.Success) {documentManager.sendFileInRes(generationResult.path, 'szurkalogep-'+ deviceId +"-"+from+"-"+to+'.xlsx', res);}
        else {res.status(500).json({ status: "ERROR", message: "Hiba történt a dokumentum generálása során" });}
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});
router.get('/szurkalogepByDeviceId', middleware.isLoggedIn, async function(req, res, next) {
    try {
        let deviceId = req.query.deviceId
        ;
        let generationResult = await documentManager.szurkalogepByDeviceId(deviceId);
        if(generationResult.result === eventLogger.eventResult.Success) {documentManager.sendFileInRes(generationResult.path, 'szurkalogep-'+ deviceId +'.xlsx', res);}
        else {res.status(500).json({ status: "ERROR", message: "Hiba történt a dokumentum generálása során" });}
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});
router.get('/szurkalogepByDeviceIdBetweenTimestamps-json', middleware.isLoggedIn, async function(req, res, next) {
    //http://localhost:3000/generator/vallfaByDeviceIdBetweenTimestamps-json?dateFrom=1657692000000&dateTo=1657692060000&deviceId=egy
    try {
        let from = req.query.dateFrom,
            to = req.query.dateTo,
            deviceId = req.query.deviceId
        ;
        const [
            temperature_Thermocouple,
            rfid,
            Spect_A,
            Spect_B,
            Spect_C,
            Spect_D,
            Spect_E,
            Spect_F,
            Spect_G,
            Spect_H,
            Spect_I,
            Spect_J,
            Spect_K,
            Spect_L,
            Spect_R,
            Spect_S,
            Spect_T,
            Spect_U,
            Spect_V,
            Spect_W

        ] = await Promise.all([
            db.gettemperatureThermocoupleOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getrfidOfDeviceBetweenTimeStamps(from, to, deviceId),

            db.getSpect_AOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_BOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_COfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_DOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_EOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_FOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_GOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_HOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_IOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_JOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_KOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_LOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_ROfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_SOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_TOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_UOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_VOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getSpect_WOfDeviceBetweenTimeStamps(from, to, deviceId),

        ]);

        res.status(200).json(
            {
                temperature_Thermocouple:temperature_Thermocouple,
                rfid:rfid,
                Spect_A:Spect_A,
                Spect_B:Spect_B,
                Spect_C:Spect_C,
                Spect_D:Spect_D,
                Spect_E:Spect_E,
                Spect_F:Spect_F,
                Spect_G:Spect_G,
                Spect_H:Spect_H,
                Spect_I:Spect_I,
                Spect_J:Spect_J,
                Spect_K:Spect_K,
                Spect_L:Spect_L,
                Spect_R:Spect_R,
                Spect_S:Spect_S,
                Spect_T:Spect_T,
                Spect_U:Spect_U,
                Spect_V:Spect_V,
                Spect_W:Spect_W,
            }
        );
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});
router.get('/szurkalogepByDeviceId-json', middleware.isLoggedIn, async function(req, res, next) {
    //http://localhost:3000/generator/vallfaByDeviceIdBetweenTimestamps-json?dateFrom=1657692000000&dateTo=1657692060000&deviceId=egy
    try {
        let deviceId = req.query.deviceId;

        const [
            temperature_Thermocouple,
            rfid,
            Spect_A,
            Spect_B,
            Spect_C,
            Spect_D,
            Spect_E,
            Spect_F,
            Spect_G,
            Spect_H,
            Spect_I,
            Spect_J,
            Spect_K,
            Spect_L,
            Spect_R,
            Spect_S,
            Spect_T,
            Spect_U,
            Spect_V,
            Spect_W

        ] = await Promise.all([
            db.gettemperatureThermocoupleOfDevice(deviceId),
            db.getrfidOfDevice(deviceId),

            db.getSpect_AOfDevice(deviceId),
            db.getSpect_BOfDevice(deviceId),
            db.getSpect_COfDevice(deviceId),
            db.getSpect_DOfDevice(deviceId),
            db.getSpect_EOfDevice(deviceId),
            db.getSpect_FOfDevice(deviceId),
            db.getSpect_GOfDevice(deviceId),
            db.getSpect_HOfDevice(deviceId),
            db.getSpect_IOfDevice(deviceId),
            db.getSpect_JOfDevice(deviceId),
            db.getSpect_KOfDevice(deviceId),
            db.getSpect_LOfDevice(deviceId),
            db.getSpect_ROfDevice(deviceId),
            db.getSpect_SOfDevice(deviceId),
            db.getSpect_TOfDevice(deviceId),
            db.getSpect_UOfDevice(deviceId),
            db.getSpect_VOfDevice(deviceId),
            db.getSpect_WOfDevice(deviceId),
        ]);

        res.status(200).json(
            {
                temperature_Thermocouple:temperature_Thermocouple,
                rfid:rfid,
                Spect_A:Spect_A,
                Spect_B:Spect_B,
                Spect_C:Spect_C,
                Spect_D:Spect_D,
                Spect_E:Spect_E,
                Spect_F:Spect_F,
                Spect_G:Spect_G,
                Spect_H:Spect_H,
                Spect_I:Spect_I,
                Spect_J:Spect_J,
                Spect_K:Spect_K,
                Spect_L:Spect_L,
                Spect_R:Spect_R,
                Spect_S:Spect_S,
                Spect_T:Spect_T,
                Spect_U:Spect_U,
                Spect_V:Spect_V,
                Spect_W:Spect_W,
            }
        );
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});

router.get('/sisakByDeviceIdBetweenTimestamps', middleware.isLoggedIn, async function(req, res, next) {
    try {
        let from = req.query.dateFrom,
            to = req.query.dateTo,
            deviceId = req.query.deviceId
        ;
        let generationResult = await documentManager.sisakByDeviceIdBetweenTimestamps(from, to, deviceId);
        if(generationResult.result === eventLogger.eventResult.Success) {documentManager.sendFileInRes(generationResult.path, 'sisak-'+ deviceId +"-"+from+"-"+to+'.xlsx', res);}
        else {res.status(500).json({ status: "ERROR", message: "Hiba történt a dokumentum generálása során" });}
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});
router.get('/sisakByDeviceId', middleware.isLoggedIn, async function(req, res, next) {
    try {
        let deviceId = req.query.deviceId
        ;
        let generationResult = await documentManager.sisakByDeviceId(deviceId);
        if(generationResult.result === eventLogger.eventResult.Success) {documentManager.sendFileInRes(generationResult.path, 'sisak-'+ deviceId +'.xlsx', res);}
        else {res.status(500).json({ status: "ERROR", message: "Hiba történt a dokumentum generálása során" });}
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});
router.get('/sisakByDeviceIdBetweenTimestamps-json', middleware.isLoggedIn, async function(req, res, next) {
    //http://localhost:3000/generator/vallfaByDeviceIdBetweenTimestamps-json?dateFrom=1657692000000&dateTo=1657692060000&deviceId=egy
    try {
        let from = req.query.dateFrom,
            to = req.query.dateTo,
            deviceId = req.query.deviceId
        ;

        const [
            temperatures,
            humidity,
            heartRate,
            oxygen,
            current,
            voltage
        ] = await Promise.all([
            db.getTemperatureOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getHumidityOfDeviceBetweenTimeStamps(from, to, deviceId),

            db.getHR_heartRateOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getHR_oxygenOfDeviceBetweenTimeStamps(from, to, deviceId),

            db.getcurrentOfDeviceBetweenTimeStamps(from, to, deviceId),
            db.getvoltageOfDeviceBetweenTimeStamps(from, to, deviceId)
        ]);

        res.status(200).json(
            {
                temperatures:temperatures,
                humidity:humidity,
                heartRate:heartRate,
                oxygen:oxygen,
                current:current,
                voltage:voltage,
            }
        );
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});
router.get('/sisakByDeviceId-json', middleware.isLoggedIn, async function(req, res, next) {
    //http://localhost:3000/generator/vallfaByDeviceIdBetweenTimestamps-json?dateFrom=1657692000000&dateTo=1657692060000&deviceId=egy
    try {
        let deviceId = req.query.deviceId;

        const [
            temperatures,
            humidity,
            heartRate,
            oxygen,
            current,
            voltage
        ] = await Promise.all([
            db.getTemperatureOfDevice(deviceId),
            db.getHumidityOfDevice(deviceId),

            db.getHR_heartRateOfDevice(deviceId),
            db.getHR_oxygenOfDevice(deviceId),

            db.getcurrentOfDevice(deviceId),
            db.getvoltageOfDevice(deviceId)
        ]);

        res.status(200).json(
            {
                temperatures:temperatures,
                humidity:humidity,
                heartRate:heartRate,
                oxygen:oxygen,
                current:current,
                voltage:voltage,
            }
        );
    } catch (e) {res.status(500).json({ status: "ERROR", message: e });}
});

module.exports = router;